//  ====================================
//   NAME    : fwUkl1CB
// 
//   VERSION : 3
// 
//   REVISION: 0
// 
//   DATE    : 2008/07/28
// 
//   RELEASE : 2008/04/03
// 
//   PLATFORM: PVSS II
// 
//   AUTHOR  : Gareth Rogers
// 
//   EMAIL   : rogers@hep.phy.cam.ac.uk
//  ====================================

/* \mainpage Contains all the callback functions that are available for the UKL1 library.
 *
 *   All callback functions that be connected to are in this library. It includes the callback functions
 *   that are to be used to keep the abstract registers panel shapes update when monitoring the hardware registers.
 */

// ====================
//  #USES DECLARATIONS
// ====================

/*! fwUkl1ExcepionHandling library is used to store and display errors that occur with fwUkl1 function calls. */
#uses "fwUkl1ExceptionHandling/fwUkl1ExceptionHandling.ctl"

/*! fwHw library is used for recipe and data point manipulation. */
#uses "fwHw.ctl"

/*! fwCcpc library is used for accessing the UKL1 registers. */
#uses "fwCcpc.ctl"

/*! The FSM libraries are used to create and configure the UKL1 FSM tree. */
#uses "fwCU"
#uses "fwDU"

// =========================
//  CONSTANTs & GLOBAL VARs
// =========================

/** @defgroup SectionConstants Constants
 *
 *    These are the constants used by the library and are available for library users. Primaryly
 *    they define the DP structures in use and provide a means to interact with the DPEs without
 *    the need to hardcode names.
 *
 *  @{
 */

/*! Defines the name of the callback function that manipulates the FSM state depending on the CCSERV state. */
const string FWUKL1_MONITOR_CCSERV_CB = "fwUkl1_monitorCcservStateCB";


// @}

// ========================
//  UKL1 CONNECT FUNCTIONS
// ========================

/*! @defgroup ConnectFunctions Connect functions
 *    These are a group of functions that automate the calling of the connect function for call back registers.
 * // @{
 */

/*!
 * This function takes a list of abstract registers and connects the appropriate function to the appropriate hardware datapoint.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  regList List of abstract registers that are to be updated.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void fwUkl1_connectAbstractRegsToHwDps(const string &ukl1Name, const dyn_string &regList, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // Need to know how many registers to loop over.
  const int numRegs = dynlen(regList);
  // This will store the name of the callback function we are connecting to.
  string cb;
  // Name of the associate HW registers.
  dyn_string hwRegs;
  // The tool tip text associated with this register.
  string tooltip;
  // The DPE to connect to all have an extension that need to be added after the hw reg.
  const string extension = ".readings";
  // The name of the DPE we wish to connect to.
  string dpe;
  // Name of the abstract register we are connecting.
  string absReg;
  // Loop over all the registers given.
  for (int regNum = 1; regNum <= numRegs; ++regNum) {
    absReg = regList[regNum];
    // Some of the register names contain full stops and these can't be part of a function name.
    // Just remove them from the string.
    cb = "fwUkl1_" + absReg + "CB";
    strreplace(cb, ".", "");
    if (isFunctionDefined(cb)) {
      // Get the list of hardware registers to monitor.
      hwRegs = fwUkl1_getMonitoringRegisterList(absReg, exceptionInfo);
      if (!fwUkl1Exception_checkAndRaise(exceptionInfo, "ERROR", "fwUkl1_connectAbstractRegsToHwDps(): Failed to connect the abstract register " + absReg + " to the associated hardware register as it could not be found.", "2", exInfoSize)) {
        // This will contain the DPEs that we wish to connect to.
        dyn_string dpes;
        // Create a DPE to connect to for each of the hardware registers given.
        for (int i=1; i<=dynlen(hwRegs); ++i) {
          string dpe = ukl1Name+hwRegs[i]+extension;
          if (dpExists(dpe))
            dynAppend(dpes, dpe);
          else
            exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_connectAbstractRegsToHwDps(): Failed to connect the abstract register " + absReg + " to the datapoint element " + dpe + " because the DPE did not exists.", "2");
        }// for i
        
        // Now connect the callback function to these DPEs.
        if (-1 == dpConnect(cb, FALSE, dpes))
          exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_connectAbstractRegsToHwDps(): Failed to connect the abstract register " + absReg + " to the requested datapoint elements. The dpConnect failed.", "2");
      }// if got hw regs
      // Get the tool tip text.
      tooltip = fwUkl1_getToolTipText(absReg, exceptionInfo);
      if (!fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_connectAbstractRegsToHwDps(): Failed to retrieve the tool tip text for the register " + absReg + ". No information about this register can be found by hovering over the display shape.", "2", exInfoSize)) {
        // We know what shape name we want to put the data on.
        const string shapeName = absReg + "Field";
        // Check if it exists.
        if (shapeExists(shapeName)) {
          shape sh = getShape(shapeName);
          sh.toolTipText(tooltip);
        }// if shapeExists()
      }// if got tool tip text.
    }// if(isFunctionDefined())
    else
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_connectAbstractRegsToHwDps(): Failed to connect the abstract register " + absReg + " to its associated hardware datapoint as the callback function " + cb + " did not exist.", "2");
  }// for regNum
  
  // Done.
  return;
}// fwUkl1_connectAbstractRegsToHwDps()

/*!
 * This function takes a list of abstract registers and disconnects the appropriate function from the hardware datapoint.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  regList List of abstract registers that are to be updated.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * This will only work if it is called in the same scope as the connect function.
 */
void fwUkl1_disconnectAbstractRegsToHwDps(const string &ukl1Name, const dyn_string &regList, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // Need to know how many registers to loop over.
  const int numRegs = dynlen(regList);
  // This will store the name of the callback function we are connecting to.
  string cb;
  // Name of the abstract register we are connecting.
  string absReg;
  // Name of the associate HW registers.
  dyn_string hwRegs;
  // The DPE to connect to all have an extension that need to be added after the hw reg.
  const string extension = ".readings";
  // The name of the DPE we wish to connect to.
  string dpe;
  // Loop over all the registers given.
  for (int regNum = 1; regNum <= numRegs; ++regNum) {
    absReg = regList[regNum];
    // Some of the register names contain full stops and these can't be part of a function name.
    // Just remove them from the string.
    cb = "fwUkl1_" + absReg + "CB";
    strreplace(cb, ".", "");
    if (isFunctionDefined(cb)) {
      // This will contain the DPEs that we wish to connect to.
      dyn_string dpes;
      // Get the hardware reg name
      hwRegs = fwUkl1_getMonitoringRegisterList(absReg, exceptionInfo);
      if (!fwUkl1Exception_checkAndRaise(exceptionInfo, "ERROR", "fwUkl1_disconnectAbstractRegsToHwDps(): Failed to disconnect the abstract register " + absReg + " from the associated hardware register as it it could not be found.", "2", exInfoSize)) {
        // Create a DPE to connect to for each of the hardware registers given.
        for (int i=1; i<=dynlen(hwRegs); ++i) {
          string dpe = ukl1Name+hwRegs[i]+extension;
          if (dpExists(dpe))
            dynAppend(dpes, dpe);
          else
            exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_disconnectAbstractRegsToHwDps(): Failed to disconnect the abstract register " + absReg + " to the datapoint element " + dpe + " because the DPE did not exists.", "2");
        }// for i
        
        // Now disconnect the callback function to these DPEs.
        if (-1 == dpDisconnect(cb, dpes))
          exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_disconnectAbstractRegsToHwDps(): Failed to disconnect the abstract register " + absReg + " from the datapoint elements. The dpDisconnect failed.", "2");
      }// if got hardware regs
    }// if callback function defined
  }// for regNum
  // Done.
  return;
}// fwUkl1_disconnectAbstractRegsToHwDps()

// @}


// =========================
//  UKL1 CALLBACK FUNCTIONS
// =========================

/*! @defgroup CallbackFunctions Callback functions
 *    The call back functions that are available.
 * // @{
 */

/*!
 * This function is connected to a UKL1 ccserv state and is called when ever this changes.
 * It will set the UKL1 FSM state to UNKNOWN if the ccserv process disconnects from the
 * PVSS system and to NOT_READY when it reconnects.
 *
 * \param  domain FSM domain that triggered the action.
 * \param  device Name of the FSM DU that triggered the action, corresponds to the UKL1 name.
 * \param  state State of ccserv process.
 * \return void.
 *
 * An error message is sent to the exception log if the ccserv disconnects, but not if it reconnects.
 * This behaviour is overidden for the case where the UKL1 is in the RUNNING state.
 * In this case there will be no change to the UKL1 state, but a message is still sent to the
 * exception log. The connection is setup via the fwHw library function fwHw_connectServerState.
 *
 * Once a board is connected it will be setup to start monitoring those registers that can be monitored
 * on the ccserv.
 */
void fwUkl1_monitorCcservStateCB(const string &domain, const string &device, int state) {
  dyn_string exceptionInfo;
  int exInfoSize = dynlen(exceptionInfo);
  // Perform the necessary bits when we disconnect, except state manipulation.
  if (0 == state)
    fwUkl1Exception_raise(exceptionInfo, "WARNING", "fwUkl1_monitorCcservStateCB(): ccserv process for the " + device + " disconnected. Communication is impossible with this board until the ccserv process reconnects. The board can continue to operate as the firmware is likey unaffected by the event.", "2");
  // Now perform the necessary bit when we connect.
  else if (1 == state) {
    fwUkl1_startMonitoringAllMonitorableRegs(device, exceptionInfo);
    fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_monitorCcservStateCB(): Failed to start monitoring the registers for " + device + " when it reconnected.", "2", exInfoSize);
  }// else(1==state)
  
  // Now set the appropriate state for the UKL1.
  const string dpeName = device + ".status";
  if ( dpExists(dpeName) ) {
    // The FSM state does exist for this device, now check its state.
    const string fsmState = fwUkl1_getUkl1State(device);
    if ( "RUNNING" != fsmState ) {
      // We are not in the running state so set the new state accordingly.
      // Note that we have already checked for the existence of the DPE so don't need to worry about
      // an empty string return from the fwUkl1_getUkl1State function.
      if ( 0 == state )
        dpSet(dpeName, "UNKNOWN");
      else
        dpSet(dpeName, "NOT_READY");
    }// if("RUNNING"!=fsmState)
    // no else, don't change the state when in the RUNNING state.
  }// if(dpExists(dpeName))
  else
    exInfoSize = fwUkl1Exception_raise(exceptionInfo, "WARNING", "fwUkl1_monitorCcservStateCB(): Cannot find the FSM state datapoint element for " + device + ", cannot update its state to reflect the ccserv connection status. ccserv for this UKL1 " + (0==state ? "diconnected":"connected") + ".", "2");
  
  fwUkl1ExceptionLog_submit(exceptionInfo, device);
  // Done.
  return;
}// fwUkl1_monitorCcservStateCB()

/*!
 * The following functions can be connected to associated hardware register DPE and when the register
 * changes it will place the value of that register in a panel element of the form AbsRegNameField.
 * AbsRegName is the name of the abstract register for example MacDestinationAddress would be
 * MacDestinationAddressField. In the event of an error it will be sent to the error log.
 */
// FPGA configuration registers.
void fwUkl1_MacDestinationAddressCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MacDestinationAddress";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MacDestinationAddressCB()

void fwUkl1_MacSourceAddressCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MacSourceAddress";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MacSourceAddressCB()

void fwUkl1_IpDestinationAddressCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "IpDestinationAddress";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_IpDestinationAddressCB()

void fwUkl1_IpSourceAddressCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "IpSourceAddress";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_CB()

void fwUkl1_PartitionIdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "PartitionId";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_PartitionIdCB()

void fwUkl1_TimeToLiveCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TimeToLive";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TimeToLiveCB()

void fwUkl1_TypeOfServiceCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TypeOfService";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TypeOfServiceCB()

void fwUkl1_ProtocolCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "Protocol";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ProtocolCB()

void fwUkl1_TypeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "Type";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TypeCB()

void fwUkl1_MepEventCountCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MepEventCount";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MepEventCountCB()

void fwUkl1_MTUCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MTU";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MTUCB()

void fwUkl1_MepTruncationHighWatermarkCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MepTruncationHighWatermark";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MepTruncationHighWatermarkCB()

void fwUkl1_ManualMepGbeOutputPortNumberCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ManualMepGbeOutputPortNumber";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ManualMepGbeOutputPortNumberCB()

void fwUkl1_ThrottleModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ThrottleMode";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ThrottleModeCB()

void fwUkl1_ThrottlePolarityCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ThrottlePolarity";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ThrottlePolarityCB()

void fwUkl1_ThrottleOutputCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ThrottleOutput";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ThrottleOutputCB()

void fwUkl1_ForceFixedMepDestinationAddressCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ForceFixedMepDestinationAddress";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ForceFixedMepDestinationAddressCB()

void fwUkl1_MepBuildingModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MepBuildingMode";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MepBuildingModeCB()

void fwUkl1_TfcDecodingCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TfcDecoding";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_CB()

void fwUkl1_GbeTpaPollingCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeTpaPolling";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeTpaPollingCB()

void fwUkl1_ManualMepGbeOutputPortControlCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ManualMepGbeOutputPortControl";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ManualMepGbeOutputPortControlCB()

void fwUkl1_Ingress0EnableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "Ingress0Enable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_Ingress0EnableCB()

void fwUkl1_Ingress1EnableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "Ingress1Enable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_Ingress1EnableCB()

void fwUkl1_Ingress2EnableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "Ingress2Enable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_Ingress2EnableCB()

void fwUkl1_Ingress3EnableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "Ingress3Enable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_Ingress3EnableCB()

void fwUkl1_VersionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "Version";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_VersionCB()

void fwUkl1_TfcLatencyCompensationCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TfcLatencyCompensation";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TfcLatencyCompensationCB()

void fwUkl1_L1IdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "L1Id";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_L1IdCB()

// FPGA status registers.
void fwUkl1_TTCIdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TTCId";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TTCIdCB()

void fwUkl1_TFCFIFORequestCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TFCFIFORequest";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TFCFIFORequestCB()

void fwUkl1_TTCrxReadyCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TTCrxReady";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TTCrxReadyCB()

void fwUkl1_EventMergerReadStateCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EventMergerReadState";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EventMergerReadStateCB()

void fwUkl1_GTDataLowWordInhibit0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataLowWordInhibit0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataLowWordInhibit0CB()

void fwUkl1_GTDataLowWordInhibit1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataLowWordInhibit1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataLowWordInhibit1CB()

void fwUkl1_GTDataLowWordInhibit2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataLowWordInhibit2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataLowWordInhibit2CB()

void fwUkl1_GTDataLowWordInhibit3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataLowWordInhibit3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataLowWordInhibit3CB()

void fwUkl1_GTDataHighWordInhibit0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataHighWordInhibit0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataHighWordInhibit0CB()

void fwUkl1_GTDataHighWordInhibit1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataHighWordInhibit1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataHighWordInhibit1CB()

void fwUkl1_GTDataHighWordInhibit2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataHighWordInhibit2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataHighWordInhibit2CB()

void fwUkl1_GTDataHighWordInhibit3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataHighWordInhibit3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataHighWordInhibit3CB()

void fwUkl1_GTCommunicationWordInhibit0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTCommunicationWordInhibit0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTCommunicationWordInhibit0CB()

void fwUkl1_GTCommunicationWordInhibit1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTCommunicationWordInhibit1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTCommunicationWordInhibit1CB()

void fwUkl1_GTCommunicationWordInhibit2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTCommunicationWordInhibit2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTCommunicationWordInhibit2CB()

void fwUkl1_GTCommunicationWordInhibit3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTCommunicationWordInhibit3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTCommunicationWordInhibit3CB()

void fwUkl1_GTDataLinkInhibit0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataLinkInhibit0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataLinkInhibit0CB()

void fwUkl1_GTDataLinkInhibit1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataLinkInhibit1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataLinkInhibit1CB()

void fwUkl1_GTDataLinkInhibit2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataLinkInhibit2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataLinkInhibit2CB()

void fwUkl1_GTDataLinkInhibit3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTDataLinkInhibit3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTDataLinkInhibit3CB()

void fwUkl1_GBETxCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GBETx";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GBETxCB()

void fwUkl1_MEPFifoCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MEPFifo";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MEPFifoCB()

void fwUkl1_ThrottleAssertedCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ThrottleAsserted";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ThrottleAssertedCB()

void fwUkl1_GTFIFO0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTFIFO0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTFIFO0CB()

void fwUkl1_GTFIFO1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTFIFO1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTFIFO1CB()

void fwUkl1_GTFIFO2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTFIFO2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTFIFO2CB()

void fwUkl1_GTFIFO3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTFIFO3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTFIFO3CB()

void fwUkl1_GTLowFIFODataReadout0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTLowFIFODataReadout0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTLowFIFODataReadout0CB()

void fwUkl1_GTLowFIFODataReadout1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTLowFIFODataReadout1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTLowFIFODataReadout1CB()

void fwUkl1_GTLowFIFODataReadout2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTLowFIFODataReadout2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTLowFIFODataReadout2CB()

void fwUkl1_GTLowFIFODataReadout3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTLowFIFODataReadout3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTLowFIFODataReadout3CB()

void fwUkl1_GTHighFIFODataReadout0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTHighFIFODataReadout0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTHighFIFODataReadout0CB()

void fwUkl1_GTHighFIFODataReadout1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTHighFIFODataReadout1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTHighFIFODataReadout1CB()

void fwUkl1_GTHighFIFODataReadout2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTHighFIFODataReadout2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTHighFIFODataReadout2CB()

void fwUkl1_GTHighFIFODataReadout3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTHighFIFODataReadout3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTHighFIFODataReadout3CB()

void fwUkl1_TFCL0ResetCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TFCL0Reset";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TFCL0ResetCB()

void fwUkl1_TFCL1ResetCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TFCL1Reset";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TFCL1ResetCB()

void fwUkl1_TFCShortBroadcastCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TFCShortBroadcast";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TFCShortBroadcastCB()

void fwUkl1_GBETransmitPortAvailable0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GBETransmitPortAvailable0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GBETransmitPortAvailable0CB()

void fwUkl1_GBETransmitPortAvailable1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GBETransmitPortAvailable1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GBETransmitPortAvailable1CB()

void fwUkl1_GBETransmitPortAvailable2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GBETransmitPortAvailable2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GBETransmitPortAvailable2CB()

void fwUkl1_GBETransmitPortAvailable3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GBETransmitPortAvailable3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GBETransmitPortAvailable3CB()

void fwUkl1_EthernetFragmentReadyCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EthernetFragmentReady";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EthernetFragmentReadyCB()

void fwUkl1_MEPReadyCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MEPReady";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MEPReadyCB()

void fwUkl1_FragmentRequestCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "FragmentRequest";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_FragmentRequestCB()

void fwUkl1_MEPExtractionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MEPExtraction";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MEPExtractionCB()

void fwUkl1_EthernetFormatterStateCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EthernetFormatterState";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EthernetFormatterStateCB()

void fwUkl1_FragmentExtractionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "FragmentExtraction";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_FragmentExtractionCB()

void fwUkl1_SequenceErrorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "SequenceError";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_SequenceErrorCB()

void fwUkl1_MEPCountCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MEPCount";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MEPCountCB()

void fwUkl1_GTFIFOTxWait0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTFIFOTxWait0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTFIFOTxWait0CB()

void fwUkl1_GTFIFOTxWait1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTFIFOTxWait1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTFIFOTxWait1CB()

void fwUkl1_GTFIFOTxWait2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTFIFOTxWait2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTFIFOTxWait2CB()

void fwUkl1_GTFIFOTxWait3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GTFIFOTxWait3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GTFIFOTxWait3CB()

void fwUkl1_TFCFIFOOccupancyCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TFCFIFOOccupancy";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TFCFIFOOccupancyCB()

void fwUkl1_TFCLongBroadcastCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TFCLongBroadcast";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TFCLongBroadcastCB()

void fwUkl1_EgressInputFIFOLowWordSequenceError0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordSequenceError0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordSequenceError0CB()

void fwUkl1_EgressInputFIFOLowWordSequenceError1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordSequenceError1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordSequenceError1CB()

void fwUkl1_EgressInputFIFOLowWordSequenceError2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordSequenceError2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordSequenceError2CB()

void fwUkl1_EgressInputFIFOLowWordSequenceError3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordSequenceError3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordSequenceError3CB()

void fwUkl1_EgressInputFIFOHighWordSequenceError0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordSequenceError0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordSequenceError0CB()

void fwUkl1_EgressInputFIFOHighWordSequenceError1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordSequenceError1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordSequenceError1CB()

void fwUkl1_EgressInputFIFOHighWordSequenceError2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordSequenceError2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordSequenceError2CB()

void fwUkl1_EgressInputFIFOHighWordSequenceError3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordSequenceError3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordSequenceError3CB()

void fwUkl1_L0TriggerCountCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "L0TriggerCount";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_L0TriggerCountCB()

void fwUkl1_ROTBroadcastCountCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ROTBroadcastCount";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ROTBroadcastCountCB()

void fwUkl1_TFCDestinationCountCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TFCDestinationCount";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TFCDestinationCountCB()

void fwUkl1_MEPSequenceCountCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "MEPSequenceCount";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_MEPSequenceCountCB()

void fwUkl1_TTCrxReadyAlarmCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TTCrxReadyAlarm";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TTCrxReadyAlarmCB()

void fwUkl1_SequenceErrorAlarmCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "SequenceErrorAlarm";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_SequenceErrorAlarmCB()

void fwUkl1_EgressInputFIFOLowWordOccupancy0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordOccupancy0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordOccupancy0CB()

void fwUkl1_EgressInputFIFOLowWordOccupancy1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordOccupancy1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordOccupancy1CB()

void fwUkl1_EgressInputFIFOLowWordOccupancy2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordOccupancy2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordOccupancy2CB()

void fwUkl1_EgressInputFIFOLowWordOccupancy3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordOccupancy3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordOccupancy3CB()

void fwUkl1_EgressInputFIFOHighWordOccupancy0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordOccupancy0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordOccupancy0CB()

void fwUkl1_EgressInputFIFOHighWordOccupancy1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordOccupancy1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordOccupancy1CB()

void fwUkl1_EgressInputFIFOHighWordOccupancy2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordOccupancy2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordOccupancy2CB()

void fwUkl1_EgressInputFIFOHighWordOccupancy3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordOccupancy3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordOccupancy3CB()

void fwUkl1_EgressInputFIFOLowWordRxCount0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordRxCount0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordRxCount0CB()

void fwUkl1_EgressInputFIFOLowWordRxCount1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordRxCount1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordRxCount1CB()

void fwUkl1_EgressInputFIFOLowWordRxCount2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordRxCount2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordRxCount2CB()

void fwUkl1_EgressInputFIFOLowWordRxCount3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordRxCount3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordRxCount3CB()

void fwUkl1_EgressInputFIFOHighWordRxCount0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordRxCount0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordRxCount0CB()

void fwUkl1_EgressInputFIFOHighWordRxCount1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordRxCount1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordRxCount1CB()

void fwUkl1_EgressInputFIFOHighWordRxCount2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordRxCount2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordRxCount2CB()

void fwUkl1_EgressInputFIFOHighWordRxCount3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordRxCount3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordRxCount3CB()

void fwUkl1_EgressInputFIFOLowWordTxCount0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordTxCount0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordTxCount0CB()

void fwUkl1_EgressInputFIFOLowWordTxCount1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordTxCount1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordTxCount1CB()

void fwUkl1_EgressInputFIFOLowWordTxCount2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordTxCount2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordTxCount2CB()

void fwUkl1_EgressInputFIFOLowWordTxCount3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOLowWordTxCount3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOLowWordTxCount3CB()

void fwUkl1_EgressInputFIFOHighWordTxCount0CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordTxCount0";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordTxCount0CB()

void fwUkl1_EgressInputFIFOHighWordTxCount1CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordTxCount1";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordTxCount1CB()

void fwUkl1_EgressInputFIFOHighWordTxCount2CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordTxCount2";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordTxCount2CB()

void fwUkl1_EgressInputFIFOHighWordTxCount3CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "EgressInputFIFOHighWordTxCount3";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_EgressInputFIFOHighWordTxCount3CB()

// ID registers.
void fwUkl1_SerialNumberCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "SerialNumber";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_SerialNumberCB()

void fwUkl1_LogicalIdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "LogicalId";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_LogicalIdCB()

void fwUkl1_RichIdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "RichId";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_RichIdCB()

// Sensors.
void fwUkl1_TemperatureSensorTopCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TemperatureSensorTop";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TemperatureSensorTopCB()

void fwUkl1_TemperatureSensorMiddleCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TemperatureSensorMiddle";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TemperatureSensorMiddleCB()

void fwUkl1_TemperatureSensorBottomCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TemperatureSensorBottom";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TemperatureSensorBottomCB()

// TTCrx.
void fwUkl1_TtcrxControlCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "TtcrxControl";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_TtcrxControlCB()

void fwUkl1_GbeJtagIdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeJtagId";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeJtagIdCB()

void fwUkl1_GbeMACSoftResetCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeMACSoftReset";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeMACSoftResetCB()

void fwUkl1_GbeReceivePortResetCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeReceivePortReset";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeReceivePortResetCB()

void fwUkl1_GbeTransmitPortResetCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeTransimitPortReset";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeTransimitPortResetCB()

void fwUkl1_GbeReceiveFifoEnableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeReceiveFifoEnable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeReceiveFifoEnableCB()

void fwUkl1_GbeModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeMode";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeModeCB()

void fwUkl1_GbeClockCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeClock";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeClockCB()

void fwUkl1_GbeSPI3ConfigTrnmtGlobalCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeSPI3ConfigTrnmtGlobal";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeSPI3ConfigTrnmtGlobalCB()

void fwUkl1_GbeSPI3ConfigRcvCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeSPI3ConfigRcv";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeSPI3ConfigRcvCB()

void fwUkl1_GbeRxStatusCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeRxStatus";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeRxStatusCB()

void fwUkl1_GbePHYCtrlCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePHYCtrl";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePHYCtrlCB()

void fwUkl1_GbePHYWriteDataCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePHYWriteData";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePHYWriteDataCB()

void fwUkl1_GbePHYReadDataCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePHYReadData";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePHYReadDataCB()

void fwUkl1_GbeMDIOControlCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbeMDIOControl";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbeMDIOControlCB()

void fwUkl1_GbePort0EnableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort0Enable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort0EnableCB()

void fwUkl1_GbePort1EnableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort1Enable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort1EnableCB()

void fwUkl1_GbePort2EnableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort2Enable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort2EnableCB()

void fwUkl1_GbePort3EnableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort3Enable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort3EnableCB()

void fwUkl1_GbePort0TxFifoThresholdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort0TxFifoThreshold";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort0TxFifoThresholdCB()

void fwUkl1_GbePort1TxFifoThresholdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort1TxFifoThreshold";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort1TxFifoThresholdCB()

void fwUkl1_GbePort2TxFifoThresholdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort2TxFifoThreshold";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort2TxFifoThresholdCB()

void fwUkl1_GbePort3TxFifoThresholdCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort3TxFifoThreshold";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort3TxFifoThresholdCB()

void fwUkl1_GbePort0TxFifoLowWatermarkCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort0TxFifoLowWatermark";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort0TxFifoLowWatermarkCB()

void fwUkl1_GbePort1TxFifoLowWatermarkCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort1TxFifoLowWatermark";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort1TxFifoLowWatermarkCB()

void fwUkl1_GbePort2TxFifoLowWatermarkCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort2TxFifoLowWatermark";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort2TxFifoLowWatermarkCB()

void fwUkl1_GbePort3TxFifoLowWatermarkCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort3TxFifoLowWatermark";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort3TxFifoLowWatermarkCB()

void fwUkl1_GbePort0TxFifoHighWatermarkCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort0TxFifoHighWatermark";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort0TxFifoHighWatermarkCB()

void fwUkl1_GbePort1TxFifoHighWatermarkCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort1TxFifoHighWatermark";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort1TxFifoHighWatermarkCB()

void fwUkl1_GbePort2TxFifoHighWatermarkCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort2TxFifoHighWatermark";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort2TxFifoHighWatermarkCB()

void fwUkl1_GbePort3TxFifoHighWatermarkCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "GbePort3TxFifoHighWatermark";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_GbePort3TxFifoHighWatermarkCB()
    
void fwUkl1_Channel0DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel0.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel1DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel1.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel2DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel2.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel3DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel3.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel4DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel4.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel5DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel5.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel6DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel6.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel7DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel7.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel8DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel8.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel9DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel9.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel10DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel10.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel11DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel11.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel12DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel12.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel13DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel13.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel14DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel14.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel15DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel15.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel16DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel16.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel17DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel17.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel18DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel18.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel19DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel19.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel20DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel20.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel21DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel21.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel22DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel22.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel23DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel23.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel24DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel24.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel25DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel25.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel26DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel26.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel27DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel27.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel28DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel28.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel29DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel29.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel30DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel30.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel31DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel31.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel32DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel32.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel33DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel33.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel34DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel34.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel35DisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel35.Disable";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel0HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel0.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel1HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel1.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel2HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel2.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel3HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel3.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel4HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel4.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel5HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel5.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel6HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel6.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel7HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel7.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel8HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel8.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel9HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel9.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel10HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel10.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel11HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel11.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel12HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel12.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel13HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel13.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel14HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel14.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel15HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel15.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel16HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel16.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel17HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel17.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel18HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel18.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel19HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel19.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel20HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel20.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel21HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel21.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel22HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel22.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel23HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel23.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel24HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel24.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel25HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel25.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel26HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel26.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel27HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel27.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel28HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel28.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel29HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel29.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel30HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel30.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel31HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel31.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel32HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel32.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel33HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel33.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel34HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel34.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel35HpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel35.HpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel0ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel0.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel1ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel1.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel2ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel2.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel3ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel3.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel4ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel4.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel5ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel5.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel6ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel6.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel7ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel7.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel8ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel8.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel9ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel9.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel10ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel10.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel11ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel11.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel12ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel12.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel13ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel13.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel14ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel14.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel15ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel15.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel16ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel16.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel17ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel17.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel18ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel18.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel19ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel19.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel20ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel20.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel21ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel21.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel22ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel22.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel23ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel23.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel24ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel24.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel25ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel25.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel26ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel26.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel27ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel27.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel28ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel28.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel29ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel29.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel30ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel30.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel31ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel31.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel32ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel32.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel33ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel33.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel34ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel34.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel35ZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel35.ZeroSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel0EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel0.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel1EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel1.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel2EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel2.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel3EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel3.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel4EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel4.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel5EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel5.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel6EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel6.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel7EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel7.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel8EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel8.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel9EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel9.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel10EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel10.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel11EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel11.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel12EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel12.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel13EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel13.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel14EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel14.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel15EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel15.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel16EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel16.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel17EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel17.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel18EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel18.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel19EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel19.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel20EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel20.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel21EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel21.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel22EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel22.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel23EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel23.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel24EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel24.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel25EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel25.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel26EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel26.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel27EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel27.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel28EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel28.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel29EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel29.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel30EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel30.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel31EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel31.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel32EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel32.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel33EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel33.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel34EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel34.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel35EmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel35.EmptyHpdSuppression";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel0EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel0.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel1EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel1.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel2EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel2.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel3EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel3.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel4EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel4.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel5EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel5.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel6EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel6.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel7EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel7.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel8EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel8.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel9EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel9.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel10EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel10.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel11EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel11.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel12EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel12.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel13EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel13.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel14EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel14.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel15EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel15.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel16EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel16.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel17EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel17.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel18EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel18.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel19EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel19.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel20EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel20.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel21EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel21.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel22EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel22.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel23EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel23.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel24EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel24.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel25EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel25.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel26EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel26.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel27EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel27.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel28EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel28.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel29EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel29.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel30EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel30.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel31EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel31.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel32EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel32.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel33EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel33.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel34EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel34.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel35EmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel35.Emulator";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel0EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel0.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel1EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel1.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel2EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel2.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel3EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel3.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel4EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel4.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel5EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel5.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel6EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel6.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel7EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel7.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel8EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel8.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel9EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel9.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel10EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel10.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel11EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel11.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel12EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel12.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel13EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel13.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel14EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel14.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel15EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel15.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel16EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel16.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel17EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel17.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel18EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel18.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel19EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel19.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel20EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel20.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel21EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel21.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel22EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel22.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel23EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel23.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel24EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel24.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel25EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel25.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel26EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel26.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel27EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel27.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel28EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel28.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel29EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel29.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel30EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel30.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel31EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel31.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel32EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel32.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel33EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel33.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel34EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel34.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel35EmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel35.EmulatorHpdPixelMode";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel0EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel0.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel1EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel1.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel2EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel2.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel3EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel3.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel4EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel4.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel5EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel5.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel6EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel6.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel7EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel7.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel8EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel8.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel9EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel9.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel10EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel10.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel11EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel11.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel12EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel12.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel13EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel13.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel14EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel14.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel15EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel15.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel16EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel16.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel17EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel17.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel18EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel18.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel19EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel19.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel20EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel20.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel21EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel21.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel22EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel22.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel23EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel23.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel24EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel24.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel25EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel25.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel26EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel26.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel27EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel27.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel28EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel28.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel29EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel29.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel30EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel30.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel31EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel31.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel32EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel32.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel33EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel33.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel34EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel34.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_Channel35EmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  const string absRegName = "Channel35.EmulatorEvent";
  string ukl1Name;
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
}

void fwUkl1_ChannelAllDisableCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ChannelAll.Disable";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ChannelAllDisableCB()

void fwUkl1_ChannelAllHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ChannelAll.HpdPixelMode";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ChannelAllHpdPixelModeCB()

void fwUkl1_ChannelAllZeroSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ChannelAll.ZeroSuppression";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ChannelAllZeroSuppressionCB()

void fwUkl1_ChannelAllEmptyHpdSuppressionCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ChannelAll.EmptyHpdSuppression";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ChannelAllEmptyHpdSuppressionCB()

void fwUkl1_ChannelAllPixelMasksCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ChannelAll.PixelMasks";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ChannelAllPixelMasksCB()

void fwUkl1_ChannelAllEmulatorCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ChannelAll.Emulator";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ChannelAllEmulatorCB()

void fwUkl1_ChannelAllEmulatorHpdPixelModeCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ChannelAll.EmulatorHpdPixelMode";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ChannelAllEmulatorHpdPixelModeCB()

void fwUkl1_ChannelAllEmulatorEventCB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // The abstract register we are dealing with.
  const string absRegName = "ChannelAll.EmulatorEvent";
  // UKL1 name is returned by this function.
  string ukl1Name;
  // Now call the function that will parse this data.
  _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
  fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
  return;
}// fwUkl1_ChannelAllEmulatorEventCB()

// [INSERT HERE]

// void fwUkl1_CB(const dyn_string &dpeNames, const dyn_dyn_char &ddcNewValues) {
//   dyn_string exceptionInfo;
//   int exInfoSize = 0;
  // The abstract register we are dealing with.
//   const string absRegName = "";
  // UKL1 name is returned by this function.
//   string ukl1Name;
  // Now call the function that will parse this data.
//   _fwUkl1_parseRegisterForCallback(absRegName, dpeNames, ddcNewValues, ukl1Name, exceptionInfo);
//   fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_" + absRegName + "CB(): Could not parse and display the updated value for this register. Shape not updated.", "2", exInfoSize);
  // The UKL1 name is the bit before the first full stop in the DPE name. Leave the system name in.
//   fwUkl1ExceptionLog_submit(exceptionInfo, ukl1Name);
  // Done.
//   return;
// }// fwUkl1_CB()

// ==========
//  INTERNAL
// ==========

/*!
 * This function takes the abstract register name and the data from the hardware register that contains the value(s)
 * for the hardware register(s) and displays the abstract register value on a panel shape.
 *
 * \param  absRegName Abtract register name that the new value is to be retrieved for.
 * \param  dpeNames Names of the DPE that the updated hardware register data has come from.
 * \param  ddcNewValues The updated data in the hardware register(s) that need to be parsed.
 * \param  ukl1Name Name of the UKL1 board as found in the DIM server that is retrieved from the DPE name.
 *           Returned by reference.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * This function contains all the generic parsing that is required by the individual abstract register
 * callback functions. They simply need to define the register that they want the data for and pass on
 * that data they were given by when called and this function will sort the rest out.
 */
void _fwUkl1_parseRegisterForCallback(const string &absRegName, dyn_string dpeNames, dyn_dyn_char ddcNewValues, string &ukl1Name, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // Need to put the DPE new data into a map to link it with the hardware register name.
  mapping inData;
  // Should contain the null reg just incase.
  inData[FWUKL1_NULL_HWREG] = makeDynChar();
  // Need to get the hardware name for each register.
  const int numDpes = dynlen(dpeNames);
  // Get the UKL1 name. This only needs to be done once.
  int endOfUkl1Name;
  for (int i=1; i<=numDpes; ++i) {
    // The UKL1 name is up to the first full stop.
    if (1 == i) {
      endOfUkl1Name = strpos(dpeNames[i], ".");
      // Get the UKL1 name while we are here.
      ukl1Name = substr(dpeNames[i], 0, endOfUkl1Name);
    }// if(1==i)
    // Need to get ride of anything after and including readings.
    const int startOfReadings = strpos(dpeNames[i], ".readings");
    // Now the hardware register name.
    const string hwReg = substr(dpeNames[i], endOfUkl1Name, startOfReadings-endOfUkl1Name);
    // Now setup the data.
    inData[hwReg] = ddcNewValues[i];
    // This holds the out data.
  }// for i
  mapping outData;
  outData[absRegName] = makeDynString();
  // Want the information for status display hence TRUE.
  _fwUkl1_parseRegistersForGet(inData, outData, TRUE, exceptionInfo);
  if (!fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "_fwUkl1_parseRegisterForCallback(): Failed to parse the new register value for " + absRegName + ".", "2", exInfoSize)) {
    // We know what shape name we want to put the data on.
    const string shapeName = absRegName + "Field";
    // Check if it exists.
    if (shapeExists(shapeName)) {
      shape sh = getShape(shapeName);
      sh.text(outData[absRegName][FWUKL1_MAP_REG_DATA]);
      sh.backCol(outData[absRegName][FWUKL1_MAP_XTR_DATA]);
    }// if shapeExists()
    else
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "WARNING", "_fwUkl1_parseRegisterForCallback(): Could not find the shape " + shapeName + " to display the data " + outData[absRegName][FWUKL1_MAP_REG_DATA] + ".", "2");
  }// parsed the register
  // Done.
  return;
}// _fwUkl1_parseRegisterForCallback()

// @}
