// ====================================
//  NAME    : fwUkl1DPInterface
// 
//  VERSION : 3
// 
//  REVISION: 0
// 
//  DATE    : 2008/07/27
// 
//  RELEASE : 2008/04/03
// 
//  PLATFORM: PVSS II
// 
//  AUTHOR  : Gareth Rogers
// 
//  EMAIL   : rogers@hep.phy.cam.ac.uk
// ====================================

/* \mainpage UKL1 datapoint interface library documentation
 *
 * This library provides the all the functions that interface to the UKL1 project datapoints.
 *
 * The library provides an interface to the UKL1 constants datapoint and the software representation
 * of the UKL1 boards, which is a collection of several datapoint structures.
 */

// ====================
//  #USES DECLARATIONS
// ====================

/*! fwUkl1ExcepionHandling library is used to store and display errors that occur with fwUkl1 function calls. */
#uses "fwUkl1ExceptionHandling/fwUkl1ExceptionHandling.ctl"

/*! fwHw library is used for recipe and data point manipulation. */
#uses "fwHw.ctl"

/*! fwCcpc library is used for accessing the UKL1 registers. */
#uses "fwCcpc.ctl"

/*! fwFSMConfDB library is used to add and remove the FSM confDB object to the FSM tree. */
#uses "fwFSMConfDB/fwFsmConfDB.ctl"

/*! The FSM libraries are used to create and configure the UKL1 FSM tree. */
#uses "fwCU"
#uses "fwDU"

// =========================
//  CONSTANTs & GLOBAL VARs
// =========================

/** @defgroup SectionConstants Constants
 *
 *    These are the constants used by the library and are available for library users. Primaryly
 *    they define the DP structures in use and provide a means to interact with the DPEs without
 *    the need to hardcode names.
 *
 *  @{
 */

/*! These constants define the possible system numbers that are used in the fwUkl1 projects. */
const int FWUKL1_RICH1_SYS_NUM = "136";
const int FWUKL1_RICH2_SYS_NUM = "176";
const int FWUKL1_RICH3_SYS_NUM = "176";

/*! These constants define the values that the UKL1 CU should take in the different RICH systems. */
const string FWUKL1_RICH1_CU = "RICH1_L1";
const string FWUKL1_RICH2_CU = "RICH2_L1";
const string FWUKL1_RICH3_CU = "RICH3_L1";

/*! Defines the RICH ID to be used for different RICH systems. RICH3 is the SSB2 lab and test systems. */
const int FWUKL1_RICH1_ID = 1;
const int FWUKL1_RICH2_ID = 2;
const int FWUKL1_RICH3_ID = 3;

/*!
 * This defines the name of the Hugin to be used in the FSM tree. This is typically only valid in RICH1 or 2.
 * Therefore the RICH3 Hugin name is an empty string and this forms the special case where it is not added.
 */
const string FWUKL1_RICH1_HUGIN_NAME = "r1hugin01";
const string FWUKL1_RICH2_HUGIN_NAME = "r2hugin02";
const string FWUKL1_RICH3_HUGIN_NAME = "";

/*! This is the name of the Hugin FSM type. */
const string FWUKL1_HUGIN_TYPE = "HUGIN";
/*! This is the TFC system name. */
const string FWUKL1_TFC_SYS_NAME = "TFC";

/*!
 * Constant to indicate if the FSM configurator object should apply the recipes itself.
 * Unless there is a change in the hardware tool this must be FALSE. Not sure exactly
 * what the simplified AR does, but it is related to having the configurator applying the
 * recipes.
 */
const bool FWUKL1_CONFIGURATOR_APPLY_RECIPES = FALSE;
const bool FWUKL1_CONFIGURATOR_SIMPLIFIED_AR = FALSE;

/*!
 * Constant to define the length of the time for the FSM configurator object should it be
 * applying the recipes itself. This only matters if FWUKL1_CONFIGURATOR_APPLY_RECIPES is
 * TRUE. See its documentation for comments on that.
 */
const int FWUKL1_CONFIGURATOR_TIMEOUT = 0;

/*! The name of the DPT that the UKL1 constants DP is created from. */
const string FWUKL1_CONSTS_DPT = "FwUkl1Constants";
/*!
 * This is the name of the datapoint that contains the various constants that should be defined
 * during post installation.
 */
const string FWUKL1_CONSTS_DP_BASENAME = "UKL1Constants";
/*!
 * FwUkl1Constants contains a bool to indicate if the FSM configurator object should retrieve the
 * recipes from the configuration database or from the recipe cache. This should be TRUE for all systems
 * where the configuration database is present. The following constant defines the name of the DPE
 * in FwUkl1Constants.
 */
const string FWUKL1_CONFIGURATOR_USE_CONFDB = "ConfiguratorUseConfDB";
/*!
 * The name of the top level control unit (CU) that is used in the L1 FSM tree is stored in FwUkl1Constants.
 * This is the name of the DPE that it is stored under.
 */
const string FWUKL1_CU = "FSMCUName";
/*!
 * The name of the Hugin that is in the UKL1 FSM, if any. An empty string would indicate that no Hugin is
 * to be placed in the tree.
 * This is the name of the DPE that it is stored under.
 */
const string FWUKL1_HUGIN_NAME = "HuginName";

/*! The name of the DPT that contains the information about the various abstract registers. */
const string FWUKL1_UKL1_BOARD_DPT_NAME = "FwUkl1Board";
/*! The name of the DP that contains the information about the various abstract registers. */
const string FWUKL1_UKL1_BOARD_DP_NAME  = "UKL1Board";
/*! Name of the element that holds the list of abstract register names. */
const string FWUKL1_ABSTRACT_REG_LIST = "AbstractRegisterList";
/*! The tool tip text that should be displayed by the shape displaying the register data. */
const string FWUKL1_TOOLTIP_TEXT      = "ToolTipText";
/*! Group that the register is associated with. */
const string FWUKL1_REGISTER_GROUPS   = "Groups";
/*! The mask that should be applied to the data when it is written as a hex string.
    Does not take into account any perculiarities of the register e.g. the FPGAs. */
const string FWUKL1_MASK              = "Mask";
/*! Name of the function that should be used to start the monitoring for this register. */
const string FWUKL1_MONITORING_START_FUNCTION = "MonitoringInfo.StartFunction";
/*! Name of the function that should be used to stop the monitoring for this register. */
const string FWUKL1_MONITORING_STOP_FUNCTION = "MonitoringInfo.StopFunction";
/*! Name of the function that should be used to start the monitoring for this register. */
const string FWUKL1_MONITORING_REGISTERS = "MonitoringInfo.Registers";
/*! DPE element for the hardware read register use to display the register for configuration. */
const string FWUKL1_HW_CONFIG_READ       = "HwConfigReadRegister";
/*! DPE element for the hardware read register use to display the register for status. */
const string FWUKL1_HW_STATUS_READ       = "HwStatusReadRegister";
/*! DPE element for the hardware write register. */
const string FWUKL1_HW_WRITE             = "HwWriteRegister";
/*! DPE element for the database read register. */
const string FWUKL1_DB_READ              = "DbReadRegister";
/*! DPE element for the database write register. */
const string FWUKL1_DB_WRITE             = "DbWriteRegister";
/*! Hardware register type number. Associated with either a write or read hardware register. */
const string FWUKL1_HW_REGISTER_TYPE     = ".Type";
/*! Recipe types that contain this database register. */
const string FWUKL1_DB_RECIPE_TYPES      = ".Types";
/*! List of registers associated with either a hardware or database register. */
const string FWUKL1_ACCESS_REGISTERS     = ".Registers";
/*! The function used to parse the register input. */
const string FWUKL1_PARSER_FUNCTION      = ".ParserFunction";
/*! The function used to parse the register input. */
const string FWUKL1_PARSER_INFO          = ".ParserInfo";
/*! This is the function to use to read or write the information to or from the hardware or database. */
const string FWUKL1_ACCESS_FUNCTION      = ".AccessFunction";
/*! This information is used to valid date the resulting register data to see if any warnings are associated with the value. */
const string FWUKL1_LIMITS_INFO          = ".LimitsInfo";

/*! This is used to define the name of the group of registers that are in the Egress FPGA configuration group.*/
const string FWUKL1_EGRESS_CONFIG_GROUP = "EgressConfig";
/*! This is used to define the name of the group of registers that are in the Egress FPGA status group.*/
const string FWUKL1_EGRESS_STATUS_GROUP = "EgressStatus";
/*! This is used to define the name of the group of registers that are in the Ingress FPGA configuration group.*/
const string FWUKL1_INGRESS_CONFIG_GROUP = "IngressConfig";
/*! This is used to define the name of the group of registers that are in the Ingress FPGA status group.*/
const string FWUKL1_INGRESS_STATUS_GROUP = "IngressStatus";
/*! This is used to define the name of the group of registers that are in the input channel configuration group.*/
const string FWUKL1_CHANNEL_CONFIG_GROUP = "ChannelConfig";
/*! This is used to define the name of the group of registers that are in the all input channel configuration group.*/
const string FWUKL1_ALL_CHANNEL_CONFIG_GROUP = "AllChannelConfig";
/*! This is used to define the name of the group of registers that are in the input channel status group.*/
const string FWUKL1_CHANNEL_STATUS_GROUP = "ChannelStatus";
/*! This is used to define the name of the group of registers that are in the GBE configuration group.*/
const string FWUKL1_GBE_CONFIG_GROUP = "GbeConfig";
/*! This is used to define the name of the group of registers that are in the GBE status group.*/
const string FWUKL1_GBE_STATUS_GROUP = "GbeStatus";
/*! This is used to define the name of the group of registers that are in the GBE port configuration group.*/
const string FWUKL1_GBE_PORT_CONFIG_GROUP = "GbePortConfig";
/*! This is used to define the name of the group of registers that are in the GBE port status group.*/
const string FWUKL1_GBE_PORT_STATUS_GROUP = "GbePortStatus";
/*! This is used to define the name of the group of registers that are in the TTCrx configuration group.*/
const string FWUKL1_TTCRX_CONFIG_GROUP = "TtcrxConfig";
/*! This is used to define the name of the group of registers that are in the TTCrx status group.*/
const string FWUKL1_TTCRX_STATUS_GROUP = "TtcrxStatus";
/*! This is a sub-group which contains all the relevant TFC status bits. */
const string FWUKL1_TFC_STATUS_GROUP = "TfcStatus";
/*! This is a sub-group all the status registers that are archived and should trigger alarms. */
const string FWUKL1_ALARM_STATUS_GROUP = "AlarmStatus";
/*! This is a sub-group for the status registers for the Ingress to Egress link on the Egress FPGA. */
const string FWUKL1_E_IN_LINK_STATUS_GROUP = "EgressIngressLinkStatus";
/*! This is a sub-group for the MEP building and transmission status. */
const string FWUKL1_MEP_STATUS = "EgressMEPStatus";
/*! This is the sub-group for the UKL1 EPROM registers. */
const string FWUKL1_PROM_GROUP = "Prom";
/*! This is the sub-group for the sensors on the UKL1 board. */
const string FWUKL1_SENSOR_GROUP = "Sensor";
/*! This is the sub-group for the registers that are displayed on the overview panel. */
const string FWUKL1_OVERVIEW_GROUP = "Overview";

/*! This is a NULL hardware register for those that do not have them. */
const string FWUKL1_NULL_HWREG = "NullRegister";
/*! This is the name of the DP node for the FGPGA configuration settings. */
const string FWUKL1_FPGA_CONFIG_HWTYPE = ".FpgaConfig";
/*! This is the name of the DP node for the FGPGA status settings. */
const string FWUKL1_FPGA_STATUS_HWTYPE = ".FpgaStatus";
/*! This is the name of the DP node for the UKL1 PROM register settings. */
const string FWUKL1_PROM_HWTYPE = ".PROM";
/*! This is the name of the DP node for the UKL1 temperature sensors. Needs to have the sensor number appended. */
const string FWUKL1_SENSOR_HWTYPE = ".Sensors";
/*! This is the name of the DP node for the UKL1 TTCrx registers. */
const string FWUKL1_TTCRX_HWTYPE = ".TTCRX";
/*! This is the name of the DP node for the UKL1 GBE registers. */
const string FWUKL1_GBE_HWTYPE = ".GBE";
/*! This is the name that must be added to the GBE type to get the GBE port DP node. It must have the port number appended. */
const string FWUKL1_GBE_PORT_HWTYPE = ".PORT";
/*! This is the name we use to indicate a function is write only and present read attempts. */
const string FWUKL1_WRITE_ONLY = "fwUkl1_writeOnly";
/*! This is the name we use to indicate a function is ready only and prevent write attempts. */
const string FWUKL1_READ_ONLY = "fwUkl1_readOnly";

// @}

// ==================
//  UKL1 BOARD SETUP
// ==================

/** @defgroup SectionSetup Board setup
 *    The functions in this section are responsible for setting up the software object that represents a UKL1 board.
 *    It provides a function that is capable of dynamically adding or removing the UKL1 board(s) from the system.
 *    An added board is then ready to use via the FSM and is visible in the appropriate places.
 *    The ability to manually add/delete UKL1 boards from the system is also provided, by the User must take care that
 *    they are adding/removing a valid UKL1 board to or from the system. None existent boards can be added to the system.\n
 *    UKL1 boards can be identified via their ID number and a function is provided that is capable of identifying UKL1
 *    production and prototype boards. It is via this function that the fwUkl1_findAndAddUkl1Boards() identifies UKL1
 *    boards from all the CCPCs present in the DIM server.
 *  @{
 */

/*!
 * Gets the names off all the CCPCs found in the DIM server and then identifies the UKL1 boards based on their ID number.
 * It will then add boards that are found to the system. It is also capable of removing boards that are found in the system
 * but no longer present in DIM.
 *
 * \param  refresh If TRUE the list existing list of UKL1 boards will be updated with any new boards found and those
 *           no longer present will be removed. FALSE all existing boards will be deleted along with their associated
 *           settings and the whole list created from new. The Hugin, FSM CU, FSMConfDB object and the abstract register
 *           list data point will all be left untouched.
 * \param  forceReconfigure If TRUE it will recreate the default settings from those hardcoded into the file and
 *           reconfigures the harware data point from these settings. If FALSE the settings are just loaded from the defaults.
 *           In the case of the FSM tree if TRUE it will force the DU, CU and FSMConfDB settings to all be updated.
 *           This won't cause the FSM tree to be restart unless there are DU's added to the tree. The Hugins will always
 *           be left alone. Finally if true then it will cause the abstract register list's data point to be reloaded
 *           from the hardcoded settings.
 * \param  showProgress If TRUE then the fwShowProgressBar() will be called indicating the progress of the function.
 *           If FALSE it will not be called, this is useful when running from a PVSS00ctrl or similar manager which do not have
 *           access to graphics functions.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * forceReconfigure and refresh are independent and forceReconfigure=True does not mean that all the existing boards will be
 * updated, only those new boards found in the system.
 *
 * This function reports its progress via fwShowProgressBar() and thus fwOpenProgressBar() can be called to monitor its progress.
 * It does not submit a percentage completion however and can only be used with types 1 and 3 with fwOpenProgressBar().
 */
void fwUkl1_findAndAddUkl1Boards(bool refresh, bool forceReconfigure, bool showProgress, dyn_string& exceptionInfo) {
  // Note the size of the exception info.
  int exInfoSize = dynlen(exceptionInfo);
  // Holds the list of CCPC names retrieved.
  // First get a list of presently registered CCPCs in the DIM server, retrieving the appropriate system name.
  dyn_string ccpcList;
  fwCcpc_get(ccpcList);
  // Save the total number found for later use.
  const int numCcpc = dynlen(ccpcList);
  // Filter the CCPC names to determine, which of these are actually UKL1 boards.
  // Holds the names of the found UKL1 boards.
  dyn_string toBeAddedUkl1List;
  // Holds the version number of the found UKL1 boards.
  dyn_uint versionList;
  // Keep track of the number of UKL1 boards added to the list, start from 1 due to PVSS array silliness.
  unsigned numUkl1Added = 1;
  // Loop over all the found CCPCs.
  for (unsigned ccpc = 1; ccpc <= numCcpc; ++ccpc) {
    // Name of the CCPC currently being checked.
    const string ccpcName = ccpcList[ccpc];
    // Check to see if it is a production or prototype.
    // Ignore the return as it will probably just indicate a prototype anyway...
    int isUkl1;
    string serialNumber;
    fwUkl1_isUkl1Board(ccpcName, isUkl1, serialNumber, exceptionInfo);
    fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_findAndAddBoards(): Adding board without a serial number to the system.", "2", exInfoSize);
    
    // At the moment we can ignore any errors as if they do occur it means that we probably have the prototype board.
    // Eventually this will need to be checked properly.
    if ( 0 != isUkl1 ) {
      // Add the name of the board to the list of UKL1 names.
      toBeAddedUkl1List[numUkl1Added] = ccpcName;
      // Add constant to declare whether we are dealing with a production or prototype board.
      versionList[numUkl1Added] = isUkl1;
      // Increment the number added.
      ++numUkl1Added;
      // Indicate our progress.
      if (showProgress)
        fwShowProgressBar("Identified " + ccpcName + " with serial number 0x" + serialNumber + " as a UKL1 board.");
    }// if(0!=isUkl1) Don't do anything for else as we are just not interested in this board.
  }// CCPC for

  // Produce a warning message if we failed to find any UKL1s or even CCPCs.
  if ( 0 == numCcpc ) {
    exInfoSize = fwUkl1Exception_raise(exceptionInfo, "WARNING", "fwUkl1_findAndAddBoards(): No CCPCs found in the DIM server.", "2");
  }// if(0==numCcpc)
  else if ( 0 == dynlen(toBeAddedUkl1List) ) {
    exInfoSize = fwUkl1Exception_raise(exceptionInfo, "WARNING", "fwUkl1_findAndAddBoards(): No UKL1 boards found, but found " + numCcpc + " CCPCs in the DIM server.", "2");
  }// elseif(0==dynlen(toBeAddedList))
  // If we didn't find anything then the rest of this section is doesn't really need to be done, but it won't do anything anyway.

  // Now we have a list of UKL1 boards in the system lets deal with them.
  // The variable toBeAddedList holds the names of the UKL1 boards that need to be added to the library.
  // This always need to contain all the found boards as we always need to check the datapoints for consistency
  // and ensure the relevant DIM and FSM functionality is established.
  // The function fwUkl1_addUkl1Board will ensure that the minimum possible is done depending on calling arguments.

  // Holds the names of the UKL1 boards that need to be removed from the library. It will either be those that are
  // no longer present after a refresh or all of them in the case of a reload.
  dyn_string toBeDeletedUkl1List;
  // Just find the new boards in the system and those that have been lost.
  if (refresh) {
    // Reset the number added.
    numUkl1Added = 1;
    // Look through the list of existing names and check for those that need to be deleted.
    // Get the list.
    const dyn_string currentList = fwUkl1_getUkl1NamesList(exceptionInfo);
    const int curListSize = dynlen(currentList);
    for (int board = 1; board <= curListSize; ++board) {
      // Check all the names in the library and check if they are still present in the new server list.
      if ( 0 == dynContains(toBeAddedUkl1List, currentList[board]) ) {
	// If they are not present they need to be deleted.
	toBeDeletedUkl1List[numUkl1Added] = currentList[board];
        if (showProgress)
          fwShowProgressBar("Deleting " + currentList[board] + ".");
      }// if(0==dynContains())
    }// for board
  }// if (refresh).
  else {
    // In this case we are starting afresh and can just remove any existing settings from 
    toBeDeletedUkl1List = fwUkl1_getUkl1NamesList(exceptionInfo);
    if (showProgress)
      fwShowProgressBar("Deleting " + toBeDeletedUkl1List);
    // Will return an empty list in the event of an error. We will just have to see why later.
  }// else (refresh)

  // We will also delete any incomplete boards that are found in the system. They can always go.
  // Give all the incomplete names to the delete FSM DU and HW DP functions as they can handle a name
  // not exisiting.
  // Just return empty arrays in the event of failure so don't worry about errors.
  dynAppend(toBeDeletedUkl1List, fwUkl1_getUkl1HwDpNamesOnlyList(exceptionInfo));
  dynAppend(toBeDeletedUkl1List, fwUkl1_getUkl1FsmTreeNamesOnlyList(exceptionInfo));

  // Delete those boards that need to be deleted.
  if ( 0 != dynlen(toBeDeletedUkl1List) ) {
    // Exception info won't be checked after this call as we will continue anyway, just let the panel deal with the exceptions.
    fwUkl1_deleteUkl1Boards(toBeDeletedUkl1List, showProgress, exceptionInfo);
    fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_findAndAddBoards(): Failed to delete all the requested boards from the system.", "2", exInfoSize);
  }// if(0!=dynlen(toBeDeletedUkl1List))

  // Add those boards that need to be added and add them in ascending order so they look nicer in the FSM.
  dynSortAsc(toBeAddedUkl1List);
  if ( 0 != dynlen(toBeAddedUkl1List) ) {
    // Exception info won't be checked after this call as we will continue anyway, just let the panel deal with the exceptions.
    fwUkl1_addUkl1Boards(toBeAddedUkl1List, versionList, forceReconfigure, showProgress, exceptionInfo);
    fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_findAndAddBoards(): Failed to all the requested boards to the system.", "2", exInfoSize);
  }// if(0!=dynlen(toBeAddedUkl1List))
  
  // Finally check the abstract register DP and update if necessary.
  _fwUkl1_updateAbstractRegisterDP(forceReconfigure, showProgress, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_findAndAddBoards(): Failed to create/update the abstract register data point. This could prevent access to some/all of the registers.", "2", exInfoSize);

  // Found and added all the boards!
  if (showProgress)
    fwShowProgressBar("Create UKL1 list.");
  return;
}// fwUkl1_findAndAddUkl1Boards()

/*!
 * Checks the given CCPC to see if it attached to UKL1 board. It identifies the board by the serial number accessible via
 * the I2C bus.
 *
 * \param  ccpcName Name of the CCPC as found in the DIM server.
 * \param  isUkl1 Returned by reference, there are three possible values:
 *   \li FWUKL1_PRODUCTION The board is a UKL1 production board.
 *   \li FWUKL1_PROTOTYPE The board is a UKL1 prototype board.
 *   \li 0 The board is not a UKL1.
 * \param  serialNumber Returned by reference, the serial number of the found board. Returns:
 *   \li Serial number of found board, whether UKL1 or not.
 *   \li Prototype in the event that it is a prototype without a working PROM. This will occur in preference to fail in the event of an error!
 *   \li Fail if an error occurred.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * There exists a UKL1 prototype that did not have a working PROM and as such no serial number can be read. In this case the
 * an exception is returned, but isUkl1 will indicate that it is a prototype and will return `PROTOTYPE' for the serial number.
 * This should be treated with suspicion especially if it is known that there are no prototype boards in the system. It will
 * eventually be `retired' and this function will need to be updated.
 */
void fwUkl1_isUkl1Board(string ccpcName, unsigned& isUkl1, string& serialNumber, dyn_string& exceptionInfo) {
  // Attempt to read the serial number from the given CCPC. All boards should have this identifier in the same place.
  // This cannot be done through a fwUkl1_read as that assumes the existence of the relevant hardware data point.
  // We can't assume it exists as we want to check if the board is a UKL1 before creating it!
  // Use the fwCcpc library I2C read function. It should be on bus 0 at address 0x50, sub-address 0. It is 32-bits big (4-bytes)
  // and we will assume an infinite page size as it doesn't really matter.
  // The bus is not constant as when dealing with prototypes it could be 1, therefore run twice if it isn't found the first time.
  bool found = FALSE;
  int bus = 0;
  const int address=0x50, subAddress=0, size=4, pageSize=-1;
  // We wish the negative acknowledge on address to be enabled.
  const bool nack = TRUE;
  // Holds the read data.
  dyn_char dcData;
  // Holds the status of the read.
  int status;
  do {
    status = fwCcpc_I2CReadSub(ccpcName, bus, address, 0, size, pageSize, FWCCPC_I2C_COMBINED, nack, dcData);
    if (0 == status) {
      // Successfully read the serial number from the CCPC.
      // Indicate we found the board.
      found = TRUE;
      // Is it an UKL1?
      string tmpstr = fwUkl1_convertByteToHexLittleEndian(dcData, exceptionInfo);
      const unsigned ccpcSerNum = fwCcpc_convertHexToDec(tmpstr);
      // If the word is byte swapped then the revision will occupy the 3rd nibble.
      // This we don't care about when identifying the board, hence mask it.
      if ( (0x601 == (ccpcSerNum>>20)) || (0x1060 == (ccpcSerNum&0xF0FF)) ) {
        // Check whether the serial number indicates that it is a production or prototype board.
        if ( (0x00020000 == (ccpcSerNum&0x000F0000)) || (0x0200 == (ccpcSerNum&0x0F00)) )
          isUkl1 = FWUKL1_PRODUCTION;
        else
          isUkl1 = FWUKL1_PROTOTYPE;
        // Convert the serial number to a string.
        serialNumber = fwCcpc_convertDecToHex(ccpcSerNum);
      }// if UKL1 serial number.
      else {
        // The CCPC is not attached to a UKL1, so we must tell everyone.
        isUkl1 = 0;
        serialNumber = fwCcpc_convertDecToHex(ccpcSerNum);
      }// else not a UKL1 serial number.
    }// if(0==status1)
    else if (0 == bus) {
      // Didn't find anything this bus try reading from the next bus.
      ++bus;
    }// elseif(0==bus)
    else {
      // No buses found in the range we are searching. Must not be a UKL1.
      // We no longer support the prototype board without a PROM.
      isUkl1 = 0;
      serialNumber = "Fail";
      fwUkl1Exception_raise(exceptionInfo, "WARNING", "fwUkl1_isUkl1Board(): " + ccpcName + " did not have a PROM on I2C buses 0 or 1 at address 0x50 and is not a UKL1 board.","2");
      // Either we break or set found to TRUE. This seems more honest :)
      break;
    }// else no 
  } while (!found);
  
  // Done.
  return;
}// fwUkl1_isUkl1Board()

/*!
 * Adds a list of UKL1 boards to the system. It creates the hardware datapoint, subscribing it to the DIM server;
 * and adding it to the FSM tree.
 *
 * \param  toBeAddedUkl1List A dyn_string of names of the UKL1 boards as they appear in the DIM server that need to
 *           be added to the system. If a name is already found in the system it will be removed and then readded.
 * \param  versionList FWUKL1_PRODUCTION if the UKL1 board to be added is a production version, FWUKL1_PROTOTYPE
 *           if it is a prototype version.
 * \param  forceReconfigure If TRUE it will force the settings to be manually set and not to be loaded from the defaults
 *           for the fwHw datapoint type. FALSE and the settings are just loaded from the defaults.
 * \param  showProgress If TRUE then the fwShowProgressBar() will be called indicating the progress of the function.
 *           If FALSE it will not be called, this is useful when running from a PVSS00ctrl or similar manager which do not have
 *           access to graphics functions.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * This function reports its progress via fwShowProgressBar() and thus fwOpenProgressBar() can be called to monitor its progress.
 * It does not submit a percentage completion however and can only be used with types 1 and 3 with fwOpenProgressBar().
 */
void fwUkl1_addUkl1Boards(dyn_string toBeAddedUkl1List, dyn_uint versionList, bool forceReconfigure, bool showProgress, dyn_string& exceptionInfo) {
  // Current length of the exception info, used to determine if more errors have appeared.
  int exInfoSize = dynlen(exceptionInfo);

  // Store the number of elements in the list.
  const unsigned numToBeAdded = dynlen(toBeAddedUkl1List);
  // If the list was empty return!
  if ( 0 == numToBeAdded )
    return;

  // Loop over each board adding them to the system.
  string errMsg;
  for (unsigned board = 1; board <= numToBeAdded; ++board) {
    const string ukl1Name = toBeAddedUkl1List[board];
    const unsigned ukl1Version = versionList[board];
    // Create the hardware type datapoint and subscribe it to the DIM server.
    // We want to just load the new datapoint from the HW type defaults and if it does exist then lets delete it.
    _fwUkl1_createHwTypeCCPCUKL1Datapoint(ukl1Name, ukl1Version, forceReconfigure, exceptionInfo);
    // Apparent bug where variables placed in strings are not updated if past directly to functions.
    errMsg = "fwUkl1_addUkl1Boards(): Failed to setup " + ukl1Name + "'s connection with the DIM server. Communication with this UKL1 is not possible.";
    fwUkl1Exception_checkAndRaise(exceptionInfo, "ERROR", errMsg, "2", exInfoSize);
    if (showProgress)
      fwShowProgressBar("Added HW DP for " + ukl1Name + ".");
  }// for each board.

  // Add the boards as device units in the FSM tree.
  _fwUkl1_createUkl1FsmTreeDU(toBeAddedUkl1List, forceReconfigure, showProgress, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "ERROR", "fwUkl1_addUkl1Boards(): Failed to add the boards to the FSM tree list.", "2", exInfoSize);
  
  // Done.
  return;
}// fwUkl1_addUkl1Boards()

/*!
 * Deletes a list of UKL1 boards from the system. It removes the hardware datapoint, unsubscribing it from the DIM server;
 * and removes it from the FSM tree.
 *
 * \param  toBeDeletedUkl1List A dyn_string of names of the UKL1 boards as they appear in the DIM server that need to
 *           be removed from the system.
 * \param  showProgress If TRUE then the fwShowProgressBar() will be called indicating the progress of the function.
 *           If FALSE it will not be called, this is useful when running from a PVSS00ctrl or similar manager which do not have
 *           access to graphics functions.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * This function reports its progress via fwShowProgressBar() and thus fwOpenProgressBar() can be called to monitor its progress.
 * It does not submit a percentage completion however and can only be used with types 1 and 3 with fwOpenProgressBar().
 */
void fwUkl1_deleteUkl1Boards(dyn_string toBeDeletedUkl1List, bool showProgress, dyn_string& exceptionInfo) {
  // Keep track of the size of the exceptionInfo.
  int exInfoSize = dynlen(exceptionInfo);
  // Store the number of elements in the list.
  const unsigned numToBeDeleted = dynlen(toBeDeletedUkl1List);
  // If the list was empty return!
  if ( 0 == numToBeDeleted )
    return;

  // Loop over each board removing them from the system.
  for (unsigned board = 1; board <= numToBeDeleted; ++board) {
    const string ukl1Name = toBeDeletedUkl1List[board];

    // Remove the hardware type datapoint and unsubscribes it from the DIM server.
    // Only remove it if it is not the FSMConfDB object.
    if ( !patternMatch("*_ConfDB", ukl1Name) ) {
      bool bStatus = fwHw_remove(FWUKL1_HW_TYPE, ukl1Name);
      if ( !bStatus )
        exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_deleteUkl1Board(): Failed to remove " + ukl1Name + "'s DIM server subscriptions.", "2");
      if (showProgress)
        fwShowProgressBar("Removed HW DP for " + ukl1Name + ".");
    }// if UKL1 is present in list.
    else
      if (showProgress)
        fwShowProgressBar("Did not unsubscribe the HW DP for " + ukl1Name + " as we believe it is the FSMConfDB object and hence has no subscriptions to unsubscribe.");
  }// for each board.

  // Remove the list of boards to the FSM tree.
  _fwUkl1_deleteUkl1FsmTreeDU(toBeDeletedUkl1List, showProgress, exceptionInfo);
  fwUkl1Exception_checkAndRaise(exceptionInfo, "ERROR", "fwUkl1_deleteUkl1Boards(): Failed to delete the boards from the FSM tree list.", "2", exInfoSize);
  
  // Done.
  return;
}// fwUkl1_deleteUkl1Boards()

/*!
 * Returns the full list of names of UKL1 boards that are present in both the FSM tree and as a HWTypeCCPCUKL1 data point
 * and hence are fully accessible in the system.
 *
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return dyn_string List of all the names of the UKL1 board that has been retrieved.
 */
dyn_string fwUkl1_getUkl1NamesList(dyn_string& exceptionInfo) {
  // This will hold the list to that is returned.
  dyn_string namesList;

  // Get the list of HW DPs in the system.
  dyn_string hwList;
  if ( fwHw_get(FWUKL1_HW_TYPE, hwList) ) {
    // Now we have the hardware list check to see if it is a node. We don't care if it is local or remote, both are >0 so just check that.
    const int numHw = dynlen(hwList);
    // This keeps track of the index in the names list that we wish to add elements for.
    int nameIndex = 1;
    for (int hw = 1; hw <= numHw; ++hw) {
      if ( 0 < fwFsmTree_isNode(hwList[hw]) ) {
	// Add it to the list.
	namesList[nameIndex] = hwList[hw];
	++nameIndex;
      }// if isNode.
      // No need for else we don't keep track here of incomplete names.
    }// for hw.
  }// if(fwHw_get())
  else
    fwUkl1Exception_raise(exceptionInfo, "WARNING", "fwUkl1_getUkl1NamesList(): Failed to retrieve list of UKL1 hardware datapoints in the system, assuming there are none.", "2");

  // Put what ever was retrieved in ascending order to make it look nice.
  dynSortAsc(namesList);
  // Done.
  return namesList;
}// fwUkl1_getUkl1NamesList()

/*!
 * Returns number of UKL1 board names that are currently in the system.
 *
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return unsigned Number of UKL1 boards that are stored in the list, -1 in the event of an error.
 */
int fwUkl1_getNamesListSize(dyn_string& exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  const int size = dynlen(fwUkl1_getUkl1NamesList(exceptionInfo));
  if ( -1 != size ) {
    fwUkl1Exception_checkAndRaise(exceptionInfo, "ERROR", "fwUkl1_getNamesListSize(): Error occurred while retrieving names list.", "1", exInfoSize);
    // Set the size to -1 to indicate an error.
    size = -1;
  }// if(-1!=size)
  else {
    // Indicate PVSS error.
    exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_getNamesListSize(): PVSS encountered an error while determining the size of the list.", "1");
    // Size is -1 so don't worry about it.
  }// else(-1!=size)
  // Done.
  return size;   
}// fwUkl1_getNamesListSize()

/*!
 * Returns the names of the UKL1 board names that are current stored as hardware data points but are not present in the FSM tree.
 *
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return dyn_string List of all the names of the UKL1 board that are present only as hardware data points. Empty if there are none.
 */
dyn_string fwUkl1_getUkl1HwDpNamesOnlyList(dyn_string& exceptionInfo) {
  // This holds the list that is to be returned.
  dyn_string namesList;

  // Get the list of HW DPs in the system.
  dyn_string hwList;
  if ( fwHw_get(FWUKL1_HW_TYPE, hwList) ) {
    // Now we have the hardware list check to see if it is a node. 0 indicates that it is not.
    const int numHw = dynlen(hwList);
    // This keeps track of the index in the names list that we wish to add elements for.
    int nameIndex = 1;
    for (int hw = 1; hw <= numHw; ++hw) {
      if ( 0 == fwFsmTree_isNode(hwList[hw]) ) {
	// Add it to the list.
	namesList[nameIndex] = hwList[hw];
	++nameIndex;
      }// if is not node.
      // No need for else we don't keep track here of complete names.
    }// for hw.
  }// if(fwHw_get())
  else
    fwUkl1Exception_raise(exceptionInfo, "WARNING", "fwUkl1_getUkl1HwDpNamesOnlyList(): Failed to retrieve list of UKL1 hardware datapoints in the system, assuming there are none.", "2");

  // Hopefully this is empty.
  return namesList;
}// fwUkl1_getUkl1HwDpNamesOnlyList()

/*!
 * Returns the names of the UKL1 board names that are current present in the FSM tree, but are not stored as hardware data points.
 *
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return dyn_string List of all the names of the UKL1 board that are present only as hardware data points. Empty if there are none.
 */
dyn_string fwUkl1_getUkl1FsmTreeNamesOnlyList(dyn_string& exceptionInfo) {
  // This holds the list that is to be returned.
  dyn_string namesList;

  // Get the list of children in the FSM tree node.
  // The function also returns by reference the type of each child, CU, LU or DU. We don't care, should only ever be a DU.
  dyn_int junkChildrenTypes;
  dyn_string fsmList = fwCU_getChildren(junkChildrenTypes, fwUkl1_getFSMCUName() );
  // There is a special FSM child called `fwUk1_getFSMCUName()'_confDB, which should not be returned.
  // It will never exist in the hardware, but should always exist in the FSM tree.
  int confDbIndex = dynContains(fsmList, (fwUkl1_getFSMCUName() + "_ConfDB"));
  dynRemove(fsmList, confDbIndex);
  // Now get the list of HW DPs for comparison with.
  dyn_string hwList;
  if ( fwHw_get(FWUKL1_HW_TYPE, hwList) ) {
    // How many FSM children are there? Required to know if we are to loop over them.
    const int numChildren = dynlen(fsmList);
    // This keeps track of the index in the names list that we wish to add elements for.
    int nameIndex = 1;
    for (int child = 1; child <= numChildren; ++child) {
      if ( 0 == dynContains(hwList, fsmList[child]) ) {
	// The FSM child is not present as a harware DP.
	namesList[nameIndex] = fsmList[child];
	++nameIndex;
      }// if is not in the hardware list.
      // No need for else we don't keep track here of complete names.
    }// for children.
  }// if(fwHw_get())
  else
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_getUkl1FsmTreeNamesOnlyList(): Failed to retrieve list of UKL1 hardware datapoints in the system, assuming there are none.", "2");

  // Hopefully this is empty.
  return namesList;
}// fwUkl1_getUkl1FsmTreeNamesOnlyList()

// ============
//   INTERNAL
// ============

/*!
 * This is used to add list of UKL1 boards to the appropriate FSM tree. It will add the UKL1 boards as device units (DUs) under
 * the control unit (CU) defined by the FwUkl1Constants DP.
 *
 * \param  ukl1List Names of UKL1 boards to be added to the FSM tree. Should be as they appear in the DIM server.
 * \param  forceReconfigure If true then it will force the settings to be updated for all of the DU's, the CU and the FSMConfDB
 *           whether they already exist or not. It will not necessarily restart the FSM tree if no boards are added.
 * \param  showProgress If TRUE then the fwShowProgressBar() will be called indicating the progress of the function.
 *           If FALSE it will not be called, this is useful when running from a PVSS00ctrl or similar manager which do not have
 *           access to graphics functions.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * The DUs added to the tree will appear as their DIM server name, with the panel fwUkl1DUOverview.pnl added for
 * User interaction with the hardware. The label for the DUs will be the name of the UKL1 board as it appears in the DIM server.\n
 * The FSM CU node may have to be stopped for this function to complete and the CU node will be restarted once the
 * operation is complete. No other nodes in the tree will be affected.\n
 * The behaviour of this function is outlined below below:
 *   \li If the DU does not exist it will be created. The existing DU's also the CU and FSMConfDB object will be
 *         left alone. If a DU is added the FSM tree node will have been modified and requires it to be stopped and restarted.
 *   \li If forceReconfigure is TRUE the settings for the DUs will be updated as will those for the CU and
 *         FSMConfDB object. This does not require a restart of the FSM tree, only the panels to be reopened. It will also add
 *         any boards that are not already present in the FSM tree.
 *
 * Note that if the CU (as defined by FwUkl1Constants) does not exist then it will be created and the function will proceed as for creation.
 * The function will also refresh the FSM tree list in the device editor and navigator (DEN) and also will display the CU panel which
 * will refresh it if the list changed.
 */
void _fwUkl1_createUkl1FsmTreeDU(dyn_string ukl1List, bool forceReconfigure, bool showProgress, dyn_string& exceptionInfo) {
  // Don't do anything if the list is empty and we are not updating the existing boards.
  if ( !forceReconfigure && (0 == dynlen(ukl1List)) )
    return;
  // Get the name of the FSM CU, exit if it is NULL.
  const string fsmCu = fwUkl1_getFSMCUName();
  if ( "" == fsmCu ) {
    // If the FSM CU is a NULL string then we should not try and add it to the tree whether it exists or not!
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_createUkl1FsmTreeDU(): The name of the FSM CU stored in the UKL1 constants datapoint is empty. The tree has not been created. Please use the Constants configuration panel in the UKL1 administration panel to set the appropriate FSM CU name and try again.", "1");
    return;
  }// if(""!=fsmCu)
  
  // Keep track of the exception information.
  int exInfoSize = dynlen(exceptionInfo);
  // It is possible to call this function and for it to have no effect on the FSM tree node. In this case there is
  // no point in stopping, regenerating and restarting the FSM tree node. This variable is set to true if a restart
  // is required.
  bool restart = FALSE;
  // This flag is used to determine if we should create the DU or not.
  bool createDU = FALSE;
  // This is used to mark if we created a DU so we know we have to update the settings.
  bool addedDU = FALSE;
  // The CU settings will need to be updated if forceReconfigure is set or we add the CU. Determine the latter later.
  bool updateCU = forceReconfigure ? TRUE:FALSE;
  // This flag is used to signal if there is no CU.
  bool noCU = FALSE;
  // Determine if the FSM CU exists.
  const int nodeExists = fwFsmTree_isNode( fwUkl1_getFSMCUName() );
  // If the node does not exist then we must create it.
  if ( 0 == nodeExists ) {
    // Stop the FSM tree to do this. Can't have been stopped by this stage.
    fwFsmTree_stopTree();
    // Tree was stopped will need to regenerate and restart.
    restart = TRUE;
    // Create the node as a control unit (last arg=1) and put it under the root node `FSM'.
    const string createdNode = fwFsmTree_addNode("FSM", fsmCu, "DAQ_Domain_v1", 1);
    if ( "" != createdNode )
      updateCU = TRUE;
    else {
      // Tell everyone we have no CU.
      noCU = TRUE;
      // Failed to create the node, update the status value and tell everyone.
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_createUkl1FsmTreeDU(): Failed to create the control unit \'" + fwUkl1_getFSMCUName() + "\' in the FSM state machine.", "1");
    }// else(""!=createNode)
  }// if(0==nodeExists)

  // The next section can be done regardless of whether the node exist section was called or not,
  // but if it failed then we don't have a CU FSM tree node to add the DUs to so check the status is still good.
  if ( !noCU ) {
    // Loop over all the names given in the ukl1List and determine what is the appropriate behaviour for each.
    const int numUkl1s = dynlen(ukl1List);
    for (int ukl1 = 1; ukl1 <= numUkl1s; ++ukl1) {
      // Get the name of the UKL1 board as it will appear in the FSM.
      const string ukl1FsmName = ukl1List[ukl1];
      // Check whether the DU exists.
      const int duExists = fwFsmTree_isNode(ukl1FsmName);
      // If the node does not exist then we must create it.
      if ( 0 == duExists )
        createDU = TRUE;
      // If we need to create the DU then we best had.
      if ( createDU ) {
        // We need to be stopped by here if we are not already.
	if (!restart) {
          // Must always stop everything.
          fwFsmTree_stopTree();
          // We are going to have to restart now.
          restart = TRUE;
        }// if(!restart)
        // Add the board to the tree as a HwTypeCCPCUKL1 type and as a device unit (last arg=0).
        fwFsmTree_addNode(fwUkl1_getFSMCUName(), ukl1FsmName, "HwTypeCCPCUKL1", 0);
        // Check to see if the node was added.
        const int duPresent = fwFsmTree_isNode(ukl1FsmName);
        if ( 0 != duPresent )
          addedDU = TRUE;
        else
          exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_createUkl1FsmTreeDU(): Failed to add " + ukl1FsmName + " to the FSM tree. Communication with this board will not be possible via FSM.", "2");
      }// if(createDu)
      
      // Update the settings for this DU if we added it or if we are forcing a reconfigure.
      if ( forceReconfigure || addedDU ) {
        fwFsmTree_setNodeLabel(ukl1FsmName, ukl1FsmName);
        fwFsmTree_setNodePanel(ukl1FsmName, "objects/fwUkl1/fwUkl1DUOverview.pnl");
        if (showProgress)
          fwShowProgressBar("Added " + ukl1FsmName + " to the FSM.");
      }// if(forceReconfigure || addedDU)
    }// for(numUkl1s)
  
    // This function will add the configurator object if it does not already exist, and will only update its settings if it does.
    // Do this after creating all the UKL1s incase it adds it to the middle of an existing list. Generally it is going to find its
    // way to the top of all lists.
    _fwUkl1_createUkl1FsmConfiguratorObject(forceReconfigure, exceptionInfo);
    fwUkl1Exception_checkAndRaise(exceptionInfo, "ERROR", "_fwUkl1_createUkl1FsmTreeDU(): Failed to add the FSM configurator object the FSM tree, this will prevent interaction with the configurationDB and recipes may not be loaded correctly.", "2", exInfoSize);
    
    // Now check for and add if necessary the appropropriate hugin board for this RICH.
    // Implement this!
    
    // Check to see if we need to update the CU settings.
    if (updateCU) {
      fwFsmTree_setNodeLabel(fwUkl1_getFSMCUName(), fwUkl1_getFSMCUName());
      fwFsmTree_setNodePanel(fwUkl1_getFSMCUName(), "fwUkl1/fwUkl1CUOverview.pnl");
    }// if(updateCU)
  }// if(!noCU) Don't bother with an else we already have the appropriate status and will have signaled the error.

  // We should only regenerate and restart the FSM tree node if it has actually been stopped and modified.
  if (restart) {
    // Generate the FSM for this CU only.
    fwFsmTree_generateTreeNode( fwUkl1_getFSMCUName() );
    // Start FSM processes for the CU sub-tree
    fwFsmTree_startTree();
  }// if(restart)

  // Refresh the Tree in case the DEN is running, this can be done regardless. It ensures that the tree display is correct.
  fwFsmTree_refreshTree();
  // Don't try and view the CU panel as if it is run in a script in the console it has no concept of a UI and ths can't start it.

  // Now we are done.
  return;
}// _fwUkl1_createUkl1FsmTreeDU()

/*!
 * This is used to delete a list UKL1 boards from the appropriate FSM tree. It will look in the tree fwUkl1_getFSMCUName()
 *
 * \param  ukl1List List of names of UKL1 boards to be deleted from the FSM tree. Names should be as they appear in the DIM server.
 * \param  showProgress If TRUE then the fwShowProgressBar() will be called indicating the progress of the function.
 *           If FALSE it will not be called, this is useful when running from a PVSS00ctrl or similar manager which do not have
 *           access to graphics functions.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_deleteUkl1FsmTreeDU(dyn_string ukl1List, bool showProgress, dyn_string& exceptionInfo) {
  if ( 0 == dynlen(ukl1List) )
    return;
  
  int exInfoSize = dynlen(exceptionInfo);
  // First we must determine if the fwUkl1_getFSMCUName() node exists in the FSM tree.
  const int nodeExists = fwFsmTree_isNode( fwUkl1_getFSMCUName() );
  // Does the node we wish to delete from exist?
  if ( 0 != nodeExists ) {
    // The node exists, either locally or remotely.
    // Stop it so we can edit it, accept the default of stopping all children.
    fwFsmTree_stopTree();
    // Loop over all the names given in the ukl1List and determine what is the appropriate behaviour for each.
    const int numUkl1s = dynlen(ukl1List);
    const string fsmConfDBName = fwUkl1_getFSMCUName() + "_ConfDB";
    const string huginName     = fwUkl1_getHuginName();
    for (int ukl1 = 1; ukl1 <= numUkl1s; ++ukl1) {
      // Convert the ukl1Name into the name as it will appear in the FSM.
      const string ukl1FsmName = ukl1List[ukl1];
      // Check whether the DU exists.
      const int duExists = fwFsmTree_isNode(ukl1FsmName);
      if ( 0 != duExists ) {
        // Check to see if we are dealing with the FSMConfDB object, hugin or a normal board.
        switch (ukl1FsmName) {
          case fsmConfDBName:
            if ( -1 == fwFSMConfDB_removeConfigurator(fwUkl1_getFSMCUName(), fwUkl1_getFSMCUName() + "_ConfBD") )
              exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_deleteUkl1FsmTreeDU(): Failed to delete " + ukl1FsmName + " from the FSM tree.", "2");
            break;
          
          case huginName:
            // Implement - don't want to do this all the time!
            break;
            
          default:
            // The default case is a UKL1 board.
            // Remove the DU from the tree, accept the default of removing a node recursively from the tree as the DU shouldn't have any children!
            fwFsmTree_removeNode(fwUkl1_getFSMCUName(), ukl1FsmName);
            // Check the DU was actually deleted.
            if ( 0 == fwFsmTree_isNode(ukl1FsmName) )
              if (showProgress)
                fwShowProgressBar("Removed " + ukl1FsmName + " from FSM.");
            else
              exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_deleteUkl1FsmTreeDU(): Failed to delete " + ukl1FsmName + " from the FSM tree. There is no physical board in the crate, but it will still appear in the FSM tree.", "2");
            break;
        }// switch(ukl1FSMName)
      }// if(0==duExists)
      else
        if (showProgress)
          fwShowProgressBar(ukl1FsmName + " is not present in the FSM tree to remove.");
    }// for(numUkl1s)

    // Only any point of doing this if the node exists.
    // Generate the FSM for CU.
    fwFsmTree_generateTreeNode( fwUkl1_getFSMCUName() );
    // Start FSM processes for the CU sub-tree. We could have deleted only a couple of boards.
    fwFsmTree_startTreeNode( fwUkl1_getFSMCUName() );
    // Refresh the Tree in case the DEN is running, this can be done regardless.
    fwFsmTree_refreshTree();
    // Don't try and reopen the CU, we might not be able to achieve that if we are running in a console script.
  }// if(0!=nodeExists)
  else {
    // The node does not exist so we cannot delete any boards. Warn people, it will happen on a fresh install though.
    exInfoSize = fwUkl1Exception_raise(exceptionInfo, "WARNING", "_fwUkl1_deleteUkl1FsmTreeDU(): UKL1 control unit `" + fwUkl1_getFSMCUName() + "' not found. UKL1 FSM tree does not exist, cannot remove UKL1 boards from a none existant FSM tree.", "1");
  }// else(0!=nodeExists)

  // Done.
  return;
}// _fwUkl1_deleteUkl1FsmTreeDU()

/*!
 * This will create and configure an FSM configurationDB configurator object for the UKL1 control unit in the FSM tree.
 *
 * \param  forceReconfigure If this is TRUE then the setting for the configurator object will be updated even if it already
 *           exists. If it is FALSE then if the configurator exists then no changes will be made to it.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void
 *
 * If the object already exists then this function will only update the settings for the object. There is no single function
 * provided by the framework to do this and as such some code is taken straight from the FSMConfDB configuration panel.
 */
void _fwUkl1_createUkl1FsmConfiguratorObject(bool forceReconfigure, dyn_string &exceptionInfo) {
  // Used to keep track of errors.
  int exInfoSize = dynlen(exceptionInfo);
  // This is the name of the DP that will hold the confDB object.
  const string dpName = fwFSMConfDB_getConfiguratorName(fwUkl1_getFSMCUName(), "_ConfDB");
  // This is used to indicate if the configurator exists.
  bool fsmConfDBExists = TRUE;
  // This is used to indicate if it has been created.
  bool fsmConfDBCreated = FALSE;
  
  // Lets check to see if the object already exists, if it doesn't then try and create it.
  if ( !dpExists(dpName) ) {
    // Call the function to add the configurator object. The domain is just the name of the CU.
    // If it is added potentially over ride the forceReconfigure value to ensure the settings are updated.
    if( 0 == fwFSMConfDB_addConfigurator( fwUkl1_getFSMCUName(), FWUKL1_FSMCONFDB_TYPE) )
      fsmConfDBCreated = TRUE;
    else
      fsmConfDBExists = FALSE;
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_createUkl1FsmConfiguratorObject(): Failed to add the configurator object to the UKL1 FSM tree. Call fwFSMConfDB_addConfigurator returned -1.", "1");
  }// if(!dpExists())
  // The exists flag is already set to TRUE and created to FALSE.
  // If there was problem making it exist then it will have been flagged.

  // If the FSMConfDB object exists then we should configure it.
  if ( fsmConfDBExists && (fsmConfDBCreated || forceReconfigure) ) {
    // These are the recipes that are used for start and stop. They are entered as user recipes, so they
    // are not associated with any mode.
    const dyn_string userRecipes = makeDynString("Start", "Stop");
    // Now update the settings for the configurator object.
    if ( 0 != dpSet(dpName + ".applyRecipes.usingConfigurator", FWUKL1_CONFIGURATOR_APPLY_RECIPES,
                    dpName + ".applyRecipes.timeout", FWUKL1_CONFIGURATOR_TIMEOUT,
                    dpName + ".applyRecipes.simplifiedAR", FWUKL1_CONFIGURATOR_SIMPLIFIED_AR,
                    dpName + ".useConfDB", fwUkl1_getConfiguratorUseConfDBFlag(),
                    dpName + ".userRecipes", userRecipes) )
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_createUkl1FsmConfiguratorObject(): Failed to update the configuration settings for the FSMConfDB object. It may not be properly configured, please check these manually. dpSet failed.", "2");
  }// if(fsmConfDBExists)

  // Done.
  return;
}// _fwUkl1_createUkl1FsmConfiguratorObject()

/* !!!!!!!!!!!!!!!!!!!!Does not work!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! */
/*!
 * This function will add the necessary Hugin to the UKL1 FSM tree underneath the CU if it is not already present.
 *
 * \param  forceReconfigure If TRUE then the Hugin node will be readded to the FSM tree, if FALSE then if the Hugin
 *           is already present it will be left as it is.
 * \param  exceptionInfo Error Information. No change in size if no exception information is generated.
 * \return void.
 *
 * The Hugin added will be the one defined by the Hugin name in the UKL1 constants DP. If the name is an empty string
 * then no Hugin will be added. Further is it is an empty string then no Hugin will be checked for either.
 */
void _fwUkl1_createHuginFsmNode(bool forceReconfigure, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // Name of the hugin we are interested in.
  const string huginName = fwUkl1_getHuginName();
  // This indicates if the Hugin exists.
  bool huginExists  = TRUE;
  // This indicates if the Hugin was created.
  bool huginCreated = FALSE;
  
  const int nodeExists = fwFsmTree_isNode(huginName);
  if ( 0 == nodeExists ) {
    // The Hugin is not already present and it should be attempted to be added.
    // First check to see if the Hugin type is already present in the system.
    dyn_string types = fwFsm_getDps("*","_FwFsmObjectType");
    if ( 0 == dynContains(types, FWUKL1_HUGIN_TYPE) ) {
      fwFsmTree_importType(FWUKL1_HUGIN_TYPE, FWUKL1_TFC_SYS_NAME);
      // Now check to see if it was added.
      types = fwFsm_getDps("*","_FwFsmObjectType");
      if ( 0 < dynContains(types, FWUKL1_HUGIN_TYPE) ) {
        // This is currently a secret, need to ask Clara how to do this properly!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
//         fwFsmTree_addNode(fwUkl1_getFSMCUName(), huginName, FWUKL1_HUGIN_TYPE, 0);
      }// if(0<dynContains())
      else {
        exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_createHuginFsmNode(): Failed to import the Hugin FSM object type into the system. Cannot add the Hugin node to the UKL1 FSM tree.", "2");
        huginExists = FALSE;
      }// else(0<dynContains())
    }// if(0==dynContains(types, FWUKL1_HUGIN_TYPE))
  }// if(0==nodeExists)

  // Not finished!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  if ( fsmConfDBExists && (fsmConfDBCreated || forceReconfigure) ) {
  }
  
  // Done.
  return;
}// _fwUkl1_createHuginFsmNode()

/*!
 * This create if necessary the abstract register data point, which contains the information about how to convert
 * the abstract register displayed in the panel into the hardware registers written with DIM to the UKL1s.
 *
 * \param  forceReconfigure If TRUE then the data point elements will be updated from the library settings,
 *           if FALSE then if the data point elements will not be updated.
 * \param  showProgress If TRUE then the fwShowProgressBar() will be called indicating the progress of the function.
 *           If FALSE it will not be called, this is useful when running from a PVSS00ctrl or similar manager which do not have
 *           access to graphics functions.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * In the event that the DP does not exist then it will always be created regardless of the forceReconfigure.
 */
void _fwUkl1_updateAbstractRegisterDP(bool forceReconfigure, bool showProgress, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // If the data point does not exist then we must create it.
  if (!dpExists(FWUKL1_UKL1_BOARD_DP_NAME)) {
    // If it doesn't exist then we must create it.
    // Quote PVSS help: "dpCreate() returns 0, in the event of a failure returns -1. 
    //                   The function possibly returns 0 also in the event of a failure.
    //                   In this case errors can only be retrieved with getLastError()!"
    // Nice. Use getLastError() to determine if the DP creation was successful.
    // Don't bother to try and create it on a specific system, it is not necessarily correct
    // when this is called. For example during the init routine where the library won't have
    // been reloaded with the appropriate system number.
    dpCreate(FWUKL1_UKL1_BOARD_DP_NAME, FWUKL1_UKL1_BOARD_DPT_NAME);
    // Doubt it is thread safe...
    dyn_errClass error = getLastError();
    if (0 != dynlen(error)) {
      // Couldn't create the data point.
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "FATAL", "_fwUkl1_updateAbstractRegisterDP(): Failed to create the UKL1 abstract register interface DP, it is not possible to access any of the UKL1 registers or recipes via the panels. The FSM will still work. Check the DPT \'" + FWUKL1_UKL1_BOARD_DPT_NAME + "\' exists.", "1");
      // Without the datapoint there is little point trying to do anything.
      return;
    }// if dpCreate() failed
    // Set forceReconfigure TRUE to ensure that we update the settings.
    forceReconfigure = TRUE;
  }// if(!dpExists())
  
  // Now we will update the settings only if forceReconfigure is true.
  if (forceReconfigure) {
    // Update the list of registers that we can use.
    _fwUkl1_updateAbstractRegisterListDPE(exceptionInfo);
    fwUkl1Exception_checkAndRaise(exceptionInfo, "", "_fwUkl1_updateAbstractRegisterDP(): Failed to update/set the list of abstract registers in the system. This will likely prevent any registers from being accessed either on the hardware or in the configuration DB.", "2", exInfoSize);
    // For each of the registers in the abstract register list we must set the individual elements.
    // Some useful constants.
    const string ccpcStartMonitoringFunc = "fwCcpc_startMonitoring";
    const string ccpcStopMonitoringFunc = "fwCcpc_startMonitoring";
    const string baseWrite = "_fwUkl1_write"; // This is the 'standard' write function.
    const string baseRead  = "_fwUkl1_read"; // This is the 'standard' read function.
    const string baseSave = "_fwUkl1_save"; // This is the 'standard' save function.
    const string baseLoad  = "_fwUkl1_load"; // This is the 'standard' load function.
    // This is the name of the register being set.
    string registerName;
    // The map that contains the values to write for each DPE.
    mapping registerValues;
    // Now set the values, this is just a long tedious list. For the errors just use what ever exceptionType is used.
    // FPGA config registers.
    registerName = "MacDestinationAddress";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ffffffffffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "MAC address of the farm that the data will be sent to. Only used if a fixed destination address is used. Colon delimited value.";
    // HW read.
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_FPGA_CONFIG_HWTYPE + ".MacDestinationAddress";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToMac";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    // HW write.
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION] = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertMacToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    // DB read.
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    // DB write.
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    // Monitoring
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_CONFIG_HWTYPE + ".MacDestinationAddress");
    
    registerName = "MacSourceAddress";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ffffffff0000";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Base MAC address of the GBE ports on the UKL1s. UKL1 sets remaining two bytes. Colon delimited value.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToMac";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertMacToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "IpDestinationAddress";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ffffffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "IP address of the farm that the data will be sent to. Only used if a fixed destination address is used. Standard IPv4 format.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToIp";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertIpToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "IpSourceAddress";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ffffff00";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Base IP address of the GBE ports on the UKL1s. UKL1 sets the last section to a RICH specific value. Standard IPv4 format.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToIp";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertIpToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "PartitionId";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "ffffffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Bit mask indicating which sub-detectors are present during the run. It is defined by the top level run control typically. Hex.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,32";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "Protocol";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Ethernet protocol that used for transporting the MEPs over TCP/IP. Hex.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TypeOfService";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Type of service value that will be put in the IP header. Hex.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TimeToLive";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Time to live field in the IP header. Length of time (seconds) an IP fragment can exist in the network before reaching the destination. Hex.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "Type";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Type field in the IP header. Hex.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,16";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "Version";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Version field in the IP header. Hex.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TfcLatencyCompensation";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "fff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of clock cycles the Egress FPGA waits before sending TFC commands to the Ingress FPGAs. Compensates for transit time of TFC commands to the L0s and the L0 data to L1. Accurate value for this setting is not required. Hex.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,12";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "L1Id";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Unique identifier for the UKL1 board. Corresponds to the last byte of the serial number stored in the EPROM. Hex.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "MepEventCount";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "000f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of events placed into a Multi-Event Packet (MEP) before closing for transimission. Only valid if Don't Wait for Destination Broadcast is set. Dec.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwCcpc_convertDecToHex";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,16";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "MTU";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "3fff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Maximum Transmission Unit (MTU) size. Determines the maximum size of any packets sent over the network. Dec.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwCcpc_convertDecToHex";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,14";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "MepTruncationHighWatermark";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Maximum size a MEP can reach before forcibly closed. Dec.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwCcpc_convertDecToHex";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,16";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "ManualMepGbeOutputPortNumber";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "3";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Port that will be used to send MEPs. Only valid if the Manual GBE Port is set. Dec.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "8";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwCcpc_convertDecToHex";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,2";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "ThrottleMode";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Throttle operation depends on the readout mode. LHCb or ALICE. This must be set the same to the readout mode in the Ingress FPGA configuration.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "4;ALICE,1;LHCb,0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,1;1,ALICE;0,LHCb";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "ThrottleOutput";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "3";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "The throttle output can be disabled, in which case the TFC will never see the UKL1 throttle being asserted.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "2;Enable,3;Disable,0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "2,2;3,Enabled;0,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "2,2;3,Enable;0,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "ThrottlePolarity";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "3";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "The throttle polarity can be inverted. This defines the polarity that the UKL1 uses to assert a throttle. If inverted it will appear always on.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "4;Invert,3;Normal,0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "4,2;3,Inverted;0,Normal";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,2;3,Invert;0,Normal";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "ForceFixedMepDestinationAddress";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "If enabled then a fixed destination address is used to send the MEPs. Defined in the MAC and IP destination addresses registers.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0;Enable,1;Disable,0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "0,1;1,Enabled;0,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;1,Enable;0,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "MepBuildingMode";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Either the UKL1 will wait for a TFC broadcast to build a MEP or it will do it once a predefined number of MEPs have been received, defined in the packing factor register.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "1;Manual,1;TFC,0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "1,1;1,Manual;0,TFC";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TfcDecoding";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "This enables the decoding of TFC commands. This is required if the UKL1 is to receive triggers, and send and build MEPs.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "6;Enable,1;Disable,0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "6,1;1,Enabled;0,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "6,1;1,Enable;0,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeTpaPolling";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "If enabled then it will poll the enabled GBE ports and send data to those with space available. Must be enabled to send data.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "7;Enable,1;Disable,0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "7,1;1,Enabled;0,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "7,1;1,Enable;0,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "ManualMepGbeOutputPortControl";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "If enabled then the data will be sent to a fixed GBE port defined in the MEP output GBE port.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "10;Enable,1;Disable,0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "10,1;1,Enabled;0,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "10,1;1,Enable;0,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "Ingress0Enable";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "If enabled then data will be read from this Ingress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0;Enable,0;Disable,1";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwEquipmentDisabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "0,1;0,Enabled;1,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;0,Enable;1,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "Ingress1Enable";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "If enabled then data will be read from this Ingress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "1;Enable,0;Disable,1";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwEquipmentDisabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "1,1;0,Enabled;1,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "1,1;0,Enable;1,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "Ingress2Enable";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "If enabled then data will be read from this Ingress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "2;Enable,0;Disable,1";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwEquipmentDisabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "2,1;0,Enabled;1,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "2,1;0,Enable;1,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "Ingress3Enable";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "If enabled then data will be read from this Ingress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "3;Enable,0;Disable,1";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwEquipmentDisabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "3,1;0,Enabled;1,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "3,1;0,Enable;1,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    
    // The FPGA status registers.
    registerName = "TTCId";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "TTC ID.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TFCFIFORequest";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if data is present in the TFC FIFO to be read out.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,1;1,Pending;0,None";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TTCrxReady";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the TTCrx is ready. It should always be ready.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateAttention2;1,FwStateOKPhysics";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "9,1;1,Ready;0,Error";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EventMergerReadState";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "State of the FSM that mergers the events in the Egress FPGA from the front ends.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataLowWordInhibit0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver low data word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataLowWordInhibit1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver low data word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "1,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataLowWordInhibit2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver low data word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "2,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataLowWordInhibit3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver low data word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "3,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataHighWordInhibit0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver high data word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataHighWordInhibit1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver high data word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "5,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataHighWordInhibit2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver high data word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "6,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataHighWordInhibit3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver high data word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "7,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTCommunicationWordInhibit0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver communication word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTCommunicationWordInhibit1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver communication word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "13,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTCommunicationWordInhibit2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver communication word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "14,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTCommunicationWordInhibit3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver communication word link is disabled for this Ingress FPGA. Must be enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "15,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataLinkInhibit0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver data links are disabled for this Ingress FPGA. Will be disabled if the Ingress inhibit bit is set or either data word links.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwEquipmentDisabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataLinkInhibit1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver data links are disabled for this Ingress FPGA. Will be disabled if the Ingress inhibit bit is set or either data word links.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwEquipmentDisabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "9,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataLinkInhibit2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver data links are disabled for this Ingress FPGA. Will be disabled if the Ingress inhibit bit is set or either data word links.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwEquipmentDisabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "10,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTDataLinkInhibit3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the gigabit transceiver data links are disabled for this Ingress FPGA. Will be disabled if the Ingress inhibit bit is set or either data word links.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwEquipmentDisabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "11,1;1,Disabled;0,Enabled";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GBETx";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if data is being transmitted from the Egress FPGA to the GBE card.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;1,Busy;0,Idle";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "MEPFifo";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the MEP FIFO buffers (where MEPs are stored before transmission) are full. They should never be full.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "1,1;1,Full;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "ThrottleAsserted";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "3";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the throttle is currently asserted. In ALICE mode the throttle is asserted for the duration of each event.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;3,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "2,2;3,Asserted;0,Deasserted";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTFIFO0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the FIFO for this Ingress FPGA link is full.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,1;1,Full;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTFIFO1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the FIFO for this Ingress FPGA link is full.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "5,1;1,Full;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTFIFO2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the FIFO for this Ingress FPGA link is full.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "6,1;1,Full;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTFIFO3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the FIFO for this Ingress FPGA link is full.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "7,1;1,Full;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTLowFIFODataReadout0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there the data is being transmitted from the Ingress FPGA on the low data link.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTLowFIFODataReadout1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there the data is being transmitted from the Ingress FPGA on the low data link.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "9,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTLowFIFODataReadout2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there the data is being transmitted from the Ingress FPGA on the low data link.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "10,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTLowFIFODataReadout3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there the data is being transmitted from the Ingress FPGA on the low data link.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "11,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTHighFIFODataReadout0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there the data is being transmitted from the Ingress FPGA on the high data link.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTHighFIFODataReadout1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there the data is being transmitted from the Ingress FPGA on the high data link.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "13,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTHighFIFODataReadout2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there the data is being transmitted from the Ingress FPGA on the high data link.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "14,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTHighFIFODataReadout3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there the data is being transmitted from the Ingress FPGA on the high data link.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "15,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TFCL0Reset";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if an L0 reset is being asserted by the TFC.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;1,Asserted;0,Deasserted";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TFCL1Reset";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if an L1 reset is being asserted by the TFC.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;1,Asserted;0,Deasserted";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TFCShortBroadcast";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "3f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Last short broadcast command received from the TFC.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "2,6";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GBETransmitPortAvailable0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if this GBE port is available to transmit data. Should reflect the GBE port inhibit setting.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwEquipmentDisabled;1,FwBackgroundInputText";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,1;1,Available;0,Inhibited";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GBETransmitPortAvailable1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if this GBE port is available to transmit data. Should reflect the GBE port inhibit setting.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwEquipmentDisabled;1,FwBackgroundInputText";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "9,1;1,Available;0,Inhibited";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GBETransmitPortAvailable2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if this GBE port is available to transmit data. Should reflect the GBE port inhibit setting.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwEquipmentDisabled;1,FwBackgroundInputText";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "10,1;1,Available;0,Inhibited";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GBETransmitPortAvailable3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if this GBE port is available to transmit data. Should reflect the GBE port inhibit setting.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwEquipmentDisabled;1,FwBackgroundInputText";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "11,1;1,Available;0,Inhibited";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EthernetFragmentReady";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if an ethernet fragment has been constructed from the MEP and is ready for transmission.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,1;1,Ready;0,Fragmenting";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "MEPReady";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if a MEP is built.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "13,1;1,Ready;0,Building";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "FragmentRequest";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if a fragment is being extracted from the Egress to the GBE card.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "14,1;1,Requested;0,Inactive";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "MEPExtraction";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if a MEP is being extracted from the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "15,1;1,Active;0,Inactive";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EthernetFormatterState";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "16";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "State of the FSM that formats the events for transmission over ethernet.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,16";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "FragmentExtraction";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if an ethernet fragment is being extracted.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;1,Active;0,Inactive";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "SequenceError";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the UKL1s have seen consequtive triggers. If in consequtive triggers are seen then the data from the L0s is no longer valid.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "1,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "MEPCount";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "3";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of MEPs currently in the MEP buffer.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "2,2";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTFIFOTxWait0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates is the transmission of data from the Ingress data link is suppressed.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTFIFOTxWait1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates is the transmission of data from the Ingress data link is suppressed.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "5,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTFIFOTxWait2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates is the transmission of data from the Ingress data link is suppressed.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "6,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GTFIFOTxWait3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates is the transmission of data from the Ingress data link is suppressed.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "7,1;1,Suspended;0,Active";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TFCFIFOOccupancy";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Occupancy of the FIFO used to stored TFC commands.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TFCLongBroadcast";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "ffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Last long broadcast commnad received from the TFC.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,16";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordSequenceError0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there has been a sequence error on the data received on the low word of this Ingress' input FIFO on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordSequenceError1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there has been a sequence error on the data received on the low word of this Ingress' input FIFO on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "2,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordSequenceError2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there has been a sequence error on the data received on the low word of this Ingress' input FIFO on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordSequenceError3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there has been a sequence error on the data received on the low word of this Ingress' input FIFO on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "6,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordSequenceError0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there has been a sequence error on the data received on the high word of this Ingress' input FIFO on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "1,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordSequenceError1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there has been a sequence error on the data received on the high word of this Ingress' input FIFO on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "3,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordSequenceError2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there has been a sequence error on the data received on the high word of this Ingress' input FIFO on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "5,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordSequenceError3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if there has been a sequence error on the data received on the high word of this Ingress' input FIFO on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwBackgroundInputText;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "7,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "L0TriggerCount";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of L0 trigger commands seen.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "ROTBroadcastCount";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of readout type (ROT) broadcast commands seen.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TFCDestinationCount";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_TFC_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of TFC destination commands seen.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "MEPSequenceCount";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_MEP_STATUS);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of MEPs sent by the UKL1.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TTCrxReadyAlarm";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_ALARM_STATUS_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the TTCrx is ready. Same as the normal TTCrx status register however the DP this is connected to is archived.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateAttention2;1,FwStateOKPhysics";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;1,Ready;0,Error";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "SequenceErrorAlarm";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_ALARM_STATUS_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "1";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates if the UKL1s have seen consequtive triggers. Same as the normal sequence error status register, however this DP is archived.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwStateAttention2";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "1,1;1,Error;0,OK";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordOccupancy0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Occuapncy of the low data word Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordOccupancy1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Occuapncy of the low data word Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordOccupancy2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Occuapncy of the low data word Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordOccupancy3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Occuapncy of the low data word Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordOccupancy0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Occuapncy of the high data word Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordOccupancy1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Occuapncy of the high data word Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordOccupancy2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Occuapncy of the high data word Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordOccupancy3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Occuapncy of the high data word Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordRxCount0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of low data words received from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordRxCount1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of low data words received from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordRxCount2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of low data words received from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordRxCount3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of low data words received from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordRxCount0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of high data words received from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordRxCount1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of high data words received from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordRxCount2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of high data words received from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordRxCount3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of high data words received from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordTxCount0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of low data words transmitted from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordTxCount1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of low data words transmitted from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordTxCount2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of low data words transmitted from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOLowWordTxCount3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of low data words transmitted from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordTxCount0";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of high data words transmitted from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordTxCount1";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of high data words transmitted from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordTxCount2";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of high data words transmitted from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "EgressInputFIFOHighWordTxCount3";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP, FWUKL1_E_IN_LINK_STATUS_GROUP);
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number of high data words transmitted from the Input FIFO from this Ingress FPGA on the Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "12,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;


    // PROM registers
    registerName = "SerialNumber";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_PROM_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "ffffffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Unique number to identify each board.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_I2C;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHexLittleEndian";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByteLittleEndian";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,32;";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "LogicalId";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_PROM_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Number identifying the UKL1 board within the RICH.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_I2C;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHexLittleEndian";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "40";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByteLittleEndian";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "40,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "RichId";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_PROM_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates which RICH the board is on.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_I2C;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHexLittleEndian";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "32";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByteLittleEndian";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "32,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    
    // Sensors.
    registerName = "TemperatureSensorTop";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_SENSOR_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Temperature at the top of the UKL1 board (near Ingress 0).";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_I2C;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "40,FwBackgroundInputText;50,FwStateAttention2;60,FwStateAttention3";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TemperatureSensorMiddle";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_SENSOR_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Temperature in the middle of the UKL1 board.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_I2C;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "40,FwBackgroundInputText;50,FwStateAttention2;60,FwStateAttention3";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "TemperatureSensorBottom";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_SENSOR_GROUP, FWUKL1_OVERVIEW_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Temperature at the bottom of the UKL1 board (near Ingress 3).";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_I2C;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "40,FwBackgroundInputText;50,FwStateAttention2;60,FwStateAttention3";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwUkl1_readOnly";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;


    // TTCrx.
    registerName = "TtcrxControl";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_TTCRX_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Must be set to 0xA1 for the UKL1 to function correctly. Should be done as part of FSM configure command.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    
    // GBE.
    registerName = "GbeJtagId";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "ffffffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Identification number for the GBE JTAG.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = FWUKL1_READ_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,32";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeMACSoftReset";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Resets the four MAC chips.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "fwUkl1_writeOnly";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = FWUKL1_WRITE_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeReceivePortReset";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Resets the receiver ports on the GBE.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "fwUkl1_writeOnly";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = FWUKL1_WRITE_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeTransmitPortReset";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Resets the transmission ports on the GBE.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "fwUkl1_writeOnly";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = FWUKL1_WRITE_ONLY;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeReceiveFifoEnable";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "ff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Enables the pre-pending of two extra bytes to each packet and the CRC stripping. Expert only.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,8";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeMode";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "High for a port to be in copper mode and low for fibre mode.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeClock";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Used to allow changes to be made to the GBE clock.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeSPI3ConfigTrnmtGlobal";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "ffffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "SPI3 (Egress-GBE link) transmiter configuration register.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,24";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeSPI3ConfigRcv";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "fffffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "SPI3 (Egress-GBE link) receiver configuration register.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,28";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeRxStatus";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Expert only.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbePHYCtrl";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "1ffffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Command to be written to the PHY chips.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,21";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbePHYWriteData";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "ffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Data that is to be written to the PHY chips.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,16";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbePHYReadData";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "ffff";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Data that has been read back from the PHY chips.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "16";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "16,16";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    registerName = "GbeMDIOControl";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString();
    registerValues[FWUKL1_MASK] = "f";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Control bits for the MDIO register.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegHexToByte";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,4";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString();
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    
    // Add the port registers for each of the 4 ports.
    string msg;
    for (int port=0; port<FWUKL1_GBE_PORTS; ++port) {
      registerName = "GbePort" + port + "Enable";
      registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_GBE_CONFIG_GROUP);
      registerValues[FWUKL1_MASK] = "1";
      registerValues[FWUKL1_TOOLTIP_TEXT] = ".";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
      registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= port + ";Enable,1;Disable,0";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwEquipmentDisabled;1,FwStateOKPhysics";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
      registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = port + ",1;1,Enabled;0,Disabled";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
      registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
      registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = port + ",1;1,Enable;0,Disable";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
      registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
      registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
      registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

      registerName = "GbePort" + port + "TxFifoThreshold";
      registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_GBE_CONFIG_GROUP);
      registerValues[FWUKL1_MASK] = "ffffffff";
      registerValues[FWUKL1_TOOLTIP_TEXT] = "When the amount of data in the transmit FIFO reaches this threshold the data is transmitted.";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
      registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
      registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
      registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwCcpc_convertDecToHex";
      registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,32";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
      registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
      registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
      registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

      registerName = "GbePort" + port + "TxFifoLowWatermark";
      registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_GBE_CONFIG_GROUP);
      registerValues[FWUKL1_MASK] = "ffffffff";
      registerValues[FWUKL1_TOOLTIP_TEXT] = "The threshold below which automatic flow control on the GBE port is turned off. Bytes.";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
      registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
      registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
      registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwCcpc_convertDecToHex";
      registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,32";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
      registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
      registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
      registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

      registerName = "GbePort" + port + "TxFifoHighWatermark";
      registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_GBE_CONFIG_GROUP);
      registerValues[FWUKL1_MASK] = "ffffffff";
      registerValues[FWUKL1_TOOLTIP_TEXT] = "The threshold above which the automatic flow control on the GBE port is enabled. Bytes";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_GBE;
      registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegHex";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0";
      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
      registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
      registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "fwCcpc_convertDecToHex";
      registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,32";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
      registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
      registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
      registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

    }// for port
    
    // Input channels.
    // For these registers we must use a special write.
    string baseChannelWrite = "_fwUkl1_writeIngressFpgaChannel";
    // Monitoring has not been implemented yet.
    string fifoStartMonitoringFunc = "fwUkl1_startFifoMonitoring";
    string fifoStopMonitoringFunc = "fwUkl1_stopFifoMonitoring";
    int offset;
    for (int inFpga=0; inFpga<FWUKL1_FRONT_FPGAS; ++inFpga) {
      for (int channel=0; channel<FWUKL1_FPGA_CHANNELS; ++channel) {
        // Need to know the board channel number.
        int ukl1Channel = inFpga*FWUKL1_FPGA_CHANNELS + channel;
        // These are a unique case in that they read and write from different
        // hardware registers. Place the write register first as this is required
        // for the DB. The DB must contain an entry per channel in this case, whereas
        // the hardware has a different method of handling multiple channels and
        // this is sorted out by the channel write and read functions.
        // We place the read register second in a comma separated list.
        // The channel configuration start every 128-bits in the Ingress status word.
        // The configuration settings are offset by 64-bits into those words and the inhibit bit is the first bit.
        // We need to convert the channel from base 0 to base 1.
        offset = 128*(FWUKL1_FPGA_CHANNELS-(channel+1))+64+0;
        registerName = "Channel" + ukl1Channel + ".Disable";
        registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_CHANNEL_CONFIG_GROUP, FWUKL1_ALL_CHANNEL_CONFIG_GROUP);
        registerValues[FWUKL1_MASK] = "1";
        registerValues[FWUKL1_TOOLTIP_TEXT] = "If enabled then the UKL1 board will receive data on this input channel.";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_FPGA_CONFIG_HWTYPE + ".ConfigurationFifoChannel" + ukl1Channel;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "0;Enable,0;Disable,1";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "0,FwStateOKPhysics;1,FwEquipmentDisabled";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = offset+",1;0,Enabled;1,Disabled";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseChannelWrite;
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "0,1;0,Enable;1,Disable";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
        registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
        registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus" + inFpga);
        offset = 128*(FWUKL1_FPGA_CHANNELS-(channel+1))+64+1;
        registerName = "Channel" + ukl1Channel + ".HpdPixelMode";
        registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_CHANNEL_CONFIG_GROUP);
        registerValues[FWUKL1_MASK] = "1";
        registerValues[FWUKL1_TOOLTIP_TEXT] = "Pixel mode of the HPD.";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_FPGA_CONFIG_HWTYPE + ".ConfigurationFifoChannel" + ukl1Channel;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "1;LHCb,0;ALICE,1";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = offset+",1;0,LHCb;1,ALICE";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseChannelWrite;
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "1,1;0,LHCb;1,ALICE";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
        registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
        registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus" + inFpga);
        offset = 128*(FWUKL1_FPGA_CHANNELS-(channel+1))+64+2;
        registerName = "Channel" + ukl1Channel + ".ZeroSuppression";
        registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_CHANNEL_CONFIG_GROUP);
        registerValues[FWUKL1_MASK] = "1";
        registerValues[FWUKL1_TOOLTIP_TEXT] = "Enables compression of the HPD data.";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_FPGA_CONFIG_HWTYPE + ".ConfigurationFifoChannel" + ukl1Channel;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "2;Disable,0;Enable,1";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = offset+",1;0,Disabled;1,Enabled";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseChannelWrite;
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "2,1;0,Disable;1,Enable";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
        registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
        registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus" + inFpga);
        offset = 128*(FWUKL1_FPGA_CHANNELS-(channel+1))+64+3;
        registerName = "Channel" + ukl1Channel + ".EmptyHpdSuppression";
        registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_CHANNEL_CONFIG_GROUP);
        registerValues[FWUKL1_MASK] = "1";
        registerValues[FWUKL1_TOOLTIP_TEXT] = "Removes HPDs that transmit no data from the data stream.";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_FPGA_CONFIG_HWTYPE + ".ConfigurationFifoChannel" + ukl1Channel;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "3;Don't suppress,0;Suppress,1";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = offset+",1;0,Not suppressed;1,Supressed";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseChannelWrite;
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "3,1;0,Don't suppress;1,Suppress";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
        registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
        registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus" + inFpga);
        offset = 128*(FWUKL1_FPGA_CHANNELS-(channel+1))+64+4;
        registerName = "Channel" + ukl1Channel + ".Emulator";
        registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_CHANNEL_CONFIG_GROUP);
        registerValues[FWUKL1_MASK] = "1";
        registerValues[FWUKL1_TOOLTIP_TEXT] = "Enables the L0 emulator which will send emulate events through the UKL1 if emulator events are enabled.";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_FPGA_CONFIG_HWTYPE + ".ConfigurationFifoChannel" + ukl1Channel;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "4;Enable,0;Disable,1";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = offset+",1;0,Enabled;1,Disabled";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseChannelWrite;
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "4,1;0,Enable;1,Disable";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
        registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
        registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus" + inFpga);
        offset = 128*(FWUKL1_FPGA_CHANNELS-(channel+1))+64+5;
        registerName = "Channel" + ukl1Channel + ".EmulatorHpdPixelMode";
        registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_CHANNEL_CONFIG_GROUP);
        registerValues[FWUKL1_MASK] = "1";
        registerValues[FWUKL1_TOOLTIP_TEXT] = "Sets the pixel mode for the emulated HPDs.";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_FPGA_CONFIG_HWTYPE + ".ConfigurationFifoChannel" + ukl1Channel;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "5;LHCb,0;ALICE,1";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = offset+",1;0,LHCb;1,ALICE";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseChannelWrite;
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "5,1;0,LHCb;1,ALICE";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
        registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
        registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus" + inFpga);
        offset = 128*(FWUKL1_FPGA_CHANNELS-(channel+1))+64+7;
        registerName = "Channel" + ukl1Channel + ".EmulatorEvent";
        registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_CHANNEL_CONFIG_GROUP);
        registerValues[FWUKL1_MASK] = "1";
        registerValues[FWUKL1_TOOLTIP_TEXT] = "The emulator will only send events in response to a trigger when this has been set to send.";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_FPGA_CONFIG_HWTYPE + ".ConfigurationFifoChannel" + ukl1Channel;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "7;Don't send,0;Send,1";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = offset+",1;0,Not sending;1,Sending";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseChannelWrite;
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "7,1;0,Don't send;1,Send";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
        registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
        registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus" + inFpga);
        offset = 128*(FWUKL1_FPGA_CHANNELS-(channel+1))+64+8;
        registerName = "Channel" + ukl1Channel + ".PixelMasks";
        registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_CHANNEL_CONFIG_GROUP);
        registerValues[FWUKL1_MASK] = "1";
        registerValues[FWUKL1_TOOLTIP_TEXT] = "Indicates how to apply the UKL1 pixel masks, can be used to either force the pixel on or off.";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_FPGA_CONFIG_HWTYPE + ".ConfigurationFifoChannel" + ukl1Channel;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegDescrition";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "8;Force off,0;Force on,1";
        registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = offset+",1;0,Forced off;1,Forced on";
        registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseChannelWrite;
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegDescritionToByte";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "8,1;0,Force off;1,Force on";
        registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
        registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
        registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
        registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
        registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus" + inFpga);
      }// for channel
    }// for inFpga

    // For writing these registers are used to set the same value to multiple registers.
    // Most of the write info is here just as a place holder. The abstract register
    // name will later be converted to its corresponding abstract register for each
    // register the all represents.
    // In the case of the read some of the settings are relevant as it is at the hardware
    // register level that the all function is converted to its individual registers
    // and an ORing of the read values done.
    const string multiChannelWrite = "";
    const string multiChannelRead = "_fwUkl1_readAllUkl1Channels";
    registerName = "ChannelAll.Disable";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(); // Not reall useful to display as a single value.
    registerValues[FWUKL1_MASK] = "";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Logical OR of all the input channel states.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_NULL_HWREG;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = multiChannelRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegChannelAll";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = multiChannelWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegChannelAllToIndividualRegs";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus0", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus1", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus2", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus3");
    registerName = "ChannelAll.HpdPixelMode";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_ALL_CHANNEL_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Logical OR of all the channel HPD pixel modes. Must match the throttle mode setting on Egress FPGA.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_NULL_HWREG;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = multiChannelRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegChannelAll";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = multiChannelWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegChannelAllToIndividualRegs";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus0", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus1", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus2", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus3");
    registerName = "ChannelAll.ZeroSuppression";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_ALL_CHANNEL_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Logical OR of all the channel zero suppression setting. Enables compression of the HPD data.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_NULL_HWREG;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = multiChannelRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegChannelAll";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = multiChannelWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegChannelAllToIndividualRegs";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus0", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus1", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus2", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus3");
    registerName = "ChannelAll.EmptyHpdSuppression";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_ALL_CHANNEL_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Logical OR of all the channel empty HPD suppression. Removes HPDs that transmit no data from the data stream.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_NULL_HWREG;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = multiChannelRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegChannelAll";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus0";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = multiChannelWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegChannelAllToIndividualRegs";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus0", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus1", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus2", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus3");
    registerName = "ChannelAll.Emulator";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_ALL_CHANNEL_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Logical OR of all the channel emulators enable setting. Enables the L0 emulator which will send emulate events through the UKL1 if emulator events are enabled.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_NULL_HWREG;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = multiChannelRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegChannelAll";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = multiChannelWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegChannelAllToIndividualRegs";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus0", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus1", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus2", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus3");
    registerName = "ChannelAll.EmulatorHpdPixelMode";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_ALL_CHANNEL_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Logical OR of all the channels emulated pixel mode.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_NULL_HWREG;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = multiChannelRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegChannelAll";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = multiChannelWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegChannelAllToIndividualRegs";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus0", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus1", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus2", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus3");
    registerName = "ChannelAll.EmulatorEvent";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_ALL_CHANNEL_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Logical OR of all the channel emulator settings. The emulator will only send events in response to a trigger when this has been set to send.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_NULL_HWREG;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = multiChannelRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegChannelAll";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = multiChannelWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegChannelAllToIndividualRegs";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus0", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus1", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus2", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus3");
    registerName = "ChannelAll.PixelMasks";
    registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_ALL_CHANNEL_CONFIG_GROUP);
    registerValues[FWUKL1_MASK] = "";
    registerValues[FWUKL1_TOOLTIP_TEXT] = "Logical OR of all the channels pixel mask setting. It indicates whether to use the mask to force the pixel on or off.";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_UserSpecific;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS] = FWUKL1_NULL_HWREG;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = multiChannelRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertByteToAbsRegChannelAll";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = multiChannelWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = "_fwUkl1_convertAbsRegChannelAllToIndividualRegs";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_MONITORING_START_FUNCTION] = fifoStartMonitoringFunc;
    registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = fifoStopMonitoringFunc;
    registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus0", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus1", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus2", FWUKL1_FPGA_STATUS_HWTYPE + ".FrontEndStatus3");

//      registerName = "";
//      registerValues[FWUKL1_REGISTER_GROUPS] = makeDynString(FWUKL1_EGRESS_STATUS_GROUP);
//      registerValues[FWUKL1_MASK] = "";
//      registerValues[FWUKL1_TOOLTIP_TEXT] = "";
//      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE] = FWHW_LBUS;
//      registerValues[FWUKL1_MONITORING_REGISTERS] = makeDynString(registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS]);
//      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION] = baseRead;
    registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION] = """";
//      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO]= "";
//      registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO] = "";
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_ACCESS_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_FUNCTION] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
//      registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_HW_STATUS_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_HW_REGISTER_TYPE] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE];
    registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS];
//      registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION]       = baseWrite;
    registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION] = """";
//      registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO] = "";
    registerValues[FWUKL1_HW_WRITE+FWUKL1_LIMITS_INFO] = "";
//      registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES] = makeDynString(FWUKL1_CONFIGURE_TYPE);
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_READ+FWUKL1_ACCESS_FUNCTION]  = baseLoad;
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_READ+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_READ+FWUKL1_LIMITS_INFO] = registerValues[FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_DB_RECIPE_TYPES] = registerValues[FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_REGISTERS] = registerValues[FWUKL1_HW_WRITE+FWUKL1_ACCESS_REGISTERS];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_ACCESS_FUNCTION]  = baseSave;
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_FUNCTION]  = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_FUNCTION];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_PARSER_INFO] = registerValues[FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO];
    registerValues[FWUKL1_DB_WRITE+FWUKL1_LIMITS_INFO] = "";
//      registerValues[FWUKL1_MONITORING_START_FUNCTION] = ccpcStartMonitoringFunc;
//      registerValues[FWUKL1_MONITORING_STOP_FUNCTION]  = ccpcStopMonitoringFunc;

  }// if(forceReconfigure)
  
  // Done.
  return;
}// _fwUkl1_updateAbstractRegisterDP()

/*!
 * This sets the list of abstract registers that are accessible through the abstract register interface.
 *
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_updateAbstractRegisterListDPE(dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // First create the list that is to be set.
  dyn_string abRegList;
  // FPGA configuration registers.
  dynAppend(abRegList, "MacDestinationAddress");
  dynAppend(abRegList, "MacSourceAddress");
  dynAppend(abRegList, "IpDestinationAddress");
  dynAppend(abRegList, "IpSourceAddress");
  dynAppend(abRegList, "PartitionId");
  dynAppend(abRegList, "TypeOfService");
  dynAppend(abRegList, "Protocol");
  dynAppend(abRegList, "TimeToLive");
  dynAppend(abRegList, "Type");
  dynAppend(abRegList, "Version");
  dynAppend(abRegList, "TfcLatencyCompensation");
  dynAppend(abRegList, "L1Id");
  dynAppend(abRegList, "MepEventCount");
  dynAppend(abRegList, "MTU");
  dynAppend(abRegList, "MepTruncationHighWatermark");
  dynAppend(abRegList, "ManualMepGbeOutputPortNumber");
  dynAppend(abRegList, "ThrottleMode");
  dynAppend(abRegList, "ThrottlePolarity");
  dynAppend(abRegList, "ThrottleOutput");
  dynAppend(abRegList, "ForceFixedMepDestinationAddress");
  dynAppend(abRegList, "MepBuildingMode");
  dynAppend(abRegList, "TfcDecoding");
  dynAppend(abRegList, "GbeTpaPolling");
  dynAppend(abRegList, "ManualMepGbeOutputPortControl");
  dynAppend(abRegList, "Ingress0Enable");
  dynAppend(abRegList, "Ingress1Enable");
  dynAppend(abRegList, "Ingress2Enable");
  dynAppend(abRegList, "Ingress3Enable");
  // FPGA status registers.
  dynAppend(abRegList, "TTCId");
  dynAppend(abRegList, "TFCFIFORequest");
  dynAppend(abRegList, "TTCrxReady");
  dynAppend(abRegList, "EventMergerReadState");
  dynAppend(abRegList, "GTDataLowWordInhibit0");
  dynAppend(abRegList, "GTDataLowWordInhibit1");
  dynAppend(abRegList, "GTDataLowWordInhibit2");
  dynAppend(abRegList, "GTDataLowWordInhibit3");
  dynAppend(abRegList, "GTDataHighWordInhibit0");
  dynAppend(abRegList, "GTDataHighWordInhibit1");
  dynAppend(abRegList, "GTDataHighWordInhibit2");
  dynAppend(abRegList, "GTDataHighWordInhibit3");
  dynAppend(abRegList, "GTCommunicationWordInhibit0");
  dynAppend(abRegList, "GTCommunicationWordInhibit1");
  dynAppend(abRegList, "GTCommunicationWordInhibit2");
  dynAppend(abRegList, "GTCommunicationWordInhibit3");
  dynAppend(abRegList, "GTDataLinkInhibit0");
  dynAppend(abRegList, "GTDataLinkInhibit1");
  dynAppend(abRegList, "GTDataLinkInhibit2");
  dynAppend(abRegList, "GTDataLinkInhibit3");
  dynAppend(abRegList, "GBETx");
  dynAppend(abRegList, "MEPFifo");
  dynAppend(abRegList, "ThrottleAsserted");
  dynAppend(abRegList, "GTFIFO0");
  dynAppend(abRegList, "GTFIFO1");
  dynAppend(abRegList, "GTFIFO2");
  dynAppend(abRegList, "GTFIFO3");
  dynAppend(abRegList, "GTLowFIFODataReadout0");
  dynAppend(abRegList, "GTLowFIFODataReadout1");
  dynAppend(abRegList, "GTLowFIFODataReadout2");
  dynAppend(abRegList, "GTLowFIFODataReadout3");
  dynAppend(abRegList, "GTHighFIFODataReadout0");
  dynAppend(abRegList, "GTHighFIFODataReadout1");
  dynAppend(abRegList, "GTHighFIFODataReadout2");
  dynAppend(abRegList, "GTHighFIFODataReadout3");
  dynAppend(abRegList, "TFCL0Reset");
  dynAppend(abRegList, "TFCL1Reset");
  dynAppend(abRegList, "TFCShortBroadcast");
  dynAppend(abRegList, "GBETransmitPortAvailable0");
  dynAppend(abRegList, "GBETransmitPortAvailable1");
  dynAppend(abRegList, "GBETransmitPortAvailable2");
  dynAppend(abRegList, "GBETransmitPortAvailable3");
  dynAppend(abRegList, "EthernetFragmentReady");
  dynAppend(abRegList, "MEPReady");
  dynAppend(abRegList, "FragmentRequest");
  dynAppend(abRegList, "MEPExtraction");
  dynAppend(abRegList, "EthernetFormatterState");
  dynAppend(abRegList, "FragmentExtraction");
  dynAppend(abRegList, "SequenceError");
  dynAppend(abRegList, "MEPCount");
  dynAppend(abRegList, "GTFIFOTxWait0");
  dynAppend(abRegList, "GTFIFOTxWait1");
  dynAppend(abRegList, "GTFIFOTxWait2");
  dynAppend(abRegList, "GTFIFOTxWait3");
  dynAppend(abRegList, "TFCFIFOOccupancy");
  dynAppend(abRegList, "TFCLongBroadcast");
  dynAppend(abRegList, "EgressInputFIFOLowWordSequenceError0");
  dynAppend(abRegList, "EgressInputFIFOLowWordSequenceError1");
  dynAppend(abRegList, "EgressInputFIFOLowWordSequenceError2");
  dynAppend(abRegList, "EgressInputFIFOLowWordSequenceError3");
  dynAppend(abRegList, "EgressInputFIFOHighWordSequenceError0");
  dynAppend(abRegList, "EgressInputFIFOHighWordSequenceError1");
  dynAppend(abRegList, "EgressInputFIFOHighWordSequenceError2");
  dynAppend(abRegList, "EgressInputFIFOHighWordSequenceError3");
  dynAppend(abRegList, "L0TriggerCount");
  dynAppend(abRegList, "ROTBroadcastCount");
  dynAppend(abRegList, "TFCDestinationCount");
  dynAppend(abRegList, "MEPSequenceCount");
  dynAppend(abRegList, "TTCrxReadyAlarm");
  dynAppend(abRegList, "SequenceErrorAlarm");
  dynAppend(abRegList, "EgressInputFIFOLowWordOccupancy0");
  dynAppend(abRegList, "EgressInputFIFOLowWordOccupancy1");
  dynAppend(abRegList, "EgressInputFIFOLowWordOccupancy2");
  dynAppend(abRegList, "EgressInputFIFOLowWordOccupancy3");
  dynAppend(abRegList, "EgressInputFIFOHighWordOccupancy0");
  dynAppend(abRegList, "EgressInputFIFOHighWordOccupancy1");
  dynAppend(abRegList, "EgressInputFIFOHighWordOccupancy2");
  dynAppend(abRegList, "EgressInputFIFOHighWordOccupancy3");
  dynAppend(abRegList, "EgressInputFIFOLowWordRxCount0");
  dynAppend(abRegList, "EgressInputFIFOLowWordRxCount1");
  dynAppend(abRegList, "EgressInputFIFOLowWordRxCount2");
  dynAppend(abRegList, "EgressInputFIFOLowWordRxCount3");
  dynAppend(abRegList, "EgressInputFIFOHighWordRxCount0");
  dynAppend(abRegList, "EgressInputFIFOHighWordRxCount1");
  dynAppend(abRegList, "EgressInputFIFOHighWordRxCount2");
  dynAppend(abRegList, "EgressInputFIFOHighWordRxCount3");
  dynAppend(abRegList, "EgressInputFIFOLowWordTxCount0");
  dynAppend(abRegList, "EgressInputFIFOLowWordTxCount1");
  dynAppend(abRegList, "EgressInputFIFOLowWordTxCount2");
  dynAppend(abRegList, "EgressInputFIFOLowWordTxCount3");
  dynAppend(abRegList, "EgressInputFIFOHighWordTxCount0");
  dynAppend(abRegList, "EgressInputFIFOHighWordTxCount1");
  dynAppend(abRegList, "EgressInputFIFOHighWordTxCount2");
  dynAppend(abRegList, "EgressInputFIFOHighWordTxCount3");
  // ID registers.
  dynAppend(abRegList, "SerialNumber");
  dynAppend(abRegList, "LogicalId");
  dynAppend(abRegList, "RichId");
  // Sensor registers.
  dynAppend(abRegList, "TemperatureSensorTop");
  dynAppend(abRegList, "TemperatureSensorMiddle");
  dynAppend(abRegList, "TemperatureSensorBottom");
  // TTCrx registers.
  dynAppend(abRegList, "TtcrxControl");
  // GBE registers.
  dynAppend(abRegList, "GbeJtagId");
  dynAppend(abRegList, "GbeMACSoftReset");
  dynAppend(abRegList, "GbeReceivePortReset");
  dynAppend(abRegList, "GbeTransmitPortReset");
  dynAppend(abRegList, "GbeReceiveFifoEnable");
  dynAppend(abRegList, "GbeMode");
  dynAppend(abRegList, "GbeClock");
  dynAppend(abRegList, "GbeSPI3ConfigTrnmtGlobal");
  dynAppend(abRegList, "GbeSPI3ConfigRcv");
  dynAppend(abRegList, "GbeRxStatus");
  dynAppend(abRegList, "GbePHYCtrl");
  dynAppend(abRegList, "GbePHYWriteData");
  dynAppend(abRegList, "GbePHYReadData");
  dynAppend(abRegList, "GbeMDIOControl");
  // GBE ports.
  for (int port=0; port<FWUKL1_GBE_PORTS; ++port) {
    dynAppend(abRegList, "GbePort" + port + "Enable");
    dynAppend(abRegList, "GbePort" + port + "TxFifoThreshold");
    dynAppend(abRegList, "GbePort" + port + "TxFifoLowWatermark");
    dynAppend(abRegList, "GbePort" + port + "TxFifoHighWatermark");
  }// for port
  // Input channels.
  for (int channel=0; channel<FWUKL1_BOARD_CHANNELS; ++channel) {
    dynAppend(abRegList, "Channel" + channel + ".Disable");
    dynAppend(abRegList, "Channel" + channel + ".HpdPixelMode");
    dynAppend(abRegList, "Channel" + channel + ".ZeroSuppression");
    dynAppend(abRegList, "Channel" + channel + ".EmptyHpdSuppression");
    dynAppend(abRegList, "Channel" + channel + ".Emulator");
    dynAppend(abRegList, "Channel" + channel + ".EmulatorHpdPixelMode");
    dynAppend(abRegList, "Channel" + channel + ".EmulatorEvent");
    dynAppend(abRegList, "Channel" + channel + ".PixelMasks");
  }// for channel
  dynAppend(abRegList, "ChannelAll.Disable");
  dynAppend(abRegList, "ChannelAll.HpdPixelMode");
  dynAppend(abRegList, "ChannelAll.ZeroSuppression");
  dynAppend(abRegList, "ChannelAll.EmptyHpdSuppression");
  dynAppend(abRegList, "ChannelAll.Emulator");
  dynAppend(abRegList, "ChannelAll.EmulatorHpdPixelMode");
  dynAppend(abRegList, "ChannelAll.EmulatorEvent");
  dynAppend(abRegList, "ChannelAll.PixelMasks");
  
//    dynAppend(abRegList, "");
  // Now set the list.
  const string dpeName = FWUKL1_UKL1_BOARD_DP_NAME + "." + FWUKL1_ABSTRACT_REG_LIST;
  if ( 0 != dpSet(dpeName, abRegList) )
    exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_updateAbstractRegisterListDPE(): Failed to update/set the list of abstract registers that are available. The list will either be out of data, incomplete or at worst empty.", "1");
  
}// _fwUkl1_updateAbstractRegisterListDPE()

/*!
 * This sets the DPE for the specific register in the UKL1 abstract registers' interface DP.
 *
 * \param  regName The name of the register to update.
 * \param  regValues A map containing the list of registers to set. The key is the DPE name (all are defined as contants
 *           in this library) and it corresponds to the value to be set. Only those values given as a key will
 *           be set. No notification of those elements not present is given.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_updateAbstractRegisterDPE(const string &regName, mapping &regValues, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // Get the list of keys to write.
  const dyn_string keys = mappingKeys(regValues);
  // Now loop over them.
  const int numKeys = dynlen(keys);
  for ( int keyNum = 1; keyNum <= numKeys; ++keyNum ) {
    // The key.
    const string key = keys[keyNum];
    // Now determine the element.
    const string dpeName = FWUKL1_UKL1_BOARD_DP_NAME + "." + regName + "." + key;
    // Check it exists.
    if ( dpExists(dpeName) ) {
      // Set it.
      if ( 0 != dpSet(dpeName, regValues[key]) )
        exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_updateAbstractRegisterDPE(): Failed to update/set the abstract register " + regName + " setting " + key + ". Attempted to write to the DPE " + dpeName + ". The settings for this abstract register will either be incomplete, out of data or at worse missing. This could affect the ability to write to this register.", "2");
    }// if (dpExists(dpeName))
    else
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_updateAbstractRegisterDPE(): Failed to find the DPE " + dpeName + ". Could not update the settings " + key + " for the register " + regName + ". Please check that this register should exists.", "2");
  }// for keyNum
  // Done.
  return;
}// _fwUkl1_updateAbstractRegisterDPE()

/*!
 * This will create a datapoint from the HwTypeCCPCUKL1 datapoint type, which represents a UKL1 board, with all
 * the appropriate settings and subscribe these registers to the DIM server.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  ukl1Version If FWUKL1_PRODUCTION it is a production board, if it is FWUKL1_PROTOTYPE it is a prototype board,
 *           this affects the I2C bus that needs to be used.
 * \param  forceReconfigure If TRUE it will force the settings to be set from hardcoded settings and not to be loaded from
 *           the defaults for the fwHw datapoint type, it will also reset the default settings to those hardcoded in the library.
 *	     FALSE and the settings are just loaded from the defaults. Used if there is an update to the DPT structure.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void
 *
 * The name of the created datapoint will be the concatantion of FWUKL1_DPNAME_PREFIX and ukl1Name. The setting placed in this
 * datapoint set the name of the UKL1 board as in the DIM server and the address of all the registers that the datapoint can
 * access. Note that no inverse is provided for this function i.e._fwUkl1_deleteHwTypeCCPCUKL1Datapoint as this is done via
 * fwHw_remove.
 */
void _fwUkl1_createHwTypeCCPCUKL1Datapoint(string ukl1Name, unsigned ukl1Version, bool forceReconfigure, dyn_string& exceptionInfo) {
  if ("" == ukl1Name)
    return;

  // Keeps track of the size of the error array.
  int exInfoSize = dynlen(exceptionInfo);
  // Some datapoint and datapoint type related constants...
  // Name of the datapoint type we are creating from.
  const string dptName = FWHW_TYPE_DPT + FWHW_CCPC_DESCRIPTION + FWUKL1_HW_REGISTER_TYPE;
  // Name of the default settings data point.
  const string defaultSettingsDpName = FWHW_DEFAULT_SETTINGS_DP + FWHW_CCPC_DESCRIPTION + FWUKL1_HW_REGISTER_TYPE;

  // Check to see if the default settings datapoint actually exists. If it doesn't then we should add it
  // to the system, otherwise it will cause much confusion later... especially as there is no error checking
  // associated with loading/saving to the default values!
  if (!dpExists(defaultSettingsDpName)) {
    // Potentially override the User choice, but then we must...
    forceReconfigure = TRUE;
    // Create the hardware datapoint, but make sure we don't try and load the default settings as we are creating them.
    // Don't warn about adding this DP as it happens during creation and is annoying.
    if (!fwHw_create(FWUKL1_HW_REGISTER_TYPE, defaultSettingsDpName, FALSE))
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_createHwTypeCCPCUKL1Datapoint(): Failed to recreate the default settings for the UKL1 hardware data point. This should not have to have needed to be done in the first place (install of fwUkl1 component may not have completed successfully) and failure to create it indicates a more serious problem.", "2");
  }// if(!dpExists())
  
  // Notes if the DP exists. Can't update anything if it doesn't!
  bool ukl1Exists = TRUE;
  // Note if the DP was created.
  bool ukl1Created = FALSE;
  // Now check to see if the datapoint exists.
  if (!dpExists(ukl1Name)) {
    // Use the hardware tool to create the datapoint. If we are not forceReconfigure'ing then we can load from the
    // default settings.
    if (fwHw_create(FWUKL1_HW_REGISTER_TYPE, ukl1Name, !forceReconfigure)) 
      ukl1Created = TRUE;
    else {
      ukl1Exists = FALSE;
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_createHwTypeCCPCUKL1Datapoint(): Failed to create the hardware data point for " + ukl1Name + ", communication with this board is not possible.", "1");
    }// if(!fwHw_create())
  }// if(!dpExists(ukl1Name))
  
  // Configure those settings that cannot be loaded from the defaults.
  // The common settings are for example the name of the UKL1 boards to communicate with.
  _fwUkl1_configureHwTypeCCPCUKL1CommonSettings(ukl1Name, exceptionInfo);
  // Initialise the general settings, such as the FSM state.
  _fwUkl1_configureHwTypeCCPCUKL1GeneralSettings(ukl1Name, ukl1Version, exceptionInfo);
  
  // Now configure the specific settings if necessary. If forceReconfigure is FALSE then this will have been done from the defaults,
  // if not then the default DP settings must be saved from the file settings.
  // If we are dealing with a prototype board then we must update the settings.
  if (ukl1Exists && forceReconfigure || (FWUKL1_PROTOTYPE == ukl1Version)) {
    _fwUkl1_configureHwTypeCCPCUKL1Settings(ukl1Name, ukl1Version, exceptionInfo);
    fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "_fwUkl1_createHwTypeCCPCUKL1DataPoint(): Failed to load the settings for " + ukl1Name + " from the settings saved in the library.", "2", exInfoSize);
  }// if(ukl1Exists&&forceReconfigure)
  
  // Ensure the DIM services are setup. If they are it will be ignored otherwise they will be set up.
  // Must be done last to ensure that we have configured the HW DPs. Only do it if they are being created.
  if (ukl1Exists && ukl1Created) {
    if (!fwHw_subscribe(ukl1Name))
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_createHwTypeCCPCUKL1Datapoint(): Failed to subscribe " + ukl1Name + " to the DIM server, communication with this UKL1 board will not be possible.", "1");
  }// if UKL1 successfully created.
  
  // Done.
  return;
}// _fwUkl1_createHwTypeCCPCUKL1Datapoint()

/*!
 * This is used to configure the specific register settings of the HwTypeCCPCUKL1 datapoint type.
 * It will not configure the common settings.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server. The appropriate
 *           datapoint to be set will be found from this.
 * \param  ukl1Version Verision number of the UKL1 board, either FWUKL1_PRODUCTION or FWUKL1_PROTOTYPE.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * If called it will load the HW DP settings from the defaults and save them to the default values. There is an
 * exception, if it is a prototype board the settings will not be saved as the defaults. This has a different I2C
 * bus and it must be loaded from this file everytime.
 */
void _fwUkl1_configureHwTypeCCPCUKL1Settings(string ukl1Name, unsigned ukl1Version, dyn_string& exceptionInfo) {
  // Keep track of generated exception.
  int exInfoSize = dynlen(exceptionInfo);
  // We can only save as the defaults if it is a production board.
  bool saveAsDefaults = (FWUKL1_PRODUCTION == ukl1Version ? TRUE:FALSE);

  // Now we must do the specific settings for all of the hardware type included in the UKL1 type.
  // GBE
  _fwUkl1_configureHwTypeCCPCUKL1GBESpecificSettings(ukl1Name, ukl1Version, exceptionInfo);
  bool errOccurred = fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "_fwUkl1_configureHwTypeCCPCUKL1Settings(): Failed to set the GBE specific settings. Will not be able to communicate with these nor save them as the default values if requested.", "2", exInfoSize);
  // TTCrx
  _fwUkl1_configureHwTypeCCPCUKL1TTCRXSpecificSettings(ukl1Name, ukl1Version, exceptionInfo);
  errOccurred = fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "_fwUkl1_configureHwTypeCCPCUKL1Settings(): Failed to set the TTCrx specific settings. Will not be able to communicate with these nor save them as the default values if requested.", "2", exInfoSize);
  // FPGA configuration
  _fwUkl1_configureHwTypeCCPCUKL1FpgaConfigSpecificSettings(ukl1Name, exceptionInfo);
  errOccurred = fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "_fwUkl1_configureHwTypeCCPCUKL1Settings(): Failed to set the FPGAs' configuration specific settings. Will not be able to communicate with these nor save them as the default values if requested.", "2", exInfoSize);
  // FPGA status
  _fwUkl1_configureHwTypeCCPCUKL1FpgaStatusSpecificSettings(ukl1Name, exceptionInfo);
  errOccurred = fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "_fwUkl1_configureHwTypeCCPCUKL1Settings(): Failed to set the FPGAs' status specific settings. Will not be able to communicate with these nor save them as the default values if requested.", "2", exInfoSize);
  // UKL1 resets
  _fwUkl1_configureHwTypeCCPCUKL1ResetsSpecificSettings(ukl1Name, ukl1Version, exceptionInfo);
  errOccurred = fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "_fwUkl1_configureHwTypeCCPCUKL1Settings(): Failed to set the UKL1 reset specific settings. Will not be able to communicate with these nor save them as the default values if requested.", "2", exInfoSize);
  // UKL1 PROM
  _fwUkl1_configureHwTypeCCPCUKL1PROMSpecificSettings(ukl1Name, ukl1Version, exceptionInfo);
  errOccurred = fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "_fwUkl1_configureHwTypeCCPCUKL1Settings(): Failed to set the PROM specific settings. Will not be able to communicate with these nor save them as the default values if requested.", "2", exInfoSize);
  // UKL1 temperature sensors.
  _fwUkl1_configureHwTypeCCPCUKL1SensorSpecificSettings(ukl1Name, ukl1Version, exceptionInfo);
  errOccurred = fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "_fwUkl1_configureHwTypeCCPCUKL1Settings(): Failed to set the temperature sensor specific settings. Will not be able to communicate with these nor save them as the default values if requested.", "2", exInfoSize);

  // Check to see if any exceptions were risen.
  if (!errOccurred && saveAsDefaults) {
    // No new exceptions were generated so set them as the defaults, if we are asked to.
    // Will get the settings that we have just set and save them to the default values.
    // At present it appears that this function just returns 1, update this to check for errors once it can actually show them!
    // This is true upto at least v3r5...
    if ( 1 != fwHw_saveSettingsAsDefault(FWUKL1_HW_REGISTER_TYPE, ukl1Name) )
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "WARNING", "_fwUkl1_configureHwTypeCCPCUKL1Settings(): " + ukl1Name + "'s default settings were not saved correctly, this could mean they are corrupt and the data point should not be configured from the default settings until this problem is fixed.","2");
  }// if no errors and save as defaults.
  
  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1Settings(

/*!
 * This will set the common settings for the fwHw type UKL1 and all included fwHw types.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_configureHwTypeCCPCUKL1CommonSettings(string ukl1Name, dyn_string& exceptionInfo) {
  // The common setting to be written.
  dyn_string commonSettings;
  commonSettings[1] = ukl1Name;
  // Write the common setting, this is done recursively so all the subtypes have their common setting
  // updated to.
  if ( !fwHw_setCommonSettings(ukl1Name, commonSettings, TRUE) )
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1CommonSettings(): Failed to set the CCPC name for " + ukl1Name + ", this will prevent correct communication with this UKL1.", "1");
  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1CommonSettings()

/*!
 * This will set the specific settings for the status data point element that the UKL1 HW type has.
 * It controls the FSM interactions. It should be ensured that the ukl1Name HW data point exists before calling this function.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  ukl1Version Indicates whether we have a production or prototype board.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_configureHwTypeCCPCUKL1GeneralSettings(string ukl1Name, unsigned ukl1Version, dyn_string& exceptionInfo) {
  // Convert the UKL1 board name into the datapoint name and add the name of the DPE to the end.
  string dpeName = ukl1Name + ".status";
  // Set the board to NOT_READY by default.
  if ( 0 != dpSet(dpeName, "NOT_READY") )
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1GeneralSettings(): Failed to initialise the UKL1 FSM state to NOT_READY for, problems accessing the DP were encountered. Board will be in a UNKNOWN state when FSM is started.", "1");
  // Done.
}// _fwUkl1_configureHwTypeCCPCUKL1GeneralSettings()

/*!
 * This will set the specific settings for the fwHw type GBE that has been inserted into the
 * UKL1 fwHw type.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  ukl1Version Indicates whether we have a production or prototype board.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_configureHwTypeCCPCUKL1GBESpecificSettings(string ukl1Name, unsigned ukl1Version, dyn_string& exceptionInfo) {
  // Convert the UKL1 board name into the datapoint name.
  const string dpName = ukl1Name + ".GBE";

  // Set the specific settings.
  // This contains a list of all the register names that are to be set.
  dyn_string registerList;
  registerList[1]  = "JTAGID";
  registerList[2]  = "MACSoftReset";
  registerList[3]  = "RxFifoPrtReset";
  registerList[4]  = "TxFifoPrtReset";
  registerList[5]  = "PortEnable";
  registerList[6]  = "RxFifoEnable";
  registerList[7]  = "Mode";
  registerList[8]  = "Clock";
  registerList[9]  = "SPI3ConfigTrnmtGlobal";
  registerList[10] = "SPI3ConfigRcv";
  registerList[11] = "RxStatus";
  registerList[12] = "PHYCtrl";
  registerList[13] = "PHYData";
  registerList[14] = "MDIOControl";
  // This contains the address of all the registers to be set.
  dyn_uint regAddrList;
  regAddrList[1]  = 0x50c;
  regAddrList[2]  = 0x505;
  regAddrList[3]  = 0x59e;
  regAddrList[4]  = 0x620;
  regAddrList[5]  = 0x500;
  regAddrList[6]  = 0x5b3;
  regAddrList[7]  = 0x501;
  regAddrList[8]  = 0x794;
  regAddrList[9]  = 0x700;
  regAddrList[10] = 0x701;
  regAddrList[11] = 0x793;
  regAddrList[12] = 0x680;
  regAddrList[13] = 0x681;
  regAddrList[14] = 0x683;
  // Now we create the settings, these are actually almost the same for each except for the address.
  // 1st element is the address to be filled in later.
  // 2nd element is the number of 32-bit words for command.
  // 3rd element is the check for change rate, set to 2 to match Tell1 change rate and to be compatible with their panels.
  // 4th element is send on change only setting.
  dyn_uint specificSetting = makeDynUInt(0x00, 1, 2, 1);
  dyn_dyn_uint specificSettings;
  // Loop over all the registers
  for (unsigned count = 1; count <= dynlen(regAddrList); ++count) {
    // Put the appropriate register address in the settings array.
    specificSetting[1] = regAddrList[count];
    // Now put the specific settings in the appropriate element of the array containing all the settings for each register.
    specificSettings[count] = specificSetting;
  }// for count

  // Now write all these to the datapoint.
  // Set the general GBE port settings.
  if ( !fwHw_setSpecificSettings(dpName, registerList, specificSettings) )
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1GBESpecificSettings(): Failed to setup the specific settings for the GBE ethernet registers for, the GBE cannot be configured and status information will not be available.", "1");

  // Now setup the PROM, this will indicate its own errors don't need to add anything here.
  _fwUkl1_configureHwTypeCCPCUKL1GBEPROMSpecificSettings(ukl1Name, ukl1Version, exceptionInfo);
  // Now setup the four ports, this will indicate its own errors don't need to add anything here.
  _fwUkl1_configureHwTypeCCPCUKL1GBEPORTSpecificSettings(ukl1Name, exceptionInfo);

  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1GBESpecificSettings()

/*!
 * This will set the specific settings for the fwHw GBE PORM type that has been inserted into the
 * UKL1 fwHw type.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  ukl1Version Indicates whether we have a production or prototype board.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_configureHwTypeCCPCUKL1GBEPROMSpecificSettings(string ukl1Name, unsigned ukl1Version, dyn_string& exceptionInfo) {
  // Convert the UKL1 board name into the datapoint name.
  const string dpName = ukl1Name + ".GBE.PROM";

  // Set the specific settings.
  // This contains a list of all the register names that are to be set.
  dyn_string registerList;
  registerList[1] = "Id";
  // Now we create the settings, these are actually almost the same for each except for the address.
  // 1st element is the bus number that the PROM is on, always either 0 or 1 depending on the version.
  int bus = 0;
  if ( FWUKL1_PROTOTYPE == ukl1Version )
    bus = 1;
  // 2nd element is the address of the PROM on the bus, always 0x57.
  // 3rd element is the address of the PROM registers at register 0x57, always 0.
  // 4th element is the number of bytes that should be written to that register, 46 for compatibility with Tell1.
  // 5th element is the page size, again 46 for compatibility with Tell1.
  // 6th element is the the type of I2C interface to use, always FWCCPC_I2C_COMBINED for the PROM.
  // 7th element is the negative acknowledge, NACK, leave it enabled as I think it tells us if it failed. Always 1. 
  // 8th element is the refresh rate, always 2.
  // 9th element is the on data change settings always 1.
  dyn_int specificSetting = makeDynAnytype(bus, 0x57, 0, 46, 46, FWCCPC_I2C_COMBINED, 1, 2, 1);
  dyn_dyn_int specificSettings;
  specificSettings[1] = specificSetting;

  // Now write all these to the datapoint.
  if ( !fwHw_setSpecificSettings(dpName, registerList, specificSettings) )
   fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1GBEPROMSpecificSettings(): Failed to setup the specific settings for the GBE ethernet PROM, communication with the PROM is not possible.", "1");
  
  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1GBEPROMSpecificSettings()

/*!
 * This will set the specific settings for the fwHw GBE PORT type that has been inserted into the
 * UKL1 fwHw type.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_configureHwTypeCCPCUKL1GBEPORTSpecificSettings(string ukl1Name, dyn_string& exceptionInfo) {
  // Loop over the four ports.
  for (unsigned port = 0; port < FWUKL1_GBE_PORTS; ++port) {
    // Convert the UKL1 board name into the datapoint name.
    const string dpName = ukl1Name + ".GBE.PORT" + port;

    // Set the specific settings.
    // This contains a list of all the register names that are to be set.
    dyn_string registerList;
    registerList[1]  = "Duplex";
    registerList[2]  = "MAC";
    registerList[3]  = "Config";
    registerList[4]  = "TXFifoThreshold";
    registerList[5]  = "TXFifoLowWtrmrk";
    registerList[6]  = "TXFifoHighWtrmrk";
    registerList[7]  = "PHYControl";
    registerList[8]  = "PHYStatus";
    registerList[9]  = "TXStat";
    registerList[10] = "RXStat";

    // This contains the address of all the registers to be set.
    dyn_uint regAddrList;
    // Calculate the start address in the block that contains the per port settings.
    const unsigned offset = (0x80*(port));
    regAddrList[1]  = offset + 0x02;
    regAddrList[2]  = offset + 0x10;
    regAddrList[3]  = offset + 0x18;
    regAddrList[4]  = 0x614 + port;
    regAddrList[5]  = 0x60a + port;
    regAddrList[6]  = 0x600 + port;
    regAddrList[7]  = offset + 0x60;
    regAddrList[8]  = offset + 0x61;
    regAddrList[9]  = offset + 0x40;
    regAddrList[10] = offset + 0x20;

    // This contains the size in bytes of the register to be read.
    dyn_uint regSizeList;
    regSizeList[1]  = 1;
    regSizeList[2]  = 1;
    regSizeList[3]  = 1;
    regSizeList[4]  = 1;
    regSizeList[5]  = 1;
    regSizeList[6]  = 1;
    regSizeList[7]  = 1;
    regSizeList[8]  = 1;
    regSizeList[9]  = 25;
    regSizeList[10] = 26;

    // Now we create the settings, these are actually almost the same for each except for the address.
    // 1st element is the address to be filled in later.
    // 2nd element is the number of 32-bit words for command.
    // 3rd element is the check for change rate, 4th is send on change only setting.
    dyn_uint specificSetting = makeDynUInt(0x00, 1, 2, 1);
    dyn_dyn_uint specificSettings;
    // Loop over all the registers
    for (unsigned count = 1; count <= dynlen(regAddrList); ++count) {
      // Put the appropriate register address in the settings array.
      specificSetting[1] = regAddrList[count];
      // Put the appropriate size of the register in.
      specificSetting[2] = regSizeList[count];
      // Now put the specific settings in the appropriate element of the array containing all the settings for each register.
      specificSettings[count] = specificSetting;
    }// for count
    
    // Now write all these to the datapoint.
    if ( !fwHw_setSpecificSettings(dpName, registerList, specificSettings) )
      fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1GBEPORTSpecificSettings(): Failed to setup the specific settings for the GBE ethernet port " + port + ", port cannot be configured nor is the status available.", "1");
  }// for port
  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1GBEPORTSpecificSettings()
  
/*!
 * This will set the specific settings for the fwHw FpgaConfig type that has been inserted into the
 * UKL1 fwHw type.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_configureHwTypeCCPCUKL1FpgaConfigSpecificSettings(string ukl1Name, dyn_string& exceptionInfo) {
  // Convert the UKL1 board name into the datapoint name.
  const string dpName = ukl1Name + FWUKL1_FPGA_CONFIG_HWTYPE;

  // Set the specific settings.
  // This contains a list of all the register names that are to be set.
  dyn_string registerList;
  registerList[1]  = "MacDestinationAddress";
  registerList[2]  = "MacSourceAddress";
  registerList[3]  = "IpDestinationAddress";
  registerList[4]  = "IpSourceAddress";
  registerList[5]  = "Protocol";
  registerList[6]  = "TypeOfService";
  registerList[7]  = "TimeToLive";
  registerList[8]  = "Type";
  registerList[9]  = "Version";
  registerList[10] = "MiscellaneousControl1";
  registerList[11] = "PartitionId";
  registerList[12] = "MepEventCount";
  registerList[13] = "MiscellaneousControl2";
  registerList[14] = "Latency";
  registerList[15] = "L1Id";
  registerList[16] = "IngressControl";
  registerList[17] = "MTU";
  registerList[18] = "MepTruncationHighWtrmrk";
  registerList[19] = "PixelMaskFifo";
  // Create a configuration FIFO for each channel.
  // This is require so the DB can store settings for each channel.
  // They all map to the same register on the hardware.
  for (int ch=0; ch<FWUKL1_BOARD_CHANNELS; ++ch)
    registerList[20+ch] = "ConfigurationFifoChannel" + ch;
  
  // This contains the address of all the registers to be set.
  dyn_uint regAddrList;
  regAddrList[1]  = _fwUkl1_fpgaizeAddress(0);
  regAddrList[2]  = _fwUkl1_fpgaizeAddress(3);
  regAddrList[3]  = _fwUkl1_fpgaizeAddress(6);
  regAddrList[4]  = _fwUkl1_fpgaizeAddress(8);
  regAddrList[5]  = _fwUkl1_fpgaizeAddress(10);
  regAddrList[6]  = _fwUkl1_fpgaizeAddress(11);
  regAddrList[7]  = _fwUkl1_fpgaizeAddress(12);
  regAddrList[8]  = _fwUkl1_fpgaizeAddress(13);
  regAddrList[9]  = _fwUkl1_fpgaizeAddress(14);
  regAddrList[10] = _fwUkl1_fpgaizeAddress(15);
  regAddrList[11] = _fwUkl1_fpgaizeAddress(16);
  regAddrList[12] = _fwUkl1_fpgaizeAddress(18);
  regAddrList[13] = _fwUkl1_fpgaizeAddress(19);
  regAddrList[14] = _fwUkl1_fpgaizeAddress(22);
  regAddrList[15] = _fwUkl1_fpgaizeAddress(23);
  regAddrList[16] = _fwUkl1_fpgaizeAddress(24);
  regAddrList[17] = _fwUkl1_fpgaizeAddress(29);
  regAddrList[18] = _fwUkl1_fpgaizeAddress(30);
  regAddrList[19] = _fwUkl1_fpgaizeAddress(31);
  for (int ch=0; ch<FWUKL1_BOARD_CHANNELS; ++ch)
    regAddrList[20+ch] = _fwUkl1_fpgaizeAddress(31);
  
  // This contains a list of the number of 16-bit words per register.
  dyn_uint wordNumList;
  wordNumList[1]  = 3;
  wordNumList[2]  = 3;
  wordNumList[3]  = 2;
  wordNumList[4]  = 2;
  wordNumList[5]  = 1;
  wordNumList[6]  = 1;
  wordNumList[7]  = 1;
  wordNumList[8]  = 1;
  wordNumList[9]  = 1;
  wordNumList[10] = 1;
  wordNumList[11] = 2;
  wordNumList[12] = 1;
  wordNumList[13] = 1;
  wordNumList[14] = 1;
  wordNumList[15] = 1;
  wordNumList[16] = 1;
  wordNumList[17] = 1;
  wordNumList[18] = 1;
  wordNumList[19] = 16;
  for (int ch=0; ch<FWUKL1_BOARD_CHANNELS; ++ch)
    wordNumList[20+ch] = 2;

  // Now we create the settings, for the first 18 LBUS registers we need to overwrite
  // the address and number of words in the register.
  // 1st element is the address to be filled in later.
  // 2nd element is the number of bits in the register.
  // 3rd element is the number of words for command.
  // 4th element is the check for change rate (2secs).
  // 5th is send on change only setting.
  dyn_uint specificSetting = makeDynUInt(0x00, FWCCPC_LBUS_BITS_32, 1, 2, 1);
  dyn_dyn_uint specificSettings;
  // Loop over all the registers LBUS registers.
  for (unsigned count=1; count<=18; ++count) {
    // Put the appropriate register address in the settings array.
    specificSetting[1] = regAddrList[count];
    // Put the appropriate size of register into the array.
    specificSetting[3] = wordNumList[count];
    // Now put the specific settings in the appropriate element of the array containing all the settings for each register.
    specificSettings[count] = specificSetting;
  }// for count

  // For the last two registers, these are UserSpecific and must be set up differently.
  // 1st element is the register address of the FIFO, register 0x1f or 31.
  // 2nd element is the type, which is 1 for FIFOs.
  // 3rd element is the width of the FIFO, which is the size of each word that is to be read out in bytes, 2 bytes as we have 16-bit registers.
  // 4rd element is the size of the FIFO, the total number of words in the FIFO.
  // 5th to 10th elements can be ignored, these are the hexpar and par settings which are irrelevant.
  // 11th element is the rate at which it checks for change, 0s as we cannot read back from this register, it makes no sense.
  // 12th element is send on change only setting, set this.
  specificSetting = makeDynUInt(0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1);
  for (unsigned count=19; count<=dynlen(regAddrList); ++count) {
    specificSetting[1] = regAddrList[count];
    specificSetting[4] = wordNumList[count];
    specificSettings[count] = specificSetting;
  }// for count
  
  // Now write all the read write register settings to the datapoint.
  if ( !fwHw_setSpecificSettings(dpName, registerList, specificSettings) )
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1FpgaConfigSpecificSettings(): Failed to setup the configuration specific settings for the FPGAs, the FPGAs' configuration settings cannot be accessed.", "1");

  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1FpgaConfigSpecificSettings()

/*!
 * This will set the specific settings for the fwHw EgressFPGAStatus type that has been inserted into the
 * UKL1 fwHw type.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void
 */
void _fwUkl1_configureHwTypeCCPCUKL1FpgaStatusSpecificSettings(string ukl1Name, dyn_string& exceptionInfo) {
  // Convert the UKL1 board name into the datapoint name.
  const string dpName = ukl1Name + FWUKL1_FPGA_STATUS_HWTYPE;
  
  // Set the specific settings.
  // This contains a list of all the register names that are to be set.
  dyn_string registerList;
  registerList[1]  = "GeneralStatus1";
  registerList[2]  = "GigabitTransceiverInhibits";
  registerList[3]  = "BufferFlags";
  registerList[4]  = "MEPBuilderStatus";
  registerList[5]  = "EthernetFormatterState";
  registerList[6]  = "GeneralStatus2";
  registerList[7]  = "TFCLongBroadcast";
  registerList[8]  = "EgressInputFIFOErrors";
  registerList[9]  = "FrontEndStatus0";
  registerList[10] = "FrontEndStatus1";
  registerList[11] = "FrontEndStatus2";
  registerList[12] = "FrontEndStatus3";
  registerList[13] = "TFCCommandCounters";
  registerList[14] = "MEPCounters";
  registerList[15] = "Alarms";
  registerList[16] = "EgressInputFIFOOccupancy01";
  registerList[17] = "EgressInputFIFOOccupancy23";
  registerList[18] = "EgressInputFIFORxCnt01";
  registerList[19] = "EgressInputFIFORxCnt23";
  registerList[20] = "EgressInputFIFOTxCnt01";
  registerList[21] = "EgressInputFIFOTxCnt23";

  // The specific settings vary depending on the register so set them all individually.
  dyn_dyn_uint specificSettings;
  // There are two types of register in use here. LBUS and UserSpecific.
  // LBUS registers have:
  // 1st element is the address.
  // 2nd element is the number of bits in the register.
  // 3rd element is the number of words for command.
  // 4th element is the check for change rate (2secs).
  // 5th is send on change only setting.
  // UserSpecific:
  // 1st element is the address of the first word in the FIFO.
  // 2nd element is the type, which is 1 for FIFOs.
  // 3rd element is the width of the FIFO, which is the size of each word that is to be read out in bytes, 2 bytes as we have 16-bit registers.
  // 4rd element is the size of the FIFO, the total number of words in the FIFO. 76 words (4 general status and 9*8 words for the channels.).
  // 5th to 10th elements can be ignored, these are the hexpar and par settings which are irrelevant.
  // 11th element is the rate at which it checks for change, 0s as we cannot read back from this register, it makes no sense.
  // 12th element is send on change only setting, set this.
  specificSettings[1]  = makeDynUInt(_fwUkl1_fpgaizeAddress(0x20), FWCCPC_LBUS_BITS_32, 1, 2, 1);// LBUS
  specificSettings[2]  = makeDynUInt(_fwUkl1_fpgaizeAddress(0x21), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[3]  = makeDynUInt(_fwUkl1_fpgaizeAddress(0x22), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[4]  = makeDynUInt(_fwUkl1_fpgaizeAddress(0x23), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[5]  = makeDynUInt(_fwUkl1_fpgaizeAddress(0x24), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[6]  = makeDynUInt(_fwUkl1_fpgaizeAddress(0x25), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[7]  = makeDynUInt(_fwUkl1_fpgaizeAddress(0x26), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[8]  = makeDynUInt(_fwUkl1_fpgaizeAddress(0x27), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[9]  = makeDynUInt(_fwUkl1_fpgaizeAddress(0x28), 1, 2, 76, 0, 0, 0, 0, 0, 0, 0, 1);// UserSpecific
  specificSettings[10] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x29), 1, 2, 76, 0, 0, 0, 0, 0, 0, 0, 1);
  specificSettings[11] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x2a), 1, 2, 76, 0, 0, 0, 0, 0, 0, 0, 1);
  specificSettings[12] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x2b), 1, 2, 76, 0, 0, 0, 0, 0, 0, 0, 1);
  specificSettings[13] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x2c), FWCCPC_LBUS_BITS_32, 1, 2, 1);// LBUS
  specificSettings[14] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x2d), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[15] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x2f), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[16] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x30), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[17] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x31), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[18] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x32), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[19] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x33), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[20] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x34), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  specificSettings[21] = makeDynUInt(_fwUkl1_fpgaizeAddress(0x35), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  
  // Now write all these to the datapoint.
  if ( !fwHw_setSpecificSettings(dpName, registerList, specificSettings) )
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1FpgaStatusSpecificSettings(): Failed to setup the status specific settings for the FPGAs, the FPGAs' status values will be unavaliable.", "1");

  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1FpgaSpecificSettings()

/*!
 * This will set the specific settings for the fwHw UKL1Resets type that has been inserted into the
 * UKL1 fwHw type.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  ukl1Version Indicates whether we have a production or prototype board.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void
 */
void _fwUkl1_configureHwTypeCCPCUKL1ResetsSpecificSettings(string ukl1Name, unsigned ukl1Version, dyn_string& exceptionInfo) {
  // Convert the UKL1 board name into the datapoint name.
  const string dpName = ukl1Name + ".Resets";

  // Set the specific settings.
  // This contains a list of all the register names that are to be set.
  dyn_string registerList;
  registerList[1]  = "IngressFpgaStatusBufferPointers";
  registerList[2]  = "SPI3RxReadPointer";
  registerList[3]  = "PartialL1";
  registerList[4]  = "DCMs";

  // Now we create the settings, they are all the same as all the registers exist on the same address.
  // 1st element is the address, all 0x15 (21).
  // 2nd element is the number of bits in the register, set to 32-bits like everyone else.
  // 3rd element is the number of words for command.
  // 4th element is the check for change rate (2secs).
  // 5th is send on change only setting.
  dyn_uint specificSetting = makeDynUInt(_fwUkl1_fpgaizeAddress(0x15), FWCCPC_LBUS_BITS_32, 1, 2, 1);
  dyn_dyn_uint specificSettings;
  // Loop over all the registers
  for (unsigned count = 1; count <= dynlen(registerList); ++count) {
    // Now put the specific settings in the appropriate element of the array containing all the settings for each register.
    specificSettings[count] = specificSetting;
  }// for count

  // Now write all the read write register settings to the datapoint.
  if ( !fwHw_setSpecificSettings(dpName, registerList, specificSettings) )
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUK1ResetsSpecificSettings(): Failed to setup the specific settings for the UKL1 resets, will not be able to perform certain specific resets. General UKL1 reset still available.", "1");
  
  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1ResetsSpecificSettings()

/*!
 * This will set the specific settings for the fwHw EEPORM type that has been inserted into the
 * UKL1 fwHw type.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  ukl1Version Indicates whether we have a production or prototype board.
 *           documentation) are used.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_configureHwTypeCCPCUKL1PROMSpecificSettings(string ukl1Name, unsigned ukl1Version, dyn_string& exceptionInfo) {
  // Convert the UKL1 board name into the datapoint name.
  const string dpName = ukl1Name + ".PROM";

  // Set the specific settings.
  // This contains a list of all the register names that are to be set.
  dyn_string registerList;
  registerList[1] = "Id";
  // These are the settings that are specific to each register, the address and its size.
  // Note that we tie the page size to the register size, which is probably correct and at least works.
  dyn_uint registerAddr;
  registerAddr[1] = 0;
  dyn_uint registerSize;
  registerSize[1] = 6;
  // The bus number that the PROM is on is determined by whether it is production or prototype.
  // Zero for production.
  int bus = 0;
  // One for prototype.
  if ( FWUKL1_PROTOTYPE == ukl1Version )
    bus = 1;
  // Now we create the settings, these are actually almost the same for each except for the address.
  // 1st element is the bus number that the PROM is on, dependent on whether it is a production or prototype board.
  // 2nd element is the address of the PROM on the bus, always 0x50.
  // 3rd element is the address of the data on the PROM.
  // 4th element is the number of bytes that should be written to that register.
  // 5th element is the page size, the number of bytes. Probably.
  // 6th element is the the type of I2C interface to use, always FWCCPC_I2C_COMBINED for the PROM.
  // 7th element is the negative acknowledge, NACK, leave it enabled as I think it tells us if it failed. Always 1. 
  // 8th element is the refresh rate, always 2. Monitoring must be enabled to use this setting.
  // 9th element is the on data change settings always 1. Monitoring must be enabled to use this setting.
  dyn_uint specificSetting = makeDynUInt(bus, 0x50, 0, 0, 0, FWCCPC_I2C_COMBINED, 1, 2, 1);
  dyn_dyn_uint specificSettings;
  // Loop over all the registers
  for (unsigned count = 1; count <= dynlen(registerList); ++count) {
    // Now put the specific settings in the appropriate element of the array containing all the settings for each register.
    specificSetting[3] = registerAddr[count];
    specificSetting[4] = registerSize[count];
    specificSetting[5] = registerSize[count];// This is the page size which we are tying to the register size, as it is probably correct.
    specificSettings[count] = specificSetting;
  }// for count
  
  // Now write all these to the datapoint.
  if ( !fwHw_setSpecificSettings(dpName, registerList, specificSettings) )
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1PROMSpecificSettings(): Failed to setup the specific settings for the UKL1 PROM, communication with the PROM is not possible.", "1");

  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1PROMSpecificSettings()

/*!
 * This will set the specific settings for the fwHw TEMPSENS types that has been inserted into the
 * UKL1 fwHw type.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  ukl1Version Indicates whether we have a production or prototype board.
 *           documentation) are used.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_configureHwTypeCCPCUKL1SensorSpecificSettings(string ukl1Name, unsigned ukl1Version, dyn_string& exceptionInfo) {
  // Address of the 3 sensors.
  dyn_int addresses = makeDynInt(0x48, 0x4a, 0x4c);
  // Loop over all the available temperature sensors and configure them.
  for (int tempSens = 1; tempSens <= FWUKL1_TEMPERATURE_SENSORS; ++tempSens) {
    // Convert the UKL1 board name into the datapoint name.
    const string dpName = ukl1Name + ".Sensors.Temp" + tempSens;
    
    // Set the specific settings.
    // This contains a list of all the register names that are to be set.
    dyn_string registerList;
    registerList[1] = "TempRead";
    // 1st element is the bus number that the PROM is on, dependent on whether it is a production or prototype board.
    // Zero for production
    unsigned bus = 0;
    // One for prototype.
    if ( FWUKL1_PROTOTYPE == ukl1Version )
      bus = 1;
    // 2nd element is the address of the temperature sensor on the bus, varies depending on which sensor it is:
    unsigned address = addresses[tempSens];
    // 3rd element is the address of the temperature data on the register, always 0.
    // 4th element is the number of bytes that should be read from the register, 1 as the temperature is stored as an 8-bit number.
    // 5th element is the page size, -1 which is infinite and we can ignore it.
    // 6th element is the the type of I2C interface to use, always FWCCPC_I2C_COMBINED for the temperature sensor.
    // 7th element is the negative acknowledge, NACK, leave it enabled as I think it tells us if it failed. Always 1. 
    // 8th element is the refresh rate, always 2. Monitoring must be enabled to use this setting.
    // 9th element is the on data change settings always 1. Monitoring must be enabled to use this setting.
    dyn_uint specificSetting = makeDynUInt(bus, address, 0, 1, -1, FWCCPC_I2C_COMBINED, 1, 2, 1);
    dyn_dyn_uint specificSettings;
    specificSettings[1] = specificSetting;
  
    // Now write all these to the datapoint.
    if ( !fwHw_setSpecificSettings(dpName, registerList, specificSettings) )
      fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1SensorSpecificSettings(): Failed to setup the specific settings for the temperature sensor number " + tempSens + ", communication with this sensor is not possible.", "1");
  }// for tempSensor
  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1SensorSpecificSettings()

/*!
 * This will set the specific settings for the fwHw TTCRX type that has been inserted into the
 * UKL1 fwHw type.
 *
 * \param  ukl1Name Name of the UKL1 board as it appears in the DIM server.
 * \param  ukl1Version Indicates whether we have a production or prototype board.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void _fwUkl1_configureHwTypeCCPCUKL1TTCRXSpecificSettings(string ukl1Name, unsigned ukl1Version, dyn_string& exceptionInfo) {
  // Convert the UKL1 board name into the datapoint name.
  const string dpName = ukl1Name + ".TTCRX";

  // Set the specific settings.
  // This contains a list of all the register names that are to be set.
  dyn_string registerList;
  registerList[1]  = "IACId";
  registerList[2]  = "I2CId";
  registerList[3]  = "FineDelay1";
  registerList[4]  = "FineDelay2";
  registerList[5]  = "CoarseDelay";
  registerList[6]  = "Control";
  registerList[7]  = "Status";
  registerList[8]  = "Config1";
  registerList[9]  = "Config2";
  registerList[10] = "Config3";
  registerList[11] = "SingleErrCnt";
  registerList[12] = "DoubleErrCnt";
  registerList[13] = "SEUErrCnt";
  registerList[14] = "BunchCnt";
  registerList[15] = "EventCnt";
  // This contains the address of all the registers to be set.
  dyn_uint regAddrList;
  regAddrList[1]  = 16;
  regAddrList[2]  = 18;
  regAddrList[3]  = 0;
  regAddrList[4]  = 1;
  regAddrList[5]  = 2;
  regAddrList[6]  = 3;
  regAddrList[7]  = 22;
  regAddrList[8]  = 19;
  regAddrList[9]  = 20;
  regAddrList[10] = 21;
  regAddrList[11] = 8;
  regAddrList[12] = 10;
  regAddrList[13] = 11;
  regAddrList[14] = 24;
  regAddrList[15] = 26;
  // This contains the number of bytes that need to be set for the each of the registers.
  dyn_uint numBytes;
  numBytes[1]  = 2;
  numBytes[2]  = 1;
  numBytes[3]  = 1;
  numBytes[4]  = 1;
  numBytes[5]  = 1;
  numBytes[6]  = 1;
  numBytes[7]  = 1;
  numBytes[8]  = 1;
  numBytes[9]  = 1;
  numBytes[10] = 1;
  numBytes[11] = 2;
  numBytes[12] = 1;
  numBytes[13] = 1;
  numBytes[14] = 2;
  numBytes[15] = 3;

  // Now we create the settings, these are actually almost the same for each except for the address.
  // 1st element is the bus number that the TTCrx is on,determined by whether it is a prototype or not.
  // Zero for production
  unsigned bus = 0;
  // One for prototype.
  if ( FWUKL1_PROTOTYPE == ukl1Version )
    bus = 1;
  // 2nd element is the address of the TTCrx on the bus, again always 0x42 the address the register addresses should be written to.
  // 3rd element is the address of the TTCrx registers on the TTCrx chip, variable.
  // 4th element is the number of bytes that should be written to that register, again variable.
  // 5th element is the page size, don't really know but if -1 it is infinite and we can ignore it.
  // 6th element is the the type of I2C interface to use, always FWCCPC_I2C_SEPARATED for the TTCrx chip.
  // 7th element is the negative acknowledge, NACK, leave it enabled as I think it tells us if it failed. Always 1. 
  // 8th element is the refresh rate, always 2. Have to enable monitoring to eactually use this setting.
  // 9th element is the on data change settings always 1. Have to enable monitoring to eactually use this setting.
  dyn_uint specificSetting = makeDynUInt(bus, 0x42, 0, 0, -1, FWCCPC_I2C_SEPARATED, 1, 2, 1);
  dyn_dyn_uint specificSettings;
  // Loop over all the registers
  for (unsigned count = 1; count <= dynlen(regAddrList); ++count) {
    // Put the appropriate register address in the settings array.
    specificSetting[3] = regAddrList[count];
    specificSetting[4] = numBytes[count];
    // Now put the specific settings in the appropriate element of the array containing all the settings for each register.
    specificSettings[count] = specificSetting;
  }// for count

  // Now write all these to the datapoint.
  if ( !fwHw_setSpecificSettings(dpName, registerList, specificSettings) )
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_configureHwTypeCCPCUKL1TtcrxSpecificSettings(): Failed to setup the specific settings for the UKL1 TTCrx chip, communication with the TTCrx is not possible.", "1");

  // Done.
  return;
}// _fwUkl1_configureHwTypeCCPCUKL1TtcrxSpecificSettings()

// @}


// ==========================
//  UKL1 CONSTANTS INTERFACE
// ==========================

/*! @defgroup ConstantsInterface UKL1 constants interface
 *     These functions are all used to set or get the DPE of the UKL1 constants datapoint.
 *
 *     The constants datapoint contains the values that are RICH specific and are used at run time to configure
 *     the project appropriately.
 *  @{
 */

/*!
 * Retrieves the name that is to be used for the UKL1 FSM CU.
 *
 * \param  sysName This is the name of the system that the FwUkl1Constant DP has been stored on. It must contain the trailing
 *           semi-colon e.g. R2DAQL1: or it can be an empty string if the system name is not known or it is running locally.
 *           Defaults to an empty string.
 * \return string The name that is to be used for the UKL1 FSM CU. Returns an empty string in the event of an error.
 *
 * Errors are reported directly to the UKL1 log.
 */
string fwUkl1_getFSMCUName(string sysName = "") {
  // Holds the exception information.
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // Holds the name of the CU.
  string cu = fwUkl1_getUkl1Constant(FWUKL1_CU, sysName, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getFSMCUName(): Failed to retrieve the FSM CU name. Returning an emtpy string for the name.", "2", exInfoSize) ) {
    fwUkl1ExceptionLog_submit(exceptionInfo, FWUKL1_CONSTS_DP_BASENAME);
    cu = "";
  }// if error.
  // Done.
  return cu;
}// fwUkl1_getFSMCUName()

/*!
 * Retrieves the flag that indicates if the recipes are to be loaded from the database or the recipe cache.
 *
 * \param  sysName This is the name of the system that the FwUkl1Constant DP has been stored on. It must contain the trailing
 *           semi-colon e.g. R2DAQL1: or it can be an empty string if the system name is not known or it is running locally.
 *           Defaults to an empty string.
 * \return bool Value of the flag. FALSE is returned in the event of an error as the recipe cache should always be present.
 *
 * Errors are reported directly to the UKL1 log.
 */
string fwUkl1_getConfiguratorUseConfDBFlag(string sysName = "") {
  // Holds the exception information.
  dyn_string exceptionInfo;
  // Holds the value of the flag.
  bool flag = fwUkl1_getUkl1Constant(FWUKL1_CONFIGURATOR_USE_CONFDB, sysName, exceptionInfo);
  int exInfoSize = 0;
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getConfiguratorUseConfDBFlag(): Failed to retrieve the value of the flag that determines if the FSM configurator object should retrieve recipes from the cache or DB. Setting to use from the cache.", "2", exInfoSize) ) {
    fwUkl1ExceptionLog_submit(exceptionInfo, FWUKL1_CONSTS_DP_BASENAME);
    flag = FALSE;
  }// if error.
  // Done.
  return flag;
}// fwUkl1_getFSMCUName()

/*!
 * Retrieves the name that is to be used for the Hugin in the FSM tree.
 *
 * \param  sysName This is the name of the system that the FwUkl1Constant DP has been stored on. It must contain the trailing
 *           semi-colon e.g. R2DAQL1: or it can be an empty string if the system name is not known or it is running locally.
 *           Defaults to an empty string.
 * \return string The name that is to be used for the Hugin. Returns an empty string in the event of an error.
 *
 * Errors are reported directly to the UKL1 log.
 */
string fwUkl1_getHuginName(string sysName = "") {
  // Holds the exception information.
  dyn_string exceptionInfo;
  int exInfoSize = 0;
  // Holds the name of the Hugin.
  string hugin = fwUkl1_getUkl1Constant(FWUKL1_HUGIN_NAME, sysName, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getHuginName(): Failed to retrieve the name of the Hugin that is to be used in the FSM tree. Returning an emtpy string for the name.", "2", exInfoSize) ) {
    fwUkl1ExceptionLog_submit(exceptionInfo, FWUKL1_CONSTS_DP_BASENAME);
    hugin = "";
  }// if error.
  // Done.
  return hugin;
}// fwUkl1_getHuginName()

/*!
 * This sets a specific constant in the FwUkl1Constants DP.
 *
 * \param  dpeName This is the name of the DPE element that is to be set. These are all defined as library constants.
 * \param  value This is the value to be set to the constant. It is an anytype parameter so the user must ensure that
 *           the appropriate type is set for the given constant.
 * \param  sysName This is the name of the system that the FwUkl1Constant DP has been stored on. It must contain the trailing
 *           semi-colon e.g. R2DAQL1: or it can be an empty string if the system name is not known or it is running locally.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * This function should only be used as part of the post install process. It purely sets the value of the constant and does
 * not trigger any of the required side effects that changing the constants entails.
 */
void fwUkl1_setUkl1Constant(const string& dpeName, anytype& value, const string& sysName, dyn_string& exceptionInfo) {
  // Keeps track of the exceptionInfo size.
  int exInfoSize = dynlen(exceptionInfo);
  // Create the full DPE name.
  const string fullName = sysName + FWUKL1_CONSTS_DP_BASENAME + "." + dpeName;
  // Now check it exists.
  if (dpExists(fullName)) {
    // DP exists so set the value.
    if (0 != dpSet(fullName, value)) {
      // Failed to retrieve the value, note this.
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_setUkl1Constant(): Failed to set the requested constant \'" + fullName + "\'. dpSet() failed.", "2");
    }// if(0!=dpSet())
  }// if(dpExists(fullName))
  else {
    // If the DPE didn't exist, just check that the base DP exists.
    if (!dpExists(FWUKL1_CONSTS_DP_BASENAME)) {
      // Try and create the constants DP.
      fwUkl1_createUkl1ConstantsDP(sysName, exceptionInfo);
      // If no error call ourselves again.
      if (!fwUkl1Exception_checkAndRaise(exceptionInfo, "FATAL", "fwUkl1_setUkl1Constant(): The UKL1 constants DP does not exists and could not be created. Could not set the DPE \'" + fullName + "\' as the DP does not exist and could not be created.", "1", exInfoSize))
        fwUkl1_setUkl1Constant(dpeName, value, sysName, exceptionInfo);
    }// if(!dpExists())
    else {
      // The base DP did existed so there must be a problem with the DPE.
      // Raise an exception to note that the requested DP element did not exist.
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_setUkl1Constant(): Failed to set the requested constant as the DPE \'" + fullName + "\'. Does not exist.", "2");
    }// else(!dpExists())
  }// else(dpExists(fullName))
  
  // Done.
  return;
}// fwUkl1_setUkl1Constant()

/*!
 * This retrieves a specific constant from the FwUk1Constants DP.
 *
 * \param  dpeName This is the name of the DPE element that is to be retrieved. These are all defined as library constants.
 * \param  sysName This is the name of the system that the FwUkl1Constant DP has been stored on. It must contain the trailing
 *           semi-colon e.g. R2DAQL1: or it can be an empty string if the system name is not known or it is running locally.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return anytype The constant that is requested from the DP. It is an any type so must be converted to the appropriate
 *           value for the constant. In the event that an error occurs the value of the return can be anything.
 */
anytype fwUkl1_getUkl1Constant(const string& dpeName, const string& sysName, dyn_string& exceptionInfo) {
  const string fullName = sysName + FWUKL1_CONSTS_DP_BASENAME + "." + dpeName;
  // Holds the value that is to be returned.
  anytype value;
  // Now check it exists.
  if (dpExists(fullName)) {
    // DP exists so retrieve the data.
    if (0 != dpGet(fullName, value)) {
      // Failed to retrieve the value, note this.
      fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_getUkl1Constant(): Failed to retrieve the requested constant as the DPE \'" + fullName + "\'. dpGet() failed.", "2");
    }// if(0!=dpGet())
  }// if(dpExists(fullName))
  else {
    // Raise an exception to note that the requested DP element did not exist.
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "fwUkl1_getUkl1Constant(): Failed to retrieve the requested constant as the DPE \'" + fullName + "\'. Does not exist.", "2");
  }// else(dpExists(fullName))
  // Done.
  return value;
}// fwUkl1_getUkl1Constant()

/*!
 * Creates the DP that stores the UKL1 constants.
 *
 * \param  sysName This is the name of the system that the FwUkl1Constant DP has been stored on. It must contain the trailing
 *           semi-colon e.g. R2DAQL1: or it can be an empty string if the system name is not known or it is running locally.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 */
void fwUkl1_createUkl1ConstantsDP(const string& sysName, dyn_string& exceptionInfo) {
  // Keeps track of the exceptionInfo size.
  int exInfoSize = dynlen(exceptionInfo);
  const string fullDpName = sysName + FWUKL1_CONSTS_DP_BASENAME;
  if ( !dpExists(fullDpName) ) {
    // If it doesn't exist then we must create it.
    // Quote PVSS help: "dpCreate() returns 0, in the event of a failure returns -1. 
    //                  The function possibly returns 0 also in the event of a failure.
    //                  In this case errors can only be retrieved with getLastError()!"
    // Nice. Use getLastError() to determine if the DP creation was successful.
    // Don't bother to try and create it on a specific system, it is not necessarily correct
    // when this is called. For example during the init routine where the library won't have
    // been reloaded with the appropriate system number.
    dpCreate(FWUKL1_CONSTS_DP_BASENAME, FWUKL1_CONSTS_DPT);
    // Doubt it is thread safe...
    dyn_errClass error = getLastError();
    if ( 0 != dynlen(error) ) {
      // Couldn't create the data point.
      exInfoSize = fwUkl1Exception_raise(exceptionInfo, "FATAL", "fwUkl1_createUkl1ConstantsDP(): Failed to create the UKL1 constants DP, the UKL1 library and panels will not function correctly. Check the DPT \'" + FWUKL1_CONSTS_DPT + "\' exists.", "1");
    }// if dpCreate() failed
  }// if(!dpExists())
  // No else as we just return if the data point already exists.
  // Done.
  return;
}// fwUkl1_createUkl1ConstantsDP()

// @}


// =========================
//  UKL1 BOARD DP INTERFACE
// =========================

/*! @defgroup Ukl1BoardDpInterface These function provide the interface to the UKL1 board datapoint.
 *     These functions are all used to get the DPE of the UKL1 board datapoint.
 *
 *     The UKL1 board datapoint provides the information on how to deal with the abstract registers
 *     that exist for the UKL1 board. One or more abstract registers can be associated with a single
 *     hardware register. The fwHw library does provide the means to do this also, however DIM communication
 *     is the bottle neck in terms of time in the system so it is better to have a minimum of registers
 *     that DIM is used to communicate with. The abstraction layer is therefore created in the software
 *     above DIM using this datapoint to manage these 'registers'.
 *
 *     The functions used here can only be used to read values from the data point. The configuration
 *     functions are provided as part of the board setup interface and are all internal functions.
 *  @{
 */

/*!
 * Retrieves the names of the hardware registers associated with the given list of abstract regiseters.
 *
 * \param  regList Names of the abstract registers to find the associated hardware registers.
 * \param  standard It is possible that some registers store a comma separated list. Passing TRUE
 *           retrieves the first entry in the list, the standard register. Passing FALSE picks
 *           up the second entry in the list, the alternative. If no alternative is found the
 *           standard is returned with a warning. This is set for each register name in the regList.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return dyn_string Names of the hardware registers associated with these abstract registers. Each entry is unique.
 */
dyn_string fwUkl1_getHwRegNames(const dyn_string &regList, dyn_bool standard, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // Holds the list of hardware registers once retrieved from the DP.
  dyn_string hwRegNames;
  // Holds the individual hw reg while we check whether to add it.
  string hwRegName;
  // Number of registers to search for.
  const int numRegs = dynlen(regList);
  // The abstract register we are interested in.
  string regName;
  for (int regNum = 1; regNum <= numRegs; ++regNum) {
    regName = regList[regNum];
    hwRegName = fwUkl1_getHwRegName(regName, standard[regNum], exceptionInfo);
    if (!fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getHwRegNames(): Failed to retrieve the hardware register associated with the abstract register " + regName + ". Returned list of hardware registers may not be complete.", "2", exInfoSize)) {
      if (1 > dynContains(hwRegNames, hwRegName))
        dynAppend(hwRegNames, hwRegName);
    }// if got hardware reg name.
  }// for regNum
  // Done.
  return hwRegNames;
}// fwUkl1_getHwRegNames()

/*!
 * Retrieves the name of the hardware register associated with the given register.
 *
 * \param  regName Name of the register to find the associated hardware register.
 * \param  standard It is possible that some registers store a comma separated list. Passing TRUE
 *           retrieves the first entry in the list, the standard register. Passing FALSE picks
 *           up the second entry in the list, the alternative. If no alternative is found then
 *           the standard will be returned and no error condition is raised. Typically the
 *           standard is the write register and the alternative the read.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return string Empty string in the event of an error.
 *
 * The returned form of the hardware register name could have a semi-colon separated list of the
 * registers that are associated with the register. This is typically the case with abstract
 * registers that are a collection of multiple registers.
 */
string fwUkl1_getHwRegName(const string &regName, bool standard, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  string hwReg = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_REGISTERS, exceptionInfo);
  if (!fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getHwRegName(): Failed to retrieve the name of the hardware register associated with " + regName + ".", "2", exInfoSize)) {
    // Search to see if we have a comma.
    int commaPos = strpos(hwReg, ",");
    if (-1 < commaPos) {
      // Found a comma, do we want the first standard entry in the list of the second alternative.
      if (standard)
        hwReg = substr(hwReg, 0, commaPos);
      else
        hwReg = substr(hwReg, commaPos+1);
    }// if(-1<commaPos)
  }// if got hardware register.
  else
    hwReg = "";
  // Done.
  return hwReg;
}// fwUkl1_getHwRegName()

/*!
 * Retrieves the type of the hardware register associated with the given register.
 *
 * \param  regName Name of the register to find the associated hardware register.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return int -1 in the event of failure or the hardware type.
 */
int fwUkl1_getHwRegType(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  int hwType = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_HW_CONFIG_READ+FWUKL1_HW_REGISTER_TYPE, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getHwRegType(): Failed to retrieve the type of the hardware register associated with " + regName + ".", "2", exInfoSize) )
    hwType = -1;
  // Done.
  return hwType;
}// fwUkl1_getHwRegType()

/*!
 * Retrieves the associated with the given register.
 *
 * \param  regName Name of the register to find the associated hardware register.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return dyn_string List of group names which this register is a member of or empty in the event of failure.
 */
dyn_string fwUkl1_getRegisterGroups(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  dyn_string groups = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_REGISTER_GROUPS, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getRegisterGroups(): Failed to retrieve the group associated with " + regName + ".", "2", exInfoSize) )
    groups = makeDynString();
  // Done.
  return groups;
}// fwUkl1_getRegisterGroups()

/*!
 * Retrieves the list of recipe types that the register is in.
 *
 * \param  regName Name of the register to look up.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return dyn_string List of the recipe types that the register is in, empty in the event of an error.
 */
dyn_string fwUkl1_getRecipeTypesWithReg(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  dyn_string rTypes = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_DB_READ+FWUKL1_DB_RECIPE_TYPES, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getRecipeTypesWithReg(): Failed to retrieve the recipe types containing " + regName + ".", "2", exInfoSize) )
    rTypes = makeDynString();
  // Done.
  return rTypes;
}// fwUkl1_getRecipeTypesWithReg()

/*!
 * This retrieves the mask for this abstract register as a hex string.
 *
 * \param  regName Name of the register to look up.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return string Mask as a hex string.
 */
string fwUkl1_getHwRegMask(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  string mask = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_MASK, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getWriteFunction(): Failed to retrieve the mask associated with " + regName + ".", "2", exInfoSize) )
    mask = "";
  // Done.
  return mask;
}// fwUkl1_getHwRegMask()
    
/*!
 * This retrieves the name of the function that should be used to write the hardware register.
 *
 * \param  regName Name of the register to look up.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return string Name of the function to use.
 */
string fwUkl1_getWriteFunction(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  string func = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_HW_WRITE+FWUKL1_ACCESS_FUNCTION, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getWriteFunction(): Failed to retrieve the write function associated with " + regName + ".", "2", exInfoSize) )
    func = "";
  // Done.
  return func;
}// fwUkl1_getWriteFunction()
    
/*!
 * This retrieves the name of the function that should be used to read the hardware register.
 *
 * \param  regName Name of the register to look up.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return string Name of the function to use.
 */
string fwUkl1_getReadFunction(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  string func = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_HW_CONFIG_READ+FWUKL1_ACCESS_FUNCTION, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getReadFunction(): Failed to retrieve the read function associated with " + regName + ".", "2", exInfoSize) )
    func = "";
  // Done.
  return func;
}// fwUkl1_getReadFunction()

/*!
 * This retrieves the tool tip that should be associated with shape used to display the data.
 *
 * \param  regName Name of the register to look up.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return string Tool tip text information.
 */
string fwUkl1_getToolTipText(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  string tooltip = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_TOOLTIP_TEXT, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getToolTipText(): Failed to retrieve the tool tip text associated with " + regName + ".", "2", exInfoSize) )
    tooltip = "";
  // Done.
  return tooltip;
}// fwUkl1_getToolTipText()
    
/*!
 * This retrieves the function that should be used to start monitoring the register.
 *
 * \param  regName Name of the register to look up.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return string Function name.
 */
string fwUkl1_getStartMonitoringFunction(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  string func = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_MONITORING_START_FUNCTION, exceptionInfo);
  if (fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getStartMonitoringFunction(): Failed to retrieve the monitoring start function associated with " + regName + ".", "2", exInfoSize))
    func = "";
  // Done.
  return func;
}// fwUkl1_getStartMonitoringFunction()

/*!
 * This retrieves the function that should be used to stop monitoring the register.
 *
 * \param  regName Name of the register to look up.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return string Function name.
 */
string fwUkl1_getStopMonitoringFunction(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  string func = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_MONITORING_STOP_FUNCTION, exceptionInfo);
  if (fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getStopMonitoringFunction(): Failed to retrieve the monitoring start function associated with " + regName + ".", "2", exInfoSize))
    func = "";
  // Done.
  return func;
}// fwUkl1_getStopMonitoringFunction()

/*!
 * This retrieves the list of hardware registers that should be monitored for this function.
 *
 * \param  regName Name of the register to look up.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return dyn_string List of registers to monitor.
 */
dyn_string fwUkl1_getMonitoringRegisterList(const string &regName, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  dyn_string list = _fwUkl1_getUkl1AbstractRegisterProperty(regName, FWUKL1_MONITORING_REGISTERS, exceptionInfo);
  if (fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getMonitoringRegisterList(): Failed to retrieve the list of hardware registers to monitor associated with " + regName + ".", "2", exInfoSize))
    list = makeDynString();
  // Done.
  return list;
}// fwUkl1_getMonitoringRegisterList()

/*!
 * This returns the extra information for a specified action and returns it in a parsed form.
 *
 * \param  regName Name of the abstract register the data is to be read for.
 * \param  action Takes on of the three library constants FWUKL1_HW_WRITE+FWUKL1_PARSER_INFO, FWUKL1_HW_CONFIG_READ+FWUKL1_PARSER_INFO
 *           FWUKL1_HW_STATUS_READ+FWUKL1_PARSER_INFO or FWUKL1_HW_CONFIG_READ+FWUKL1_LIMITS_INFO.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return dyn_dyn_string  Each of element of the dyn_dyn_string contains the list of arguments to the data parsing
 *           functions required to get the data into a displayable or writeable format. Each element of the
 *           dyn_string contains the argument itself. No indication is given as to what functions should be
 *           called this is required to be known. Empty in the event of an error.
 *
 * The library provides the functions fwUkl1_parseRegistersForGet/Set which are capable of interpreting this
 * information.
 */
dyn_dyn_string fwUkl1_getExtraRegisterInformation(const string &regName, const string &action, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // Store the outcome here.
  dyn_dyn_string dds;
  string xtrInfo= _fwUkl1_getUkl1AbstractRegisterProperty(regName, action, exceptionInfo);
  if ( !fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getExtraRegisterInformation(): Failed to retrieve the extra register information associated with " + regName + ".", "2", exInfoSize) ) {
    // Now we have the information we need to parse it.
    if ("" != xtrInfo) {
      dyn_string semiColonDelim = strsplit(xtrInfo, ";");
      const int numSemiSec = dynlen(semiColonDelim);
      // Now split the sections by commas.
      for (int secNum = 1; secNum <= numSemiSec; ++secNum)
       dynAppend(dds, strsplit(semiColonDelim[secNum], ","));
    }// if got some extra info
  }// if got extra info successfully
  return dds;
}// fwUkl1_getExtraRegisterInformation()

/*!
 * This retrieves the names of the abstract registers that are in use in the system.
 *
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return dyn_string List of the register names, empty in the event of an error.
 */
dyn_string fwUkl1_getRegisterList(dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // Holds the hardware register name.
  dyn_string rList = _fwUkl1_getUkl1AbstractRegisterProperty("", FWUKL1_ABSTRACT_REG_LIST, exceptionInfo);
  if ( fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", "fwUkl1_getRegisterNames(): Failed to retrieve the list of register names.", "2", exInfoSize) )
    rList = makeDynString();
  // Done.
  return rList;
}// fwUkl1_getRegisterList()

/*!
 * Adds to the mapping all the registers that are in the given group and are present in the recipe type as keys.
 *
 * \param  groups List of groups that the registers should be part of. Can be an empty dyn_string if it is not to be checked.
 * \param  recipeType Name of the recipe type that the registers should be in. Can be empty string if it is not to be checked.
 * \param  rejectedFromType This is a list of the registers that were rejected because they were not in the recipe type,
 *           but they were in the group. This is useful if panel elements are to be disabled when they are not in the type.
 * \param  exceptionInfo Error information. No change in size if no exception information is generated.
 * \return void.
 *
 * The map need not be empty, registers not present are added. Those already present are ignored. Newly added
 * keys have their associated data iniitalised to an empty dyn_string.
 */
void fwUkl1_getRegistersInGroups(const dyn_string &groups, const string &recipeType, mapping &regMap, dyn_string &rejectedFromType, dyn_string &exceptionInfo) {
  int exInfoSize = dynlen(exceptionInfo);
  // Need to create a string for the error message as it isn't updated in loops properly!
  string errmsg = "";
  // First we must get the list of registers in the system.
  const dyn_string absRegList = fwUkl1_getRegisterList(exceptionInfo);
  if ( !fwUkl1Exception_checkAndRaise(exceptionInfo, "ERROR", "fwUkl1_getRegistersInGroup(): Failed to get the list of registers that are in the system, thus we cannot retrieve those that are in the specified group and recipe type.", "2", exInfoSize)) {
    // Used to note if we passed the cut.
    bool passed = FALSE;
    // Now loop over those registers and retrieve the group.
    const int numRegs = dynlen(absRegList);
    for (int regNum = 1; regNum <= numRegs; ++regNum) {
      // Default to not passed.
      passed = FALSE;
      // Name of the register that we are looking at.
      const string reg = absRegList[regNum];
      // See if we have the key, we are ignoring it if does.
      if ( mappingHasKey(regMap, reg) )
        continue;
      
      // Only check the group list if it is not empty.
      if ( 0 < dynlen(groups) ) {
        const dyn_string regGroups = fwUkl1_getRegisterGroups(reg, exceptionInfo);
        errmsg = "fwUkl1_getRegistersInGroup(): Failed to retrieve the group for the register " + reg + ". This register will not be returned in the list.";
        if ( !fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", errmsg, "2", exInfoSize) ) {
          // Loop over the given groups and compare to the list that this register is in.
          for (int i = 1; i <= dynlen(groups); ++i) {
            if (0 < dynContains(regGroups, groups[i]))
              passed = TRUE;
          }// for i
          // If we couldn't find the groups in the register's groups then we can ignore this one.
          if (!passed)
            continue;
        }// if get group
      }// if(0<dynlen(groups))
      
      // Only check the recipe type if it is not empty.
      if ( passed && ("" != recipeType) ) {
        // This returns a list of the recipe types that contain this.
        const dyn_string regRTypes = fwUkl1_getRecipeTypesWithReg(reg, exceptionInfo);
        errmsg = "fwUkl1_getRegistersInGroup(): Failed to retrieve the recipe type for the register " + reg + ". This register will not be returned in the list.";
        if ( !fwUkl1Exception_checkAndRaise(exceptionInfo, "WARNING", errmsg, "2", exInfoSize) ) {
          if ( 0 < dynContains(regRTypes, recipeType) )
            passed = TRUE;
          else {
            // Add it to the list of rejected registers. It must be in the group to get this far.
            dynAppend(rejectedFromType, regRTypes);
            continue;
          }// else
        }// if get group
      }// if check recipeType

      // See if we should add the register to the map.
      if ( passed ) {
        regMap[reg] = makeDynString();
      }// if(passed)
    }// for regNum
  }// if got register list
  
  // Done.
  return;
}// fwUkl1_getRegistersInGroups()

// ==========
// INTERNAL
// =========

/*!
 * This retrieves a value associated with a register from the FwUkl1Board DP.
 *
 * \param  regName The abstract register name that we want to retrieve the information for. If an empty string it
 *           can be used to retrieve the abstract register list, assuming that the appropriate DPE name is given.
 * \param  dpeName This is the name of the DPE element that is to be retrieved. These are all defined as library constants.
 * \param  exceptionInfo Error information. If dynlen is zero no errors occurred. The standard error codes (defined in library
 *           documentation) are used.
 * \return anytype The value that is requested from the DP. It is an any type so must be converted to the appropriate
 *           value for the constant. In the event that an error occurs the value of the return can be anything.
 */
anytype _fwUkl1_getUkl1AbstractRegisterProperty(string regName, const string& dpeName, dyn_string& exceptionInfo) {
  // This doesn't take a system name for the moment until I figure out a good way to retrieve it in a distributed system!
  // If the register name is not empty then it contains a register name and we need to append it with a .
  // to add the extra element into the DPE path.
  if ( "" != regName )
    regName += ".";
  const string fullName = FWUKL1_UKL1_BOARD_DP_NAME + "." + regName + dpeName;
  // Holds the value that is to be returned.
  anytype value;
  // Now check it exists.
  if ( dpExists(fullName) ) {
    // DP exists so retrieve the data.
    if ( 0 != dpGet(fullName, value) ) {
      // Failed to retrieve the value, note this.
      fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_getUkl1AbstractRegisterProperty(): Failed to retrieve the requested DPE \'" + fullName + "\'. dpGet() failed.", "2");
    }// if(0!=dpGet())
  }// if(dpExists(fullName))
  else {
    // Raise an exception to note that the requested DP element did not exist.
    fwUkl1Exception_raise(exceptionInfo, "ERROR", "_fwUkl1_getUkl1AbstractRegisterProperty(): Failed to retrieve the requested constant as the DPE \'" + fullName + "\' does not exist.", "2");
  }// else(dpExists(fullName))
  // Done.
  return value;
}// _fwUkl1_getUkl1AbstractRegisterProperty()

// @}
